(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6019,        233]*)
(*NotebookOutlinePosition[      6727,        257]*)
(*  CellTagsIndexPosition[      6683,        253]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["1. Continuum", "Title",
  InitializationCell->True],

Cell[BoxData[
    \(<< Lautrup`\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Molecular separation scale", "Title"],

Cell["Calculate the molecular separation scales for air and water", "Text"],

Cell[CellGroupData[{

Cell["Air", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Define constants", "Text"],

Cell[BoxData[{
    \(\(M\_mol = 29\ Gram/Mole;\)\), "\n", 
    \(\(N\_A = AvogadroConstant;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = 1.2\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(d = 0.31\ Nano\ Meter;\)\)}], "Input"],

Cell["Calculate molecular separation scale", "Text"],

Cell[BoxData[
    \(L\_mol = \((M\_mol\/\(\[Rho]\ N\_A\))\)\^\(1/3\) // 
        ToUnit[Nanometer]\)], "Input"],

Cell["Calculate mean free path", "Text"],

Cell[BoxData[
    \(\[Lambda] = 
      L\_mol\^3\/\(\[Pi]\ \(d\^2\) \@2\) // ToUnit[Nanometer]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Water", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[BoxData[{
    \(\(M\_mol = 18\ Gram/Mole;\)\), "\n", 
    \(\(N\_A = AvogadroConstant;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = 1\ Gram/\((Centimeter)\)\^3;\)\)}], "Input"],

Cell[BoxData[
    \(L\_mol = \((M\_mol\/\(\[Rho]\ N\_A\))\)\^\(1/3\) // 
        ToUnit[Nanometer]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fluctuating mass density", "Title"],

Cell["\<\
Computer experiment to generate a mass density by throwing \"particles\" \
randomly into boxes.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Initialize", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[BoxData[
    \(\(SeedRandom[];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make density array", "Section"],

Cell["Choose initial values", "Text"],

Cell[BoxData[{
    \(\(size\  = \ 20;\)\), "\n", 
    \(\(subs\  = \ 500;\)\), "\n", 
    \(\(volume\  = \ size\^3;\)\)}], "Input"],

Cell["\<\
Set up a three-dimensional  array of counters (\"boxes\") and fill it \
randomly\
\>", "Text"],

Cell[BoxData[
    \(\(array\  = \ Array[0 &, {size, size, size}];\)\)], "Input"],

Cell[BoxData[
    \(For[i = 1, \ i \[LessEqual] \ volume, \(i++\), 
      x = 1 + Random[Integer, size - 1]; y = 1 + Random[Integer, size - 1]; \ 
      z = 1 + Random[Integer, size - 1]; \[IndentingNewLine]array[\([x, y, 
            z]\)]\  += \ 1]\)], "Input"],

Cell["Calculate density as function of volume number", "Text"],

Cell[BoxData[
    \(\(density = Array[0 &, volume];\)\)], "Input"],

Cell[BoxData[
    \(For[i = 1, \ 
      i \[LessEqual] subs, \(i++\), \[IndentingNewLine]For[count = 0; j = 1, 
        j \[LessEqual] \ i, \(j++\), \[IndentingNewLine]x = 
          1 + Random[Integer, size - 1]; \[IndentingNewLine]y = 
          1 + Random[Integer, size - 1]; \ \[IndentingNewLine]z = 
          1 + Random[Integer, size - 1]; 
        count\  += \ 
          array[\([x, y, z]\)]]; \[IndentingNewLine]density[\([i]\)]\  = \ 
        N[count\/i]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Construct figure", "Section"],

Cell[BoxData[
    \(\(fig1a\  = \ 
        ListPlot[density, 
          PlotRange \[Rule] {{0, subs}, {0, 2}}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b\  = \ 
        Plot[{1, 1 + 1\/\@x, 1 - 1\/\@x}, {x, 0, subs}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b, PlotRange \[Rule] {{0, subs}, {0, 2}}, 
          AxesLabel \[Rule] {"\<V\>", "\<\[Rho]\>"}] \
// \[IndentingNewLine]Figure["\<continuum1\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["1.2 Surface of cube", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\@6 // N\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3 Surface of sphere", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\((36  \[Pi])\)\^\(1/6\) // N\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5 Low density", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\((\(\@2\) \[Pi])\)\^\(3/2\) // N\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
AutoGeneratedPackage->None,
WindowSize->{827, 903},
WindowMargins->{{102, Automatic}, {Automatic, 42}},
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 1, 95, "Title",
  InitializationCell->True],
Cell[1836, 56, 72, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1945, 63, 43, 0, 95, "Title"],
Cell[1991, 65, 75, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[2091, 69, 22, 0, 73, "Section"],
Cell[2116, 71, 51, 1, 30, "Input"],
Cell[2170, 74, 32, 0, 33, "Text"],
Cell[2205, 76, 237, 4, 90, "Input"],
Cell[2445, 82, 52, 0, 33, "Text"],
Cell[2500, 84, 111, 2, 45, "Input"],
Cell[2614, 88, 40, 0, 33, "Text"],
Cell[2657, 90, 107, 2, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2801, 97, 24, 0, 73, "Section"],
Cell[2828, 99, 51, 1, 30, "Input"],
Cell[2882, 102, 182, 3, 70, "Input"],
Cell[3067, 107, 111, 2, 45, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3227, 115, 41, 0, 95, "Title"],
Cell[3271, 117, 119, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[3415, 124, 29, 0, 73, "Section"],
Cell[3447, 126, 51, 1, 30, "Input"],
Cell[3501, 129, 50, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3588, 135, 37, 0, 73, "Section"],
Cell[3628, 137, 37, 0, 33, "Text"],
Cell[3668, 139, 131, 3, 70, "Input"],
Cell[3802, 144, 104, 3, 33, "Text"],
Cell[3909, 149, 80, 1, 30, "Input"],
Cell[3992, 152, 263, 4, 70, "Input"],
Cell[4258, 158, 62, 0, 33, "Text"],
Cell[4323, 160, 66, 1, 30, "Input"],
Cell[4392, 163, 478, 9, 144, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4907, 177, 35, 0, 73, "Section"],
Cell[4945, 179, 126, 3, 30, "Input"],
Cell[5074, 184, 106, 2, 48, "Input"],
Cell[5183, 188, 198, 3, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5430, 197, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[5480, 201, 38, 0, 73, "Section"],
Cell[5521, 203, 46, 1, 30, "Input"],
Cell[5570, 206, 41, 1, 32, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5648, 212, 40, 0, 73, "Section"],
Cell[5691, 214, 46, 1, 30, "Input"],
Cell[5740, 217, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5839, 223, 34, 0, 73, "Section"],
Cell[5876, 225, 46, 1, 30, "Input"],
Cell[5925, 228, 66, 1, 34, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

