(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19521,        695]*)
(*NotebookOutlinePosition[     20194,        718]*)
(*  CellTagsIndexPosition[     20150,        714]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Fluids at rest", "Title"],

Cell[BoxData[
    \(<< Lautrup`\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Various calculations", "Title"],

Cell[CellGroupData[{

Cell["Page 59: Depth of seas", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(a = EarthRadius;\)\), "\n", 
    \(\(\[Rho] = \(10\^3\) Kilogram/Meter\^3;\)\), "\n", 
    \(\(M\_seas = 1.7*^21\ Kilogram;\)\)}], "Input"],

Cell["Volume of the sea", "Text"],

Cell[BoxData[
    \(V = M\_seas\/\[Rho] // ToUnit[Kilometer\^3]\)], "Input"],

Cell["Area of the sea", "Text"],

Cell[BoxData[
    \(A = \(4  \[Pi]\ a\^2 // N\) // ToUnit[Kilometer\^2]\)], "Input"],

Cell["Average depth of the sea", "Text"],

Cell[BoxData[
    \(d = V\/A // ToUnit[Kilometer]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Page 59: Pressure in the sea", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(\[Rho]\_0\  = \ 1000\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(d = 11\ Kilometer // N;\)\), "\[IndentingNewLine]", 
    \(\(a = EarthRadius;\)\), "\[IndentingNewLine]", 
    \(\(p\_0 = 1\ Atmosphere;\)\)}], "Input"],

Cell["Pressure head per atmosphere", "Text"],

Cell[BoxData[
    \(h\_0 = p\_0\/\(\(\[Rho]\_0\) g\_0\) // ToSI\)], "Input"],

Cell["Pressure at the bottom of the deepest ocean", "Text"],

Cell[BoxData[
    \(p\_0\ \ d\/h\_0 // ToUnit[Atmosphere]\)], "Input"],

Cell["Relative change in gravity (factor 2 due to square law)", "Text"],

Cell[BoxData[
    \(\(2  d\)\/a // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Page 60, 69: Atmospheric scale height", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(\[Rho]\_0\  = \ 1.2\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(p\_0 = 1\ Atmosphere;\)\)}], "Input"],

Cell["Scale height of the atmosphere", "Text"],

Cell[BoxData[
    \(h\_0 = \ p\_0\/\(\(\[Rho]\_0\) g\_0\) // ToUnit[Kilometer]\)], "Input"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-1\)\) p\_0 // ToUnit[Hecto\ Pascal]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["p.  72, 73: Specific heat and temperature lapse rate", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(R = MolarGasConstant;\)\), "\[IndentingNewLine]", 
    \(\(\[Gamma] = 1.4;\)\), "\[IndentingNewLine]", 
    \(\(M\_mol = AirMolarMass;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell["Specific heat at constant pressure", "Text"],

Cell[BoxData[
    \(c\_p = \(\[Gamma]\/\(\[Gamma] - 1\)\) R\/M\_mol // 
        ToUnit[Joule]\)], "Input"],

Cell["Atmospheric lapse rate", "Text"],

Cell[BoxData[
    RowBox[{\(g\_0\/c\_p\), "//", 
      RowBox[{\(ToUnit[Kelvin/Kilometer]\), Cell[""]}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bulk modulus and pressure in the Earth", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Data from Kaye and Laby", "Section"],

Cell[BoxData[
    \(\(depth = {0, 60, 150, 350, 500, 1000, 1500, 2000, 2885, 2885.01`, 
          3500, 4000, 4500, 5000, 5155, 5155.01`, 6371};\)\)], "Input"],

Cell[BoxData[
    \(\(pressure = {0, 0.018`, 0.048`, 0.117`, 0.172`, 0.388`, 0.623`, 0.87`, 
          1.356`, 1.356`, 1.936`, 2.467`, 2.882`, 3.214`, 3.302`, 3.302`, 
          3.67`};\)\)], "Input"],

Cell[BoxData[
    \(\(bulk = {0, 1.2`, 1.32`, 1.77`, 2.19`, 3.52`, 4.33`, 5.08`, 6.66`, 
          6.43`, 8.35`, 10.45`, 11.7`, 12.66`, 12.84`, 13.54`, 
          14.66`};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fig. 4.1", "Section"],

Cell[BoxData[
    \(\(figa = 
        ListPlot[Thread[List[pressure, bulk]], PlotJoined -> True, 
          AxesLabel -> {"\<p[Mbar]\>", "\<K[Mbar]\>"}];\)\)], "Input"],

Cell[BoxData[
    \(\(figb = 
        Plot[4  p, {p, 0, 4}, PlotStyle -> {Dashing[{0.01}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[figa, 
          figb] // \[IndentingNewLine]Figure["\<fluids1\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Atmospheric pressure", "Title"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[BoxData[
    \(Atmosphere // ToUnit[Pascal]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Data from CRC96 (pressure in pascal for each kilometer height)\
\>", "Section"],

Cell[BoxData[
    \(\(pressure = {101325, 89880, 79500, 70120, 61660, 54050, 47220, 41110, 
          36560, 30800, 26500, \n\t\t22700, 19400, 16580, 14170, 12110, 
          10350, 8850, 7565, 6467, 5529, 4729, \n\t\t4048, 3467, 2972, 2549, 
          2188, 1880, 1610, 1390, 1197, 1031};\)\)], "Input"],

Cell[BoxData[
    \(height = Table[n, {n, Length[pressure]}] - 1\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fig. 4.2", "Section"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["data",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["ListPlot",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"Thread", "[", \(List[height, pressure\/100]\), 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], 
        StyleBox[";",
          FontFamily->"Courier",
          FontWeight->"Bold"]}], 
      StyleBox["\n",
        FontFamily->"Courier",
        FontWeight->"Bold"]}]], "Input",
  PageWidth->Infinity,
  FontWeight->"Plain"],

Cell["Theoretical models", "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox["h",
            FontWeight->"Bold"], "0"], 
        StyleBox["=",
          FontWeight->"Bold"], 
        StyleBox["8.61",
          FontWeight->"Bold"]}], 
      StyleBox[";",
        FontWeight->"Bold"]}], "\[IndentingNewLine]", 
    StyleBox[\(\[Gamma] = 1.4;\),
      FontWeight->"Bold"], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox["p",
            FontWeight->"Bold"], "0"], 
        StyleBox["=",
          FontWeight->"Bold"], 
        RowBox[{
          FractionBox[
            StyleBox["Atmosphere",
              FontWeight->"Bold"], "100"], 
          StyleBox["//",
            FontWeight->"Bold"], 
          StyleBox["NToSI",
            FontWeight->"Bold"]}]}], 
      StyleBox[";",
        FontWeight->"Bold"]}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        SubscriptBox[
          StyleBox["h",
            FontWeight->"Bold"], "2"], 
        StyleBox["=",
          FontWeight->"Bold"], 
        FractionBox[
          SubscriptBox[
            StyleBox["h",
              FontWeight->"Bold"], "0"], \(1 - 1\/\[Gamma]\)]}], 
      StyleBox[";",
        FontWeight->"Bold"]}]}], "Input",
  PageWidth->Infinity,
  FontWeight->"Plain"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["theory",
          FontWeight->"Bold"], 
        StyleBox["=",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["Plot",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontWeight->"Bold"], 
          RowBox[{
            RowBox[{
              StyleBox["{",
                FontWeight->"Bold"], 
              RowBox[{
                RowBox[{
                  StyleBox["If",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  RowBox[{
                    RowBox[{
                      StyleBox["z",
                        FontWeight->"Bold"], 
                      StyleBox["<",
                        FontWeight->"Bold"], 
                      SubscriptBox[
                        StyleBox["h",
                          FontWeight->"Bold"], "0"]}], 
                    StyleBox[",",
                      FontWeight->"Bold"], 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["p",
                          FontWeight->"Bold"], "0"], 
                      StyleBox[\((1 - z\/h\_0)\),
                        FontWeight->"Bold"]}], 
                    StyleBox[",",
                      FontWeight->"Bold"], 
                    StyleBox["0",
                      FontWeight->"Bold"]}], 
                  StyleBox["]",
                    FontWeight->"Bold"]}], 
                StyleBox[",",
                  FontWeight->"Bold"], 
                RowBox[{
                  SubscriptBox[
                    StyleBox["p",
                      FontWeight->"Bold"], "0"], 
                  StyleBox[" ",
                    FontWeight->"Bold"], 
                  StyleBox[\(Exp[\(-\(z\/h\_0\)\)]\),
                    FontWeight->"Bold"]}], 
                StyleBox[",",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["If",
                    FontWeight->"Bold"], 
                  StyleBox["[",
                    FontWeight->"Bold"], 
                  StyleBox[" ",
                    FontWeight->"Bold"], 
                  RowBox[{
                    RowBox[{
                      StyleBox["z",
                        FontWeight->"Bold"], 
                      StyleBox["<",
                        FontWeight->"Bold"], 
                      SubscriptBox[
                        StyleBox["h",
                          FontWeight->"Bold"], "2"]}], 
                    StyleBox[",",
                      FontWeight->"Bold"], 
                    RowBox[{
                      SubscriptBox[
                        StyleBox["p",
                          FontWeight->"Bold"], "0"], 
                      StyleBox[
                        SuperscriptBox[\((1 - z\/h\_2)\), 
                          FractionBox[
                            StyleBox["\[Gamma]",
                              FontWeight->"Bold"], \(\[Gamma] - 1\)]],
                        FontWeight->"Bold"]}], 
                    StyleBox[",",
                      FontWeight->"Bold"], 
                    StyleBox["0",
                      FontWeight->"Bold"]}], 
                  StyleBox["]",
                    FontWeight->"Bold"]}]}], 
              StyleBox["}",
                FontWeight->"Bold"]}], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox["\n",
              FontWeight->"Bold"], 
            StyleBox["\t\t",
              FontWeight->"Bold"], 
            StyleBox[\({z, 0, 31}\),
              FontWeight->"Bold"], 
            StyleBox[",",
              FontWeight->"Bold"], 
            StyleBox[\(PlotStyle -> {Dashing[{0.01}], Dashing[{0.02}], {}}\),
              FontWeight->"Bold"]}], 
          StyleBox["]",
            FontWeight->"Bold"]}]}], 
      StyleBox[";",
        FontWeight->"Bold"]}]], "Input",
  PageWidth->Infinity,
  FontWeight->"Plain"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          StyleBox["fig03a",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Bold"], 
          RowBox[{
            RowBox[{
              StyleBox["Show",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox[\({data, theory}\),
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontWeight->"Bold"], 
                RowBox[{
                  StyleBox["PlotRange",
                    FontWeight->"Bold"], 
                  StyleBox["\[Rule]",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["{",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["0",
                        FontWeight->"Bold"], 
                      StyleBox[",",
                        FontWeight->"Bold"], 
                      SubscriptBox[
                        StyleBox["p",
                          FontWeight->"Bold"], "0"]}], 
                    StyleBox["}",
                      FontWeight->"Bold"]}]}], 
                StyleBox[",",
                  FontWeight->"Bold"], 
                StyleBox[\(AxesLabel \[Rule] {"\<z[km]\>", "\<p[hPa]\>"}\),
                  FontWeight->"Bold"]}], 
              StyleBox["]",
                FontWeight->"Bold"]}], 
            StyleBox["//",
              FontWeight->"Bold"], 
            StyleBox["\[IndentingNewLine]",
              FontWeight->"Bold"], 
            StyleBox[\(Figure["\<fluids3\>"]\),
              FontWeight->"Bold"]}]}], 
        StyleBox[";",
          FontWeight->"Bold"]}], 
      StyleBox["\n",
        FontWeight->"Bold"]}]], "Input",
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conditions at the top of Mt. Everest (z=h0)", "Section"],

Cell[BoxData[
    \(p = \(p\_0\) \((1 - h\_0\/h\_2)\)\^\(1\/\(\[Gamma] - 1\)\)\)], "Input"],

Cell[BoxData[
    \(\(T\_0 = 300;\)\)], "Input"],

Cell[BoxData[
    \(T = \(T\_0\) \((1 - h\_0\/h\_2)\) - 273\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["4.1.1 Molecular velocity", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(p = 1  Atmosphere;\)\), "\[IndentingNewLine]", 
    \(\(T = \((273 + 18)\)\ Kelvin;\)\), "\[IndentingNewLine]", 
    \(\(R = MolarGasConstant;\)\), "\[IndentingNewLine]", 
    \(\(M\_mol = AirMolarMass;\)\)}], "Input"],

Cell["Density of atmosphere", "Text"],

Cell[BoxData[
    \(\[Rho] = \(M\_mol\ p\)\/\(R\ T\) // ToSI\)], "Input"],

Cell["Molecular velocity", "Text"],

Cell[BoxData[
    \(v = \@\(3\ p\/\[Rho]\) // ToSI\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["4.1 Dock gate", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\n", 
    \(\(\[Rho]\_0 = 1000\ Kilogram/Meter\^3;\)\), "\n", 
    \(\(h\_1 = 9\ Meter;\)\), "\n", 
    \(\(h\_2 = \ 6\ Meter;\)\), "\n", 
    \(\(a = 12\ Meter;\)\)}], "Input"],

Cell["Force", "Text"],

Cell[BoxData[
    \(F = \(1\/2\) \((h\_1\^2 - h\_2\^2)\) a\ \(\[Rho]\_0\) g\_0 // 
        ToUnit[Newton]\)], "Input"],

Cell["Moment of force", "Text"],

Cell[BoxData[
    \(M = \(1\/6\) \((h\_1\^3 - h\_2\^3)\) a\ \(\[Rho]\_0\) g\_0 // 
        ToUnit[Newton]\)], "Input"],

Cell["Height of attack", "Text"],

Cell[BoxData[
    \(M\/F // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Underwater lamp", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\n", 
    \(\(\[Rho]\_0 = 1000\ Kilogram/Meter\^3;\)\), "\n", 
    \(\(a = 15\ Centimeter;\)\), "\n", 
    \(\(h = 3\ Meter;\)\)}], "Input"],

Cell["Force", "Text"],

Cell[BoxData[
    \(F = \(\[Rho]\_0\) g\_0\ h\ \[Pi]\ a\^2 // ToUnit[Newton]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.3 Manometer", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\n", 
    \(\(h\_1 = 6\ Meter;\)\), "\n", 
    \(\(h\_2 = 3\ Meter;\)\), "\n", 
    \(\(p\_1 = 1.6\ Atmosphere;\)\), "\n", 
    \(\(p\_2 = 2.8\ Atmosphere;\)\), "\n", 
    \(\(p\_0 = 1\ Atmosphere;\)\)}], "Input"],

Cell["Density", "Text"],

Cell[BoxData[
    \(\[Rho]\_0 = \(-\(\(p\_1 - p\_2\)\/\(\(g\_0\) \((h\_1 - h\_2)\)\)\)\) // 
        ToSI\)], "Input"],

Cell["Surface height", "Text"],

Cell[BoxData[
    \(h\_0 = 
      h\_1 + \(p\_1 - p\_0\)\/\(\(\[Rho]\_0\) g\_0\) // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.6 Water equation of state", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\n", 
    \(\(B = 3000\ Atmosphere;\)\), "\n", 
    \(\(n = 7;\)\), "\n", 
    \(\(p\_0 = 1\ Atmosphere;\)\), "\n", 
    \(\(\[Rho]\_0 = 1\ Gram/Centimeter\^3;\)\), "\n", 
    \(\(d = 10.924\ Kilometer;\)\)}], "Input"],

Cell["Scale height", "Text"],

Cell[BoxData[
    \(h = \(n\/\(n - 1\)\) \(p\_0 + B\)\/\(\(\[Rho]\_0\) g\_0\) // 
        ToUnit[Kilo\ Meter]\)], "Input"],

Cell["Density and pressure", "Text"],

Cell[BoxData[
    \(\(\[Rho][
          z_] = \(\[Rho]\_0\) \((1 - z\/h)\)\^\(1/\((n - 1)\)\);\)\)], "Input"],

Cell[BoxData[
    \(\(p[
          z_] = \(-B\) + \((p\_0 + 
                B)\) \((1 - z\/h)\)\^\(n/\((n - 1)\)\);\)\)], "Input"],

Cell["Values at deepest point", "Text"],

Cell[BoxData[
    \(\[Rho][\(-d\)]\/\[Rho]\_0 - 1 // ToSI\)], "Input"],

Cell[BoxData[
    \(p[\(-d\)] // ToUnit[Atmosphere]\)], "Input"],

Cell[BoxData[
    \(p[\(-d\)] // ToUnit[Bar]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.7 Constant bulk modulus", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[
    \(\(\(\(g\_0 = AccelerationDueToGravity;\)\n
    \(\[Rho]\_0 = 1\ Kilogram/Liter;\)\n
    \(K = 23000\ Atmosphere\ ;\)\)\(\ \)\)\)], "Input"],

Cell["Singular depth", "Text"],

Cell[BoxData[
    \(h1 = K\/\(\[Rho]\_0\ g\_0\) // ToUnit[Kilometer]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 937}},
AutoGeneratedPackage->None,
WindowSize->{865, 741},
WindowMargins->{{95, Automatic}, {Automatic, 15}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 34, 0, 95, "Title"],
Cell[1813, 55, 72, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1922, 62, 37, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[1984, 66, 41, 0, 73, "Section"],
Cell[2028, 68, 46, 1, 30, "Input"],
Cell[2077, 71, 162, 3, 70, "Input"],
Cell[2242, 76, 33, 0, 33, "Text"],
Cell[2278, 78, 76, 1, 44, "Input"],
Cell[2357, 81, 31, 0, 33, "Text"],
Cell[2391, 83, 84, 1, 31, "Input"],
Cell[2478, 86, 40, 0, 33, "Text"],
Cell[2521, 88, 62, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2620, 94, 47, 0, 73, "Section"],
Cell[2670, 96, 46, 1, 30, "Input"],
Cell[2719, 99, 323, 5, 110, "Input"],
Cell[3045, 106, 44, 0, 33, "Text"],
Cell[3092, 108, 76, 1, 42, "Input"],
Cell[3171, 111, 59, 0, 33, "Text"],
Cell[3233, 113, 70, 1, 44, "Input"],
Cell[3306, 116, 71, 0, 33, "Text"],
Cell[3380, 118, 52, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3469, 124, 56, 0, 73, "Section"],
Cell[3528, 126, 46, 1, 30, "Input"],
Cell[3577, 129, 207, 3, 70, "Input"],
Cell[3787, 134, 46, 0, 33, "Text"],
Cell[3836, 136, 91, 1, 42, "Input"],
Cell[3930, 139, 90, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4057, 145, 71, 0, 73, "Section"],
Cell[4131, 147, 46, 1, 30, "Input"],
Cell[4180, 150, 243, 4, 90, "Input"],
Cell[4426, 156, 50, 0, 33, "Text"],
Cell[4479, 158, 106, 2, 44, "Input"],
Cell[4588, 162, 38, 0, 33, "Text"],
Cell[4629, 164, 116, 2, 44, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4794, 172, 55, 0, 95, "Title"],
Cell[4852, 174, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[4923, 179, 42, 0, 73, "Section"],
Cell[4968, 181, 159, 2, 30, "Input"],
Cell[5130, 185, 200, 3, 50, "Input"],
Cell[5333, 190, 186, 3, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5556, 198, 27, 0, 73, "Section"],
Cell[5586, 200, 168, 3, 30, "Input"],
Cell[5757, 205, 107, 2, 30, "Input"],
Cell[5867, 209, 109, 2, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6025, 217, 37, 0, 95, "Title"],
Cell[6065, 219, 51, 1, 30, "Input"],
Cell[6119, 222, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[6205, 227, 89, 2, 73, "Section"],
Cell[6297, 231, 304, 4, 70, "Input"],
Cell[6604, 237, 77, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6718, 243, 27, 0, 73, "Section"],
Cell[6748, 245, 978, 31, 60, "Input"],
Cell[7729, 278, 34, 0, 33, "Text"],
Cell[7766, 280, 1301, 45, 126, "Input"],
Cell[9070, 327, 4008, 110, 70, "Input"],
Cell[13081, 439, 1857, 53, 67, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14975, 497, 62, 0, 73, "Section"],
Cell[15040, 499, 91, 1, 49, "Input"],
Cell[15134, 502, 48, 1, 30, "Input"],
Cell[15185, 505, 72, 1, 44, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15306, 512, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[15356, 516, 43, 0, 73, "Section"],
Cell[15402, 518, 46, 1, 30, "Input"],
Cell[15451, 521, 241, 4, 90, "Input"],
Cell[15695, 527, 37, 0, 33, "Text"],
Cell[15735, 529, 73, 1, 43, "Input"],
Cell[15811, 532, 34, 0, 33, "Text"],
Cell[15848, 534, 63, 1, 51, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15960, 541, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[16010, 545, 32, 0, 73, "Section"],
Cell[16045, 547, 46, 1, 30, "Input"],
Cell[16094, 550, 26, 0, 33, "Text"],
Cell[16123, 552, 239, 5, 110, "Input"],
Cell[16365, 559, 21, 0, 33, "Text"],
Cell[16389, 561, 118, 2, 42, "Input"],
Cell[16510, 565, 31, 0, 33, "Text"],
Cell[16544, 567, 118, 2, 42, "Input"],
Cell[16665, 571, 32, 0, 33, "Text"],
Cell[16700, 573, 45, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16782, 579, 38, 0, 73, "Section"],
Cell[16823, 581, 46, 1, 30, "Input"],
Cell[16872, 584, 26, 0, 33, "Text"],
Cell[16901, 586, 202, 4, 90, "Input"],
Cell[17106, 592, 21, 0, 33, "Text"],
Cell[17130, 594, 89, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17256, 600, 32, 0, 73, "Section"],
Cell[17291, 602, 46, 1, 30, "Input"],
Cell[17340, 605, 26, 0, 33, "Text"],
Cell[17369, 607, 275, 6, 130, "Input"],
Cell[17647, 615, 23, 0, 33, "Text"],
Cell[17673, 617, 118, 2, 42, "Input"],
Cell[17794, 621, 30, 0, 33, "Text"],
Cell[17827, 623, 101, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17965, 630, 46, 0, 73, "Section"],
Cell[18014, 632, 46, 1, 30, "Input"],
Cell[18063, 635, 26, 0, 33, "Text"],
Cell[18092, 637, 280, 6, 130, "Input"],
Cell[18375, 645, 28, 0, 33, "Text"],
Cell[18406, 647, 122, 2, 44, "Input"],
Cell[18531, 651, 36, 0, 33, "Text"],
Cell[18570, 653, 109, 2, 41, "Input"],
Cell[18682, 657, 131, 3, 41, "Input"],
Cell[18816, 662, 39, 0, 33, "Text"],
Cell[18858, 664, 70, 1, 44, "Input"],
Cell[18931, 667, 64, 1, 30, "Input"],
Cell[18998, 670, 57, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19092, 676, 44, 0, 73, "Section"],
Cell[19139, 678, 46, 1, 30, "Input"],
Cell[19188, 681, 26, 0, 33, "Text"],
Cell[19217, 683, 159, 3, 70, "Input"],
Cell[19379, 688, 30, 0, 33, "Text"],
Cell[19412, 690, 81, 1, 44, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

