(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16245,        613]*)
(*NotebookOutlinePosition[     16919,        636]*)
(*  CellTagsIndexPosition[     16875,        632]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Planets", "Title",
  InitializationCell->True],

Cell[BoxData[
    \(<< Lautrup`\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Earth pressure", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Data from CRC96", "Section"],

Cell[BoxData[
    \(\(depth = {0, 0.01`, 3, 3.01`, 21, 21.01`, 41, 61, 81, 101, 121, 171, 
          221, 271, 321, 371, 571, 871, 1171, 1471, 1771, 2071, 2371, 2671, 
          2886, 2886.01`, 2971, 3371, 3671, 4071, 4471, 4871, 5156, 5156.01`, 
          5371, 5771, 6071, 6371};\)\)], "Input"],

Cell[BoxData[
    \(\(pressure = {0, 0, 3, 3, 5, 5, 12, 19, 26, 33, 39, 56, 73, 89, 106, 
          124, 199, 328, 466, 607, 752, 903, 1061, 1227, 1352, 1352, 1442, 
          1858, 2154, 2520, 2844, 3116, 3281, 3281, 3385, 3529, 3592, 
          3617};\)\)], "Input"],

Cell[BoxData[
    \(\(a = Last[depth];\)\)], "Input"],

Cell[BoxData[
    \(\(radius = a - depth;\)\)], "Input"],

Cell[BoxData[
    \(\(figa = 
        ListPlot[Thread[List[radius, pressure\/1000]], 
          PlotJoined \[Rule] True];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Twolayer model", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(G = GravitationalConstant // NToSI;\)\), "\n", 
    \(\(a = EarthRadius // NToSI;\)\), "\n", 
    \(\(M\_0 = EarthMass // NToSI;\)\), "\[IndentingNewLine]", 
    \(\(a\_1 = EarthCoreRadius // NToSI;\)\), "\n", 
    \(\ \(M\_1 = EarthCoreMass // NToSI;\)\)}], "Input"],

Cell["Calculate pressure in the three layers", "Text"],

Cell[BoxData[{
    \(\(M\_2 = M\_0 - M\_1;\)\), "\n", 
    \(\(\[Rho]\_1 = 
        M\_1\/\(\(4\/3\) \[Pi]\ a\_1\^\(\(3\)\(\ \)\)\);\)\), "\n", 
    \(\(\[Rho]\_2 = 
        M\_2\/\(\(4\/3\) \[Pi]\ \((a\^3 - a\_1\^3)\)\);\)\)}], "Input"],

Cell[BoxData[{
    \(\(p\_1[r_] = \(2\/3\) \[Pi]\ G\ \(\[Rho]\_1\^2\) r\^2;\)\), "\n", 
    \(\(p\_2[
          r_] = \(2\/3\) \[Pi]\ G\ \(\[Rho]\_2\^2\) \((r\^2 - 
              a\_1\^2)\);\)\), "\n", 
    \(\(p\_3[
          r_] = \ \(4\/3\) \[Pi]\ G\ \(\[Rho]\_2\) \((\[Rho]\_1 - \
\[Rho]\_2)\) \(a\_1\^3\) \((1\/a\_1 - 1\/r)\);\)\)}], "Input"],

Cell["Central pressure", "Text"],

Cell[BoxData[
    \(p\_c = p\_1[a\_1] + p\_2[a] + p\_3[a]\)], "Input"],

Cell["Pressure function", "Text"],

Cell[BoxData[
    \(twolayer[r_] := 
      If[r < a\_1, p\_c - p\_1[r], 
        p\_c - p\_1[a\_1] - p\_2[r] - p\_3[r]]\)], "Input"],

Cell[BoxData[
    \(\(figb = 
        Plot[\(10\^\(-11\)\) twolayer[\(10\^3\) r], {r, 0, a}, 
          PlotStyle \[Rule] Dashing[{0.02}]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Figure 6.1", "Section"],

Cell[BoxData[
    \(\(Show[figa, figb, 
          AxesLabel \[Rule] {"\<r[km]\>", "\<p[Mbar]\>"}] \
// \[IndentingNewLine]Figure["\<planets4\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lane-Emden solution", "Title"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Solutions", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[
    \(\(\[Gamma]s = {6/5, 4/3, 7/5, 5/3, \[Infinity]};\)\)], "Input"],

Cell["Differential equation", "Text"],

Cell[BoxData[{
    \(\(a = 10\^\(-6\);\)\), "\[IndentingNewLine]", 
    \(\(b = 10;\)\)}], "Input"],

Cell[BoxData[
    \(\(\[Theta][\[Gamma]_] := 
        y /. NDSolve[{\(y''\)[s] + 2\/s\ \(y'\)[s] + 
                    Abs[y[s]]\^\(1/\((\[Gamma] - 1)\)\) \[Equal] 0, 
                y[a] == 1 - a\^2\/6, \(y'\)[a] == \(-\(a\/3\)\)}, 
              y, {s, a, b}, StoppingTest \[Rule] y[s] \[LessEqual] \ \ 0] // 
          First;\)\)], "Input"],

Cell["Solutions", "Text"],

Cell[BoxData[
    \(sols\  = Map[\[Theta][#] &, \[Gamma]s]\)], "Input"],

Cell["Integration limits", "Text"],

Cell[BoxData[
    \(lims\  = \ Map[#[\([1, 1, 2]\)] &, sols]\)], "Input"],

Cell["Crossings with abscissa", "Text"],

Cell[BoxData[
    \(\(\(sols1 = Drop[sols, 1]\)\(;\)\(\ \)\( (*\ 
      does\ not\ cross\ *) \)\)\)], "Input"],

Cell[BoxData[
    \(s0s = 
      Map[\(FindRoot[#[s], {s, 2, 2.1}, AccuracyGoal \[Rule] 9]\)[\([1, 
              2]\)] &, sols1]\)], "Input"],

Cell["Derivatives,", "Text"],

Cell[BoxData[
    \(\[Theta]ps = MapThread[\(#1'\)[#2] &, {sols1, s0s}]\)], "Input"],

Cell["Central values relative to scale values", "Text"],

Cell[BoxData[
    \(Tratios = MapThread[\(-1\)\/\(#1*#2\) &, {\[Theta]ps, s0s}]\)], "Input"],

Cell[BoxData[
    \(\[Rho]ratios = MapThread[\(#1\^2\/3\) #2 &, {s0s, Tratios}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fig. 6.3 Lane-Emden solutions", "Section"],

Cell[BoxData[
    \(\(plots\  = \ 
        MapThread[
          Plot[#1[s], {s, a, #2}, DisplayFunction \[Rule] Identity] &, {sols, 
            lims}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[plots, 
          Graphics[{Dashing[{0.02, 0.02}], Line[{{0, 1}, {b, 1}}], 
              Text["\<\[Infinity]\>", {2.5, 0.05}], 
              Text["\<6/5\>", {8, 0.25}], Text["\<5/3\>", {3.7, 0.05}], 
              Text["\<7/5\>", {5.1, 0.05}], Text["\<4/3\>", {6.3, 0.06}], 
              Text["\<\[Gamma]=1\>", {7, 0.95}]}], 
          DisplayFunction \[Rule] $DisplayFunction, 
          PlotRange \[Rule] {{a, b}, {0, 1}}, 
          AxesLabel \[Rule] {"\<\[Xi]\>", "\<\[Theta]\>"}] \
// \[IndentingNewLine]Figure["\<planets1\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Solar central properties", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Gamma] = 5/3;\)\), "\n", 
    \(\(M\_mol = 0.5  Gram/Mole;\)\), "\n", 
    \(\(R = MolarGasConstant // N;\)\), "\n", 
    \(\(M\_0 = SunMass // N;\)\), "\n", 
    \(\(a = SunRadius // N;\)\), "\n", 
    \(\(G = GravitationalConstant // N;\)\), "\[IndentingNewLine]", 
    \(\(Tratio = Tratios[\([3]\)];\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]ratio = \[Rho]ratios[\([3]\)];\)\)}], "Input"],

Cell["Average density", "Text"],

Cell[BoxData[
    \(\[Rho]\_0 = M\_0\/\(\(4\/3\) \[Pi]\ a\^3\) // ToSI\)], "Input"],

Cell["Scale temperature", "Text"],

Cell[BoxData[
    \(T\_0 = \(\(\[Gamma] - 1\)\/\[Gamma]\) M\_mol\/R\ G\ M\_0\/a // 
        ToSI\)], "Input"],

Cell["Central temperature", "Text"],

Cell[BoxData[
    \(T\_c = T\_0*Tratio\)], "Input"],

Cell["Central density", "Text"],

Cell[BoxData[
    \(\[Rho]\_c = \[Rho]\_0*\[Rho]ratio\)], "Input"],

Cell["Central pressure", "Text"],

Cell[BoxData[
    \(p\_c = \(\[Rho]\_c\ R\ T\_c\)\/M\_mol // ToUnit[Bar]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fig. 6.4 Solar temperature distribution", "Section"],

Cell[BoxData[{
    \(\(a0 = a\/10\^3 // NToUnit[Kilometer];\)\), "\[IndentingNewLine]", 
    \(\(\[Lambda] = a0\/s0s[\([\(-2\)]\)];\)\)}], "Input"],

Cell[BoxData[
    \(T\_c0 = T\_c // NToUnit[Mega\ Kelvin]\)], "Input"],

Cell[BoxData[
    \(\(fig2b = 
        Plot[T\_c0\ \ \(sols[\([\(-2\)]\)]\)[r/\[Lambda]], {r, 1.9, a0}, 
          PlotStyle -> {Dashing[{0.02}]}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Solar data", "Section"],

Cell[BoxData[{
    \(\(file = OpenRead["\<Planets.dat\>"];\)\), "\n", 
    \(\(Skip[file, String, 4];\)\), "\n", 
    \(\(data = ReadList[file, Number, RecordLists -> True];\)\), "\n", 
    \(\(Close[file];\)\)}], "Input"],

Cell[BoxData[
    \(\(radius = a0\ data[\([All, 1]\)];\)\)], "Input"],

Cell[BoxData[
    \(\(temperature = \ \(10\^\(-6\)\) data[\([All, 5]\)];\)\)], "Input"],

Cell[BoxData[
    \(\(fig2a = 
        ListPlot[Thread[List[radius, temperature]], PlotJoined -> True, 
          AxesLabel -> {\*"\"\<r[\!\(10\^3\)km]\>\"", \
\*"\"\<T[\!\(10\^6\)K]\>\""}, PlotRange -> {0, 16}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig2c = 
        Graphics[{Text["\<Core\>", {100, 15}], 
            Text["\<Radiation\>", {330, 15}], 
            Text["\<Convection\>", {620, 15}], Dashing[{0.01}], 
            Line[{{150, 0}, {150, 16}}], 
            Line[{{500, 0}, {500, 16}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig2a, fig2b, 
          fig2c] // \[IndentingNewLine]Figure["\<planets2\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fig. 6.2 Adiabatic index", "Section"],

Cell[BoxData[
    \(\(adiabatic = 1\/\(1 - data[\([All, 6]\)]\);\)\)], "Input"],

Cell[BoxData[
    \(\(fig3a = 
        ListPlot[Thread[List[radius, adiabatic]], 
          PlotRange -> {{650, 700}, {1, 1.8}}, 
          AxesLabel -> {\*"\"\<r[\!\(10\^3\)km]\>\"", \
\*"\"\<\!\(\[Gamma]\_eff\)\>\""}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig3b = 
        Plot[5/3, {r, 650, 700}, 
          PlotStyle -> {Dashing[{0.02}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig3a, 
          fig3b] // \[IndentingNewLine]Figure["\<planets3\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gravitational energy", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["From potential", "Section"],

Cell[BoxData[
    \(\(\[CapitalPhi][
          r_] = \(-\(1\/2\)\) \(\(G\ M\_0\)\/a\^3\) \((3  a\^2 - 
              r\^2)\);\)\)], "Input"],

Cell[BoxData[
    \(W = \(1\/2\) \(\[Rho]\_0\) \(\[Integral]\_0\%a \[CapitalPhi][r] 
            4  \[Pi]\ \(r\^2\) \[DifferentialD]r\)\)], "Input"],

Cell[BoxData[
    \(\(\[Rho]\_0 = M\_0\/\(\(\(4  \[Pi]\)\/3\) a\^3\);\)\)], "Input"],

Cell[BoxData[
    \(W\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["From mass distribution", "Section"],

Cell[BoxData[{
    \(\(M1 = \(M\_0\) \((r\/a)\)\^3;\)\), "\[IndentingNewLine]", 
    \(\(M2 = M\_0;\)\), "\[IndentingNewLine]", 
    \(W1 = \(-\(1\/2\)\) 
        G \(\[Integral]\_0\%a\( M1\^2\/r\^2\) \[DifferentialD]r\)\)}], "Input"],

Cell[BoxData[
    \(W2 = \(-\(1\/2\)\) 
        G \(\[Integral]\_a\%\[Infinity]\( M2\^2\/r\^2\) \
\[DifferentialD]r\)\)], "Input"],

Cell[BoxData[
    \(W = W1 + W2\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["6.2.1 Moon's central pressure", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(G = GravitationalConstant;\)\), "\n", 
    \(\(a = MoonRadius;\)\), "\[IndentingNewLine]", 
    \(\(M\_0 = MoonMass;\)\)}], "Input",
  InitializationCell->True],

Cell["Density", "Text"],

Cell[BoxData[
    \(\[Rho]\_0 = M\_0\/\(\(4\/3\) \[Pi]\ a\^3\) // ToSI\)], "Input"],

Cell["Central pressure", "Text"],

Cell[BoxData[
    \(p\_c = \(2\/3\) \[Pi]\ G\ \(\[Rho]\_\(\(\ \)\(0\)\)\^2\) a\^2 // 
        ToUnit[Atmosphere]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.3.2 The Sun", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(M\_0 = SunMass;\)\), "\n", 
    \(\(a = SunRadius;\)\), "\n", 
    \(\(G = GravitationalConstant;\)\), "\n", 
    \(\(R = MolarGasConstant;\)\), "\n", 
    \(\(M\_mol = 0.5\ Gram/Mole;\)\)}], "Input"],

Cell["Surface gravity", "Text"],

Cell[BoxData[
    \(g\_0 = \(G\ M\_0\)\/a\^2 // ToSI\)], "Input"],

Cell["Heat capacity", "Text"],

Cell[BoxData[
    \(\(\[Gamma] = 5\/3;\)\)], "Input"],

Cell[BoxData[
    \(c\_p = \[Gamma]\/\(\[Gamma] - 1\)\ R\/M\_mol // 
        ToUnit[Joule]\)], "Input"],

Cell["Temperature scale", "Text"],

Cell[BoxData[
    \(T\_0 = \(\(g\_0\) a\)\/c\_p // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.4.1 Gravitational energies", "Section"],

Cell[CellGroupData[{

Cell["Moon gravitational energy", "Subsection"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(M\_0 = MoonMass;\)\), "\[IndentingNewLine]", 
    \(a = MoonRadius\), "\[IndentingNewLine]", 
    \(\(G = GravitationalConstant;\)\)}], "Input"],

Cell[BoxData[
    \(g\_0 = G\ M\_0\/a\^2 // ToSI\)], "Input"],

Cell[BoxData[
    \(E\_grav = \(-\(3\/5\)\) \(M\_0\) \(g\_0\) a // ToUnit[Joule]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Earth gravitational energy", "Subsection"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(M\_0 = EarthMass;\)\), "\[IndentingNewLine]", 
    \(a = EarthRadius\), "\[IndentingNewLine]", 
    \(\(G = GravitationalConstant;\)\)}], "Input"],

Cell[BoxData[
    \(g\_0 = G\ M\_0\/a\^2 // ToSI\)], "Input"],

Cell[BoxData[
    \(E\_grav = \(-\(3\/5\)\) \(M\_0\) \(g\_0\) a // ToUnit[Joule]\)], "Input"],

Cell[BoxData[
    \(E\_grav\/M\_0 // ToUnit[Joule/Gram]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sun gravitational energy", "Subsection"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(M\_0 = SunMass;\)\), "\[IndentingNewLine]", 
    \(a = SunRadius\), "\[IndentingNewLine]", 
    \(\(G = GravitationalConstant;\)\)}], "Input"],

Cell[BoxData[
    \(g\_0 = G\ M\_0\/a\^2 // ToSI\)], "Input"],

Cell[BoxData[
    \(E\_grav = \(-\(3\/5\)\) \(M\_0\) \(g\_0\) a // ToUnit[Joule]\)], "Input"],

Cell[BoxData[
    \(\(P\_sun = 3.85*^26\ Watt;\)\)], "Input"],

Cell[BoxData[
    \(E\_grav\/P\_sun // ToSI\)], "Input"],

Cell[BoxData[
    \(% // ToUnit[Year]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["6.3 Two-layer planet", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(G = GravitationalConstant;\)\), "\n", 
    \(\(a = EarthRadius;\)\), "\n", 
    \(\(M\_0 = EarthMass;\)\), "\n", 
    \(\(a\_1 = EarthCoreRadius;\)\), "\n", 
    \(\ \(M\_1 = EarthCoreMass;\)\)}], "Input",
  InitializationCell->True],

Cell["Mantle mass", "Text"],

Cell[BoxData[
    \(\(M\_2 = M\_0 - M\_1;\)\)], "Input"],

Cell["Core density", "Text"],

Cell[BoxData[
    \(\(\[Rho]\_1 = 
        M\_1\/\(\(4\/3\) \[Pi]\ a\_1\^\(\(3\)\(\ \)\)\) // ToSI;\)\)], "Input"],

Cell["Mantle density", "Text"],

Cell[BoxData[
    \(\(\[Rho]\_2 = 
        M\_2\/\(\(4\/3\) \[Pi]\ \((a\^3 - a\_1\^3)\)\) // ToSI;\)\)], "Input"],

Cell["Pressures", "Text"],

Cell[BoxData[{
    \(\(p\_1 = \(2\/3\) \[Pi]\ G\ \(\[Rho]\_1\^2\) a\_1\^2 // 
          ToSI;\)\), "\n", 
    \(\(p\_2 = \(2\/3\) \[Pi]\ G\ \(\[Rho]\_2\^2\) \((a\^2 - a\_1\^2)\) // 
          ToSI;\)\), "\n", 
    \(\(p\_3 = \ \(4\/3\) \[Pi]\ G\ \(\[Rho]\_2\) \((\[Rho]\_1 - \[Rho]\_2)\) \
\(a\_1\^3\) \((1\/a\_1 - 1\/a)\) // ToSI;\)\)}], "Input"],

Cell["Central pressure", "Text"],

Cell[BoxData[
    \(p\_c = p\_1 + p\_2 + p\_3 // ToUnit[Mega\ Bar]\)], "Input"],

Cell["Core/mantle pressure", "Text"],

Cell[BoxData[
    \(p\_2 + p\_3 // ToUnit[Mega\ Bar]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 937}},
AutoGeneratedPackage->None,
WindowSize->{774, 806},
WindowMargins->{{191, Automatic}, {Automatic, 27}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 55, 1, 95, "Title",
  InitializationCell->True],
Cell[1834, 56, 72, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1943, 63, 31, 0, 95, "Title"],
Cell[1977, 65, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2048, 70, 34, 0, 73, "Section"],
Cell[2085, 72, 296, 4, 70, "Input"],
Cell[2384, 78, 268, 4, 70, "Input"],
Cell[2655, 84, 53, 1, 30, "Input"],
Cell[2711, 87, 56, 1, 30, "Input"],
Cell[2770, 90, 136, 3, 40, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2943, 98, 33, 0, 73, "Section"],
Cell[2979, 100, 26, 0, 33, "Text"],
Cell[3008, 102, 290, 5, 110, "Input"],
Cell[3301, 109, 54, 0, 33, "Text"],
Cell[3358, 111, 237, 5, 118, "Input"],
Cell[3598, 118, 347, 7, 112, "Input"],
Cell[3948, 127, 32, 0, 33, "Text"],
Cell[3983, 129, 70, 1, 30, "Input"],
Cell[4056, 132, 33, 0, 33, "Text"],
Cell[4092, 134, 132, 3, 30, "Input"],
Cell[4227, 139, 154, 3, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4418, 147, 29, 0, 73, "Section"],
Cell[4450, 149, 160, 3, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4659, 158, 36, 0, 95, "Title"],
Cell[4698, 160, 51, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[4774, 165, 28, 0, 73, "Section"],
Cell[4805, 167, 26, 0, 33, "Text"],
Cell[4834, 169, 83, 1, 30, "Input"],
Cell[4920, 172, 37, 0, 33, "Text"],
Cell[4960, 174, 99, 2, 50, "Input"],
Cell[5062, 178, 345, 6, 88, "Input"],
Cell[5410, 186, 25, 0, 33, "Text"],
Cell[5438, 188, 71, 1, 30, "Input"],
Cell[5512, 191, 34, 0, 33, "Text"],
Cell[5549, 193, 73, 1, 30, "Input"],
Cell[5625, 196, 39, 0, 33, "Text"],
Cell[5667, 198, 110, 2, 30, "Input"],
Cell[5780, 202, 142, 3, 30, "Input"],
Cell[5925, 207, 28, 0, 33, "Text"],
Cell[5956, 209, 84, 1, 30, "Input"],
Cell[6043, 212, 55, 0, 33, "Text"],
Cell[6101, 214, 92, 1, 43, "Input"],
Cell[6196, 217, 92, 1, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6325, 223, 48, 0, 73, "Section"],
Cell[6376, 225, 167, 4, 30, "Input"],
Cell[6546, 231, 577, 10, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7160, 246, 44, 0, 73, "Section"],
Cell[7207, 248, 26, 0, 33, "Text"],
Cell[7236, 250, 417, 8, 170, "Input"],
Cell[7656, 260, 31, 0, 33, "Text"],
Cell[7690, 262, 83, 1, 51, "Input"],
Cell[7776, 265, 33, 0, 33, "Text"],
Cell[7812, 267, 109, 2, 44, "Input"],
Cell[7924, 271, 35, 0, 33, "Text"],
Cell[7962, 273, 51, 1, 30, "Input"],
Cell[8016, 276, 31, 0, 33, "Text"],
Cell[8050, 278, 66, 1, 30, "Input"],
Cell[8119, 281, 32, 0, 33, "Text"],
Cell[8154, 283, 85, 1, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8276, 289, 58, 0, 73, "Section"],
Cell[8337, 291, 147, 2, 76, "Input"],
Cell[8487, 295, 70, 1, 30, "Input"],
Cell[8560, 298, 162, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8759, 306, 30, 0, 73, "Section"],
Cell[8792, 308, 222, 4, 90, "Input"],
Cell[9017, 314, 69, 1, 30, "Input"],
Cell[9089, 317, 87, 1, 30, "Input"],
Cell[9179, 320, 227, 4, 52, "Input"],
Cell[9409, 326, 290, 6, 70, "Input"],
Cell[9702, 334, 119, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9858, 341, 43, 0, 73, "Section"],
Cell[9904, 343, 79, 1, 44, "Input"],
Cell[9986, 346, 235, 5, 52, "Input"],
Cell[10224, 353, 122, 3, 30, "Input"],
Cell[10349, 358, 112, 2, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10510, 366, 37, 0, 95, "Title"],
Cell[10550, 368, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[10621, 373, 33, 0, 73, "Section"],
Cell[10657, 375, 140, 3, 42, "Input"],
Cell[10800, 380, 148, 2, 42, "Input"],
Cell[10951, 384, 84, 1, 51, "Input"],
Cell[11038, 387, 34, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11109, 393, 41, 0, 73, "Section"],
Cell[11153, 395, 234, 4, 98, "Input"],
Cell[11390, 401, 130, 3, 45, "Input"],
Cell[11523, 406, 44, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11616, 413, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[11666, 417, 48, 0, 73, "Section"],
Cell[11717, 419, 51, 1, 30, "Input"],
Cell[11771, 422, 26, 0, 33, "Text"],
Cell[11800, 424, 183, 4, 70, "Input",
  InitializationCell->True],
Cell[11986, 430, 23, 0, 33, "Text"],
Cell[12012, 432, 83, 1, 51, "Input"],
Cell[12098, 435, 32, 0, 33, "Text"],
Cell[12133, 437, 125, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12295, 444, 32, 0, 73, "Section"],
Cell[12330, 446, 46, 1, 30, "Input"],
Cell[12379, 449, 26, 0, 33, "Text"],
Cell[12408, 451, 223, 5, 110, "Input"],
Cell[12634, 458, 31, 0, 33, "Text"],
Cell[12668, 460, 65, 1, 42, "Input"],
Cell[12736, 463, 29, 0, 33, "Text"],
Cell[12768, 465, 53, 1, 42, "Input"],
Cell[12824, 468, 103, 2, 44, "Input"],
Cell[12930, 472, 33, 0, 33, "Text"],
Cell[12966, 474, 68, 1, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13071, 480, 47, 0, 73, "Section"],

Cell[CellGroupData[{
Cell[13143, 484, 47, 0, 38, "Subsection"],
Cell[13193, 486, 46, 1, 30, "Input"],
Cell[13242, 489, 167, 3, 70, "Input"],
Cell[13412, 494, 61, 1, 42, "Input"],
Cell[13476, 497, 93, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13606, 503, 48, 0, 38, "Subsection"],
Cell[13657, 505, 46, 1, 30, "Input"],
Cell[13706, 508, 169, 3, 70, "Input"],
Cell[13878, 513, 61, 1, 42, "Input"],
Cell[13942, 516, 93, 1, 42, "Input"],
Cell[14038, 519, 68, 1, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14143, 525, 46, 0, 38, "Subsection"],
Cell[14192, 527, 46, 1, 30, "Input"],
Cell[14241, 530, 165, 3, 70, "Input"],
Cell[14409, 535, 61, 1, 42, "Input"],
Cell[14473, 538, 93, 1, 42, "Input"],
Cell[14569, 541, 61, 1, 30, "Input"],
Cell[14633, 544, 56, 1, 45, "Input"],
Cell[14692, 547, 50, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14803, 555, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[14853, 559, 39, 0, 73, "Section"],
Cell[14895, 561, 46, 1, 30, "Input"],
Cell[14944, 564, 26, 0, 33, "Text"],
Cell[14973, 566, 256, 6, 110, "Input",
  InitializationCell->True],
Cell[15232, 574, 27, 0, 33, "Text"],
Cell[15262, 576, 56, 1, 30, "Input"],
Cell[15321, 579, 28, 0, 33, "Text"],
Cell[15352, 581, 114, 2, 51, "Input"],
Cell[15469, 585, 30, 0, 33, "Text"],
Cell[15502, 587, 113, 2, 51, "Input"],
Cell[15618, 591, 25, 0, 33, "Text"],
Cell[15646, 593, 347, 6, 112, "Input"],
Cell[15996, 601, 32, 0, 33, "Text"],
Cell[16031, 603, 79, 1, 30, "Input"],
Cell[16113, 606, 36, 0, 33, "Text"],
Cell[16152, 608, 65, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

