(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     35525,       1338]*)
(*NotebookOutlinePosition[     36196,       1361]*)
(*  CellTagsIndexPosition[     36152,       1357]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["8. Surface Tension", "Title"],

Cell["<< Lautrup`", "Input",
  PageWidth->Infinity,
  InitializationCell->True,
  ShowSpecialCharacters->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["8.1.1 Water estimate", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(N\_A = AvogadroConstant;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = 1\ Gram/Centimeter\^3;\)\), "\[IndentingNewLine]", 
    \(\(M\_mol = WaterMolarMass;\)\)}], "Input"],

Cell[BoxData[
    \(L\_mol = \((M\_mol\/\(\[Rho]\ N\_A\))\)\^\(1/3\) // 
        ToUnit[Nano\ Meter]\)], "Input"],

Cell[BoxData[
    \(H = 536  Calorie/Gram // ToUnit[Joule]\)], "Input"],

Cell[BoxData[
    \(\[Epsilon] = \(H\ M\_mol\)\/N\_A // ToUnit[Joule]\)], "Input"],

Cell[BoxData[
    \(\[Alpha] = \(1\/6\) \[Epsilon]\/L\_mol\^2 // ToUnit[Joule]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.1.2 Raindrop", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = \(10\^3\) Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(a = 0.5\ Milli\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(\[Alpha] = 0.073\ Newton/Meter;\)\)}], "Input"],

Cell[BoxData[
    \(\[CapitalDelta]p = \(2  \[Alpha]\)\/a // ToUnit[Pascal]\)], "Input"],

Cell["Pressure in bacterium-size bubble", "Text"],

Cell[BoxData[
    \(\(a = 0.5\ Micrometer;\)\)], "Input"],

Cell[BoxData[
    \(\[CapitalDelta]p = \(2  \[Alpha]\)\/a // ToUnit[Atmosphere]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.1.3 Sap", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = \(10\^3\) Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(a = 0.5\ Micrometer;\)\), "\[IndentingNewLine]", 
    \(\(\[Alpha] = 0.073\ Newton/Meter;\)\), "\[IndentingNewLine]", 
    \(\(\[Chi]\_c = 0;\)\)}], "Input"],

Cell[BoxData[
    \(\[CapitalDelta]p = \(2  \[Alpha]\)\/a // ToUnit[Atmosphere]\)], "Input"],

Cell[BoxData[
    \(h = \[CapitalDelta]p\/\(\(\[Rho]\_0\) g\_0\) // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.2.1 Walking on water", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\n", 
    \(\(\[Alpha] = 0.073\ Newton/Meter;\)\), "\[IndentingNewLine]", 
    \(\(M = 10\ Milli\ Gram;\)\)}], "Input"],

Cell["Jesus number length", "Text"],

Cell[BoxData[
    \(L = \(M\ g\_0\)\/\[Alpha] // ToUnit[Millimeter]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.2.2 Capillary tube", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Parameters in water", "Subsection"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = \(10\^3\) Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(a = 0.5\ Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[Alpha] = 0.073\ Newton/Meter;\)\), "\[IndentingNewLine]", 
    \(\(\[Chi]\_c = 0;\)\)}], "Input"],

Cell["Capillary length", "Text"],

Cell[BoxData[
    \(R\_c = \@\(\[Alpha]\/\(\(\[Rho]\_0\) g\_0\)\) // 
        ToUnit[Millimeter]\)], "Input"],

Cell["Capillary rise", "Text"],

Cell[BoxData[
    \(h = \ 2\ \(R\_c\^2\/a\) Cos[\[Chi]\_c] // ToUnit[Millimeter]\)], "Input"],

Cell["Meniscus depth", "Text"],

Cell[BoxData[
    \(d = a\ \(1 - Sin[\[Chi]\_c]\)\/Cos[\[Chi]\_c]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameters in mercury", "Subsection"],

Cell[BoxData[{
    \(\(\[Rho]\_0 = 
        13.6\ \(10\^3\) Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(\[Alpha] = 0.485\ Newton/Meter;\)\), "\[IndentingNewLine]", 
    \(\(\[Chi]\_c = 140\ \[Degree];\)\)}], "Input"],

Cell["Capillary length", "Text"],

Cell[BoxData[
    \(R\_c = \@\(\[Alpha]\/\(\(\[Rho]\_0\) g\_0\)\) // 
        ToUnit[Millimeter]\)], "Input"],

Cell["Capillary rise", "Text"],

Cell[BoxData[
    \(h = \ 2\ \(R\_c\^2\/a\) Cos[\[Chi]\_c] // ToUnit[Millimeter]\)], "Input"],

Cell["Meniscus depth", "Text"],

Cell[BoxData[
    \(d = a\ \(1 - Sin[\[Chi]\_c]\)\/Cos[\[Chi]\_c]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Planar capillary shapes", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Parametric solution", "Section"],

Cell[BoxData[
    \(\(z[\[Theta]_] = \(-2\) Sin[\[Theta]\/2];\)\)], "Input"],

Cell[BoxData[
    \(\(x[\[Theta]_] = \(-2\) Cos[\[Theta]\/2] - 
          Log[Abs[Tan[\[Theta]\/4]]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Water shape", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Chi] = 1  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(\[Theta]\_0 = \[Chi] - 90  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(R\_c = 2.728356\ Millimeter;\)\)}], "Input"],

Cell["Depth ", "Text"],

Cell[BoxData[
    \(d = z[\[Theta]\_0] R\_c // N\)], "Input"],

Cell["Plot water shape", "Text"],

Cell[BoxData[{
    \(\(x\_0 = x[\[Theta]\_0] // N;\)\), "\[IndentingNewLine]", 
    \(\(x\_1 = x\_0 + 4;\)\), "\[IndentingNewLine]", 
    \(\[Theta]\_1 = \[Theta] /. 
        FindRoot[
          x[\[Theta]] \[Equal] x\_1, {\[Theta], 0.001  \[Theta]\_0, 
            0.002  \[Theta]\_0}]\)}], "Input"],

Cell[BoxData[
    \(\(fig5a = 
        ParametricPlot[{x[\[Theta]] - x\_0, 
            z[\[Theta]]}, {\[Theta], \[Theta]\_0, \[Theta]\_1}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mercury shape", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Chi] = 140  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(\[Theta]\_0 = \[Chi] - 90  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(R\_c = 1.90696\ Millimeter;\)\)}], "Input"],

Cell[BoxData[
    \(d = z[\[Theta]\_0] R\_c // N\)], "Input"],

Cell[BoxData[{
    \(\(x\_0 = x[\[Theta]\_0];\)\), "\[IndentingNewLine]", 
    \(\(x\_1 = x\_0 + 4;\)\), "\[IndentingNewLine]", 
    \(\[Theta]\_1 = \[Theta] /. 
        FindRoot[
          x[\[Theta]] \[Equal] x\_1, {\[Theta], 0.001  \[Theta]\_0, 
            0.002  \[Theta]\_0}]\)}], "Input"],

Cell[BoxData[
    \(\(fig5b = 
        ParametricPlot[{x[\[Theta]] - x\_0, 
            z[\[Theta]]}, {\[Theta], \[Theta]\_0, \[Theta]\_1}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make margin figure", "Section"],

Cell[BoxData[
    \(\(Show[fig5a, fig5b, AspectRatio \[Rule] 1.5, 
          PlotRange \[Rule] {\(-1\), 1.5}, 
          AxesLabel \[Rule] {"\<x\>", "\<z\>"}, 
          ImageSize \[Rule] 300] // \[IndentingNewLine]Figure["\<surface5\>", 
          ImageSize \[Rule] 150];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Axial capillary shapes", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Define solution", "Section"],

Cell["Water parameters", "Text"],

Cell[BoxData[{
    \(\(\[Chi]\_c = 1  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(\[Epsilon] = 10\^\(-6\);\)\), "\[IndentingNewLine]", 
    \(\(\[Theta]max = \[Pi]\/2;\)\)}], "Input"],

Cell[BoxData[
    \(\(\[Theta]\_c = 90  \[Degree] - \[Chi]\_c;\)\)], "Input"],

Cell["Radii of curvature", "Text"],

Cell[BoxData[
    \(R\_2[\[Theta]_, R0_] := 
      If[Abs[\[Theta]] > \[Epsilon], r[\[Theta]]\/Sin[\[Theta]], 
        R0]\)], "Input"],

Cell[BoxData[
    \(R\_1[\[Theta]_, R0_] := 
      1\/\(2\/R0 - 1\/R\_2[\[Theta], R0] + \ \ z[\[Theta]]\)\)], "Input"],

Cell["Solve differential equations", "Text"],

Cell[BoxData[
    \(sol[R0_?NumericQ] := 
      NDSolve[{\(r'\)[\[Theta]] \[Equal] 
              Cos[\[Theta]] R\_1[\[Theta], R0]\ , \(z'\)[\[Theta]] \[Equal] 
              Sin[\[Theta]] R\_1[\[Theta], R0], r[0] \[Equal] 0, 
            z[0] \[Equal] 0}, {r, z}, {\[Theta], 0, \[Theta]max}] // 
        First\)], "Input"],

Cell["Radius, depth and height", "Text"],

Cell[BoxData[
    \(a[R0_?NumericQ] := \(\(r[\[Theta]\_c]\)\(/.\)\(sol[
          R0]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(d[R0_?NumericQ] := z[\[Theta]\_c] /. sol[R0]\)], "Input"],

Cell[BoxData[
    \(h[R0_?NumericQ] := 2\/R0\)], "Input"],

Cell["Show radius", "Text"],

Cell[BoxData[
    \(\(Plot[a[R0], {R0, \[Epsilon], 30}];\)\)], "Input"],

Cell["Show depth", "Text"],

Cell[BoxData[
    \(\(Plot[d[R0], {R0, \[Epsilon], 30}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of solution", "Section"],

Cell[BoxData[
    \(\(\[Theta]max = 4  \[Pi];\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[
          Evaluate[{r[\[Theta]], z[\[Theta]]} /. sol[1]], {\[Theta], 
            0, \[Theta]max}, AspectRatio \[Rule] 1, 
          AxesLabel \[Rule] {"\<r\>", "\<z\>"}] \
// \[IndentingNewLine]Figure["\<surface6\>", 
          ImageSize \[Rule] 150];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot shape", "Section"],

Cell[BoxData[
    \(\(\[Theta]max = \[Pi]\/2;\)\)], "Input"],

Cell["Central curvature", "Text"],

Cell[BoxData[
    \(R0[aa_?NumericQ] := 
      Module[{R0}, R0 /. FindRoot[a[R0] == aa, {R0, 1, 0.9}]]\)], "Input"],

Cell["Show it", "Text"],

Cell[BoxData[
    \(\(Plot[R0[aa], {aa, 1, 10}, PlotRange \[Rule] {0, 1000}];\)\)], "Input"],

Cell["Choice of radii", "Text"],

Cell[BoxData[
    \(\(as = {0.01, 1, 2, 3, 5, 10};\)\)], "Input"],

Cell["Corresponding central curvatures", "Text"],

Cell[BoxData[
    \(R0s = Map[R0, as]\)], "Input"],

Cell["Corresponding depths", "Text"],

Cell[BoxData[
    \(das = Map[d[#]\/a[#] &, R0s]\)], "Input"],

Cell["Plot shapes", "Text"],

Cell[BoxData[
    \(\(texts = 
        MapThread[
          Text[#1, {1.01, #2}, {\(-1\), 0}] &, {as, das}];\)\)], "Input"],

Cell[BoxData[
    \(\(texts[\([1, 1]\)] = 0;\)\)], "Input"],

Cell[BoxData[
    \(\(funs = 
        MapThread[{r[\[Theta]]\/#1, z[\[Theta]]\/#1} /. sol[#2] &, {as, 
            R0s}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig7 = 
        ParametricPlot[funs // Evaluate, {\[Theta], 0, \[Theta]\_c}, 
            AxesLabel \[Rule] {"\<r/a\>", "\<z/a\>"}, PlotLabel -> "\<(a)\>", 
            AspectRatio \[Rule] 1, PlotRange \[Rule] {{0, 1.07}, {0, 1.07}}, 
            PlotStyle \[Rule] 
              texts] // \[IndentingNewLine]Figure["\<surface7\>", 
            ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot parameters", "Section"],

Cell["Extremes of range", "Text"],

Cell[BoxData[
    \(R1 = R0[\[Epsilon]]\)], "Input"],

Cell[BoxData[
    \(R2 = R0[10]\)], "Input"],

Cell["Determine radius for maximum depth", "Text"],

Cell[BoxData[
    \(FindMaximum[d[R0], {R0, 10, 9.9}]\)], "Input"],

Cell[BoxData[
    \(a[67]\)], "Input"],

Cell["Plot depth and height as function of radius", "Text"],

Cell[BoxData[
    \(\(fig8a = 
        ParametricPlot[{{a[R0], d[R0]}, {a[R0], h[R0]}}, {R0, R1, R2}, 
          PlotRange \[Rule] {{0, 10}, {0, 3}}, 
          PlotPoints \[Rule] 300];\)\)], "Input"],

Cell["Plot estimates of depth and height", "Text"],

Cell[BoxData[
    \(\(fig8b = 
        Plot[{a \( 1 - Sin[\[Chi]\_c]\)\/Cos[\[Chi]\_c], \(2\/a\) 
              Cos[\[Chi]\_c]}, {a, 0, 10}, PlotRange \[Rule] {0, 3}, 
          PlotStyle \[Rule] {Dashing[{0.02}]}];\)\)], "Input"],

Cell["Show final graph", "Text"],

Cell[BoxData[
    \(\(Show[fig8a, fig8b, 
          Graphics[{Text["\<h\>", {3, 0.25}, {\(-1\), \(-1\)}], 
              Text["\<d\>", {3, 1.45}, {\(-1\), \(-1\)}]}], 
          AxesLabel \[Rule] {"\<a\>", "\<\>"}, AspectRatio \[Rule] 1, 
          PlotLabel -> "\<(b)\>"] \
// \[IndentingNewLine]Figure["\<surface8\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sessile air bubbles in water ", "Title"],

Cell[CellGroupData[{

Cell["Define solution", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Chi] = 1  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(\[Epsilon] = 10\^\(-6\);\)\), "\[IndentingNewLine]", 
    \(\(\[Theta]max = \[Pi];\)\)}], "Input"],

Cell["Contact angle", "Text"],

Cell[BoxData[
    \(\(\[Theta]\_c = 180  \[Degree] - \[Chi];\)\)], "Input"],

Cell["Radii of curvature", "Text"],

Cell[BoxData[
    \(R\_2[\[Theta]_, R0_] := 
      If[Abs[\[Theta]] > \[Epsilon], r[\[Theta]]\/Sin[\[Theta]], 
        R0]\)], "Input"],

Cell[BoxData[
    \(R\_1[\[Theta]_, R0_] := 
      1\/\(2\/R0 - 1\/R\_2[\[Theta], R0] + \ \ z[\[Theta]]\)\)], "Input"],

Cell["Differential equations", "Text"],

Cell[BoxData[
    \(sol[R0_?NumericQ] := 
      NDSolve[{\(r'\)[\[Theta]] \[Equal] 
              Cos[\[Theta]] R\_1[\[Theta], R0]\ , \(z'\)[\[Theta]] \[Equal] 
              Sin[\[Theta]] R\_1[\[Theta], R0], r[0] \[Equal] 0, 
            z[0] \[Equal] 0}, {r, z}, {\[Theta], 0, \[Theta]max}] // 
        First\)], "Input"],

Cell["Radius and depth", "Text"],

Cell[BoxData[
    \(a[R0_?NumericQ] := \(\(r[\[Theta]\_c]\)\(/.\)\(sol[
          R0]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(d[R0_?NumericQ] := z[\[Theta]\_c] /. sol[R0]\)], "Input"],

Cell[BoxData[
    \(\(Plot[a[R0], {R0, \[Epsilon], 1000}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[d[R0], {R0, \[Epsilon], 1000}];\)\)], "Input"],

Cell[BoxData[
    \(d[10\^16]\)], "Input"],

Cell[BoxData[
    \(d\_est = \@\(2 \((1 + Cos[\[Chi]])\)\) // N\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot solution", "Section"],

Cell["Central curvature", "Text"],

Cell[BoxData[
    \(R0[dd_?NumericQ] := 
      R0 /. FindRoot[d[R0] \[Equal] dd, {R0, 1, 0.99}]\)], "Input"],

Cell["Maximum depth, central curvature and radius", "Text"],

Cell[BoxData[
    \(max = FindMaximum[d[R0], {R0, 10, 9.9}]\)], "Input"],

Cell[BoxData[{
    \(dmax = max[\([1]\)]\), "\[IndentingNewLine]", 
    \(Rmax = R0 /. max[\([2]\)]\), "\[IndentingNewLine]", 
    \(amax = a[Rmax]\)}], "Input"],

Cell["Choice of central curvatures", "Text"],

Cell[BoxData[
    \(R0s = Rmax {0.01, 0.03, 0.1, 0.3, 1}\)], "Input"],

Cell["Corresponding depths and radii", "Text"],

Cell[BoxData[
    \(ds = Map[d, R0s]\)], "Input"],

Cell[BoxData[
    \(as = Map[a, R0s]\)], "Input"],

Cell["Max radius at rectangular poing", "Text"],

Cell[BoxData[
    \(amax = r[\[Pi]\/2] /. sol[Rmax]\)], "Input"],

Cell["Plot functions", "Text"],

Cell[BoxData[
    \(\(funs = 
        MapThread[{r[\[Theta]], z[\[Theta]] - #1} /. sol[#2] &, {ds, 
              R0s}] \[Union] 
          MapThread[{\(-r[\[Theta]]\), z[\[Theta]] - #1} /. sol[#2] &, {ds, 
              R0s}];\)\)], "Input"],

Cell["Correct aspect ratio", "Text"],

Cell[BoxData[
    \(aspect = dmax\/\(2  amax\)\)], "Input"],

Cell[BoxData[
    \(\(fig9a = 
        ParametricPlot[funs // Evaluate, {\[Theta], 0, \[Theta]\_c}, 
          AspectRatio \[Rule] aspect, PlotRange \[Rule] All];\)\)], "Input"],

Cell["Family of bubble shapes", "Text"],

Cell[BoxData[
    \(\(Show[fig9a, 
          Graphics[{Line[{{\(-amax\), 0.04}, {amax, 0.04}}], 
              Text["\<(a)\>", {4.3, \(-0.9\)}]}], 
          Axes \[Rule] False] // \[IndentingNewLine]Figure["\<surface9\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Sessile\)]],
  " air bubbles in mercury"
}], "Title"],

Cell[CellGroupData[{

Cell["Define solution", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Chi] = 140  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(\[Epsilon] = 10\^\(-6\);\)\), "\[IndentingNewLine]", 
    \(\(\[Theta]max = \[Pi];\)\)}], "Input"],

Cell["Contact angle", "Text"],

Cell[BoxData[
    \(\(\[Theta]\_c = 180  \[Degree] - \[Chi];\)\)], "Input"],

Cell["Radii of curvature", "Text"],

Cell[BoxData[
    \(R\_2[\[Theta]_, R0_] := 
      If[Abs[\[Theta]] > \[Epsilon], r[\[Theta]]\/Sin[\[Theta]], 
        R0]\)], "Input"],

Cell[BoxData[
    \(R\_1[\[Theta]_, R0_] := 
      1\/\(2\/R0 - 1\/R\_2[\[Theta], R0] + \ \ z[\[Theta]]\)\)], "Input"],

Cell["Differential equation", "Text"],

Cell[BoxData[
    \(sol[R0_?NumericQ] := 
      NDSolve[{\(r'\)[\[Theta]] \[Equal] 
              Cos[\[Theta]] R\_1[\[Theta], R0]\ , \(z'\)[\[Theta]] \[Equal] 
              Sin[\[Theta]] R\_1[\[Theta], R0], r[0] \[Equal] 0, 
            z[0] \[Equal] 0}, {r, z}, {\[Theta], 0, \[Theta]max}] // 
        First\)], "Input"],

Cell["Radius and depth", "Text"],

Cell[BoxData[
    \(a[R0_?NumericQ] := \(\(r[\[Theta]\_c]\)\(/.\)\(sol[
          R0]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(d[R0_?NumericQ] := z[\[Theta]\_c] /. sol[R0]\)], "Input"],

Cell[BoxData[
    \(\(Plot[a[R0], {R0, \[Epsilon], 1000}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[d[R0], {R0, \[Epsilon], 1000}];\)\)], "Input"],

Cell["Compare with estimate", "Text"],

Cell[BoxData[
    \(d\_est = \@\(2 \((1 + Cos[\[Chi]])\)\) // N\)], "Input"],

Cell[BoxData[
    \(d[10\^16]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot solution", "Section"],

Cell["Max central radius", "Text"],

Cell[BoxData[
    \(R0[dd_?NumericQ] := 
      R0 /. FindRoot[d[R0] \[Equal] dd, {R0, 1, 0.99}]\)], "Input"],

Cell[BoxData[
    \(max = FindMaximum[d[R0], {R0, 10, 9.9}]\)], "Input"],

Cell["Other values at maximum", "Text"],

Cell[BoxData[{
    \(dmax = max[\([1]\)]\), "\[IndentingNewLine]", 
    \(Rmax = R0 /. max[\([2]\)]\), "\[IndentingNewLine]", 
    \(amax = a[Rmax]\)}], "Input"],

Cell["Choice of central radius values", "Text"],

Cell[BoxData[
    \(R0s = Rmax {0.01, 0.03, 0.1, 0.3, 1}\)], "Input"],

Cell[BoxData[
    \(ds = Map[d, R0s]\)], "Input"],

Cell[BoxData[
    \(as = Map[a, R0s]\)], "Input"],

Cell[BoxData[
    \(amax = r[\[Pi]\/2] /. sol[Rmax]\)], "Input"],

Cell[BoxData[
    \(\(funs = 
        MapThread[{r[\[Theta]], z[\[Theta]] - #1} /. sol[#2] &, {ds, 
              R0s}] \[Union] 
          MapThread[{\(-r[\[Theta]]\), z[\[Theta]] - #1} /. sol[#2] &, {ds, 
              R0s}];\)\)], "Input"],

Cell[BoxData[
    \(aspect = dmax\/\(2  amax\)\)], "Input"],

Cell[BoxData[
    \(\(fig9a = 
        ParametricPlot[funs // Evaluate, {\[Theta], 0, \[Theta]\_c}, 
          AspectRatio \[Rule] aspect, PlotRange \[Rule] All];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig9a, 
          Graphics[{Line[{{\(-amax\), 0.04}, {amax, 0.04}}], 
              Text["\<(c)\>", {4.3, \(-0.25\)}]}], 
          Axes \[Rule] False] // \[IndentingNewLine]Figure["\<surface12\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sessile droplets in mercury", "Title"],

Cell[CellGroupData[{

Cell["Define solution", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Chi] = 140  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(\[Epsilon] = 10\^\(-6\);\)\), "\[IndentingNewLine]", 
    \(\(\[Theta]max = \(-180\) \[Degree];\)\)}], "Input"],

Cell[BoxData[
    \(\(\[Theta]\_c = \ \(-\[Chi]\);\)\)], "Input"],

Cell["Radii of curvature", "Text"],

Cell[BoxData[
    \(R\_2[\[Theta]_, R0_] := 
      If[Abs[\[Theta]] > \[Epsilon], r[\[Theta]]\/Sin[\[Theta]], 
        R0]\)], "Input"],

Cell[BoxData[
    \(R\_1[\[Theta]_, R0_] := 
      1\/\(2\/R0 - 1\/R\_2[\[Theta], R0] + \ \ z[\[Theta]]\)\)], "Input"],

Cell["Differential equations", "Text"],

Cell[BoxData[
    \(sol[R0_?NumericQ] := 
      NDSolve[{\(r'\)[\[Theta]] \[Equal] 
              Cos[\[Theta]] R\_1[\[Theta], R0]\ , \(z'\)[\[Theta]] \[Equal] 
              Sin[\[Theta]] R\_1[\[Theta], R0], r[0] \[Equal] 0, 
            z[0] \[Equal] 0}, {r, z}, {\[Theta], 0, \[Theta]max}] // 
        First\)], "Input"],

Cell[BoxData[
    \(a[R0_?NumericQ] := \(\(r[\[Theta]\_c]\)\(/.\)\(sol[
          R0]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(d[R0_?NumericQ] := \(-z[\[Theta]\_c]\) /. sol[R0]\)], "Input"],

Cell[BoxData[
    \(\(Plot[a[R0], {R0, \(-\[Epsilon]\), \(-1000\)}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[d[R0], {R0, \(-\[Epsilon]\), \(-1000\)}];\)\)], "Input"],

Cell[BoxData[
    \(d\_est = \@\(2 \((1 - Cos[\[Chi]])\)\) // N\)], "Input"],

Cell[BoxData[
    \(d[\(-10\^18\)]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot solution", "Section"],

Cell["Maximum central radius", "Text"],

Cell[BoxData[
    \(R0[dd_?NumericQ] := 
      R0 /. FindRoot[d[R0] \[Equal] dd, {R0, \(-1\), \(-0.99\)}]\)], "Input"],

Cell[BoxData[
    \(max = FindMaximum[d[R0], {R0, \(-10\), \(-9.9\)}]\)], "Input"],

Cell[BoxData[{
    \(dmax = max[\([1]\)]\), "\[IndentingNewLine]", 
    \(Rmax = R0 /. max[\([2]\)]\), "\[IndentingNewLine]", 
    \(amax = a[Rmax]\)}], "Input"],

Cell["Choice of radii", "Text"],

Cell[BoxData[
    \(R0s = Rmax {0.01, 0.03, 0.1, 0.3, 1}\)], "Input"],

Cell[BoxData[
    \(ds = Map[d, R0s]\)], "Input"],

Cell[BoxData[
    \(as = Map[a, R0s]\)], "Input"],

Cell[BoxData[
    \(\(funs = 
        MapThread[{r[\[Theta]], z[\[Theta]] + #1} /. sol[#2] &, {ds, 
              R0s}] \[Union] 
          MapThread[{\(-r[\[Theta]]\), z[\[Theta]] + #1} /. sol[#2] &, {ds, 
              R0s}];\)\)], "Input"],

Cell[BoxData[
    \(aspect = dmax\/\(2  amax\)\)], "Input"],

Cell[BoxData[
    \(\(fig9a = 
        ParametricPlot[funs // Evaluate, {\[Theta], 0, \[Theta]\_c}, 
          AspectRatio \[Rule] aspect, PlotRange \[Rule] All];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig9a, 
          Graphics[{Line[{{\(-amax\), \(-0.04\)}, {amax, \(-0.04\)}}], 
              Text["\<(d)\>", {4.3, 0.9}]}], 
          Axes \[Rule] False] // \[IndentingNewLine]Figure["\<surface10\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sessile droplets in water", "Title"],

Cell[CellGroupData[{

Cell["Define solution", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Chi] = 1  \[Degree];\)\), "\[IndentingNewLine]", 
    \(\(\[Epsilon] = 10\^\(-6\);\)\), "\[IndentingNewLine]", 
    \(\(\[Theta]max = \(-180\) \[Degree];\)\)}], "Input"],

Cell[BoxData[
    \(\(\[Theta]\_c = \ \(-\[Chi]\);\)\)], "Input"],

Cell["Radii of curvature", "Text"],

Cell[BoxData[
    \(R\_2[\[Theta]_, R0_] := 
      If[Abs[\[Theta]] > \[Epsilon], r[\[Theta]]\/Sin[\[Theta]], 
        R0]\)], "Input"],

Cell[BoxData[
    \(R\_1[\[Theta]_, R0_] := 
      1\/\(2\/R0 - 1\/R\_2[\[Theta], R0] + \ \ z[\[Theta]]\)\)], "Input"],

Cell["Differential equations", "Text"],

Cell[BoxData[
    \(sol[R0_?NumericQ] := 
      NDSolve[{\(r'\)[\[Theta]] \[Equal] 
              Cos[\[Theta]] R\_1[\[Theta], R0]\ , \(z'\)[\[Theta]] \[Equal] 
              Sin[\[Theta]] R\_1[\[Theta], R0], r[0] \[Equal] 0, 
            z[0] \[Equal] 0}, {r, z}, {\[Theta], 0, \[Theta]max}] // 
        First\)], "Input"],

Cell[BoxData[
    \(a[R0_?NumericQ] := \(\(r[\[Theta]\_c]\)\(/.\)\(sol[
          R0]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(d[R0_?NumericQ] := \(-z[\[Theta]\_c]\) /. sol[R0]\)], "Input"],

Cell[BoxData[
    \(\(Plot[a[R0], {R0, \(-\[Epsilon]\), \(-1000\)}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[d[R0], {R0, \(-\[Epsilon]\), \(-1000\)}];\)\)], "Input"],

Cell[BoxData[
    \(d\_est = \@\(2 \((1 - Cos[\[Chi]])\)\) // N\)], "Input"],

Cell[BoxData[
    \(d[\(-10\^18\)]\)], "Input"],

Cell[BoxData[
    \(\(d\_est\) 2.7\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot solution", "Section"],

Cell["Maximum depth", "Text"],

Cell[BoxData[
    \(max = FindMaximum[d[R0], {R0, \(-10\), \(-9.9\)}]\)], "Input"],

Cell[BoxData[{
    \(dmax = max[\([1]\)]\), "\[IndentingNewLine]", 
    \(Rmax = R0 /. max[\([2]\)]\), "\[IndentingNewLine]", 
    \(amax = a[Rmax]\)}], "Input"],

Cell["Choice of central radii", "Text"],

Cell[BoxData[
    \(R0s = Rmax {0.01, 0.03, 0.1, 0.3, 1}\)], "Input"],

Cell[BoxData[
    \(ds = Map[d, R0s]\)], "Input"],

Cell[BoxData[
    \(as = Map[a, R0s]\)], "Input"],

Cell[BoxData[
    \(\(funs = 
        MapThread[{r[\[Theta]], z[\[Theta]] + #1} /. sol[#2] &, {ds, 
              R0s}] \[Union] 
          MapThread[{\(-r[\[Theta]]\), z[\[Theta]] + #1} /. sol[#2] &, {ds, 
              R0s}];\)\)], "Input"],

Cell[BoxData[
    \(\(factor = 40;\)\)], "Input"],

Cell[BoxData[
    \(aspect = factor  dmax\/\(2  amax\)\)], "Input"],

Cell[BoxData[
    \(\(fig9a = 
        ParametricPlot[funs // Evaluate, {\[Theta], 0, \[Theta]\_c}, 
          AspectRatio \[Rule] aspect, PlotRange \[Rule] All];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig9a, 
          Graphics[{Line[{{\(-amax\), \(-0.001\)}, {amax, \(-0.001\)}}], 
              Text["\<(b)\>", {4.5, 0.007}]}], 
          Axes \[Rule] False] // \[IndentingNewLine]Figure["\<surface11\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pending droplets", "Title"],

Cell[CellGroupData[{

Cell["Define solution", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Epsilon] = 10\^\(-6\);\)\), "\[IndentingNewLine]", 
    \(\(smax = 20;\)\)}], "Input"],

Cell["Differential equations", "Text"],

Cell[BoxData[
    \(sol[R0_?NumericQ] := 
      Module[{s}, 
        NDSolve[{\(r'\)[s] \[Equal] Cos[\[Theta][s]], \(z'\)[s] \[Equal] 
                Sin[\[Theta][s]], \(\[Theta]'\)[s] \[Equal] 
                2\/R0 - 
                  If[Abs[\[Theta][s]] > \[Epsilon], Sin[\[Theta][s]]\/r[s], 
                    1\/R0] - \ z[s], r[0] \[Equal] 0, 
              z[0] \[Equal] 0, \[Theta][0] \[Equal] 0}, {r, z, \[Theta]}, {s, 
              0, smax}] // First]\)], "Input"],

Cell[BoxData[
    \(\(Plot[Evaluate[\[Theta][s] /. sol[1/3]], {s, 0, smax}, 
        AxesLabel \[Rule] {"\<s\>", "\<\[Theta]\>"}];\)\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[Evaluate[{r[s], z[s]} /. sol[1]], {s, 0, smax}, 
        AxesLabel \[Rule] {"\<r\>", "\<z\>"}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[Evaluate[r[s] /. sol[1]], {s, 0, smax}];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Critical  vertical turning point", "Subsection"],

Cell[BoxData[
    \(f[s_?NumericQ, 
        R0_?NumericQ] := {\[Theta][s] - \[Pi]\/2, \(\[Theta]'\)[s]} /. 
        sol[R0]\)], "Input"],

Cell[BoxData[
    \({s1, R1} = {s, R0} /. 
        FindRoot[f[s, R0], {{s, 1.9}, {R0, 0.77}}]\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[Evaluate[{r[s], z[s]} /. sol[R1]], {s, 0, 15}, 
          AxesLabel \[Rule] {"\<r\>", "\<z\>"}] \
// \[IndentingNewLine]Figure["\<surface13\>", 
          ImageSize \[Rule] 180];\)\)], "Input"],

Cell["Critical radius and depth", "Text"],

Cell[BoxData[
    \({a1, d1} = {r[s1], z[s1]} /. sol[R1]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Radius larger than critical  ",
  Cell[BoxData[
      \(TraditionalForm\`a > a\_1\)]]
}], "Section"],

Cell["Choice", "Text"],

Cell[BoxData[
    \(\(a = 1;\)\)], "Input"],

Cell["Curve parameter, depth and volume", "Text"],

Cell[BoxData[{
    \(s0[R0_?NumericQ] := 
      s /. FindRoot[
          Evaluate[r[s] /. sol[R0]] \[Equal] a, {s, 0, smax}]\), "\n", 
    \(d[R0_?NumericQ] := z[s0[R0]] /. sol[R0]\), "\n", 
    \(vol[
        R0_?NumericQ] := \[Pi]\ \(r[s0[R0]]\^2\) \((z[s0[R0]] + 
              2  Sin[\[Theta][s0[R0]]]\/r[s0[R0]] - 2\/R0)\) /. 
        sol[R0]\)}], "Input"],

Cell[BoxData[
    \(\(Plot[vol[R0], {R0, 0.3, 2}, 
          PlotRange \[Rule] {{0, 2}, {\(-0.5\), 6}}, 
          AxesLabel \[Rule] {\*"\"\<\!\(R\_0\)\>\"", "\<V\>"}] \
// \[IndentingNewLine]Figure["\<surface16\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell["Central radius at maximum volume", "Text"],

Cell[BoxData[
    \(R2 = 
      R0 /. \(FindMaximum[
            vol[R0] // Evaluate, {R0, 1, 0.9}]\)[\([2]\)]\)], "Input"],

Cell["Curve parameter", "Text"],

Cell[BoxData[
    \(s2 = s0[R2]\)], "Input"],

Cell["Choice of central radii", "Text"],

Cell[BoxData[
    \(Rs = R2 {1, 1.05, 1.1, 2}\)], "Input"],

Cell[BoxData[
    \(ds = Map[d, Rs]\)], "Input"],

Cell[BoxData[
    \(\(dmax = Max[ds];\)\)], "Input"],

Cell[BoxData[
    \(vols = Map[vol, Rs]\)], "Input"],

Cell[BoxData[
    \(\(funs = 
        MapThread[{r[s], z[s] - #2} /. sol[#1] &, {Rs, ds}] \[Union] 
          MapThread[{\(-r[s]\), z[s] - #2} /. sol[#1] &, {Rs, 
              ds}];\)\)], "Input"],

Cell[BoxData[
    \(\(aspect = dmax\/\(2  a\);\)\)], "Input"],

Cell[BoxData[
    \(\(fig1 = 
        ParametricPlot[funs // Evaluate, {s, 0, s2}, 
            AspectRatio \[Rule] aspect, 
            PlotRange \[Rule] {{\(-a\), a}, {\(-dmax\) - 0.01, 0}}, 
            PlotLabel -> "\<(a)\>"] // \[IndentingNewLine]Figure["\<surface14\
\>", ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Radius smaller than critical, ",
  Cell[BoxData[
      \(TraditionalForm\`a < a\_1\)]],
  ", inside solution"
}], "Section"],

Cell["Choice", "Text"],

Cell[BoxData[
    \(\(a = 0.5;\)\)], "Input"],

Cell["Extreme values", "Text"],

Cell[BoxData[
    \(f[s_?NumericQ, 
        R0_?NumericQ] := {r[s] - a, \[Theta][s] - 90  \[Degree]} /. 
        sol[R0]\)], "Input"],

Cell[BoxData[
    \({s2, R2} = {s, R0} /. 
        FindRoot[f[s, R0], {{s, 0.8}, {R0, 0.5}}]\)], "Input"],

Cell["Curve parameter, depth and volume", "Text"],

Cell[BoxData[{
    \(s0[R0_?NumericQ] := 
      s /. FindRoot[
          Evaluate[r[s] /. sol[R0]] \[Equal] a, {s, s2, s2 - 0.01}]\), "\n", 
    \(d[R0_?NumericQ] := z[s0[R0]] /. sol[R0]\), "\n", 
    \(vol[
        R0_?NumericQ] := \[Pi]\ \(r[s0[R0]]\^2\) \((z[s0[R0]] + 
              2  Sin[\[Theta][s0[R0]]]\/r[s0[R0]] - 2\/R0)\) /. 
        sol[R0]\)}], "Input"],

Cell[BoxData[
    \(\(Plot[s0[R0], {R0, R2, 2}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[vol[R0], {R0, R2, 2}];\)\)], "Input"],

Cell["Choice of  central radii", "Text"],

Cell[BoxData[
    \(Rs = R2 {1, 2}\)], "Input"],

Cell[BoxData[
    \(ds = Map[d, Rs]\)], "Input"],

Cell[BoxData[
    \(vols = Map[vol, Rs]\)], "Input"],

Cell[BoxData[
    \(\(dmax = Max[ds];\)\)], "Input"],

Cell[BoxData[
    \(\(funs = 
        MapThread[{r[s], z[s] - #2} /. sol[#1] &, {Rs, ds}] \[Union] 
          MapThread[{\(-r[s]\), z[s] - #2} /. sol[#1] &, {Rs, 
              ds}];\)\)], "Input"],

Cell[BoxData[
    \(\(aspect = dmax\/\(2  a\);\)\)], "Input"],

Cell[BoxData[
    \(\(figa = 
        ParametricPlot[funs // Evaluate, {s, 0, smax}, 
          AspectRatio \[Rule] aspect, 
          PlotRange \[Rule] {{\(-a\), a}, {\(-dmax\), 0}}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Radius smaller than critical, ",
  Cell[BoxData[
      \(TraditionalForm\`a < a\_1, outside\)]],
  " solution"
}], "Section"],

Cell[BoxData[
    \(f[s_?NumericQ, 
        R0_?NumericQ] := {r[s] - a, \[Theta][s] - 90  \[Degree]} /. 
        sol[R0]\)], "Input"],

Cell[BoxData[
    \({s3, R3} = {s, R0} /. 
        FindRoot[f[s, R0], {{s, s2 + 1}, {R0, 0.5}}]\)], "Input"],

Cell[BoxData[{
    \(s0[R0_?NumericQ] := 
      s /. FindRoot[Evaluate[r[s] /. sol[R0]] \[Equal] a, {s, 1.6}]\), "\n", 
    \(d[R0_?NumericQ] := z[s0[R0]] /. sol[R0]\), "\n", 
    \(vol[
        R0_?NumericQ] := \[Pi]\ \(r[s0[R0]]\^2\) \((z[s0[R0]] + 
              2  Sin[\[Theta][s0[R0]]]\/r[s0[R0]] - 2\/R0)\) /. 
        sol[R0]\)}], "Input"],

Cell[BoxData[
    \(\(Plot[Evaluate[{a, r[s]} /. sol[R3]], {s, 0, 5}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[Evaluate[{\[Theta][s]} /. sol[R2]], {s, 0, 5}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[s0[R0], {R0, R2, R3}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[vol[R0], {R0, R2, R3}];\)\)], "Input"],

Cell[BoxData[
    \(Rs = {R2, \((R2 + R3)\)/2, R3}\)], "Input"],

Cell[BoxData[
    \(ds = Map[d, Rs]\)], "Input"],

Cell[BoxData[
    \(vols = Map[vol, Rs]\)], "Input"],

Cell[BoxData[
    \(\(dmax = Max[ds];\)\)], "Input"],

Cell[BoxData[
    \(\(funs = 
        MapThread[{r[s], z[s] - #2} /. sol[#1] &, {Rs, ds}] \[Union] 
          MapThread[{\(-r[s]\), z[s] - #2} /. sol[#1] &, {Rs, 
              ds}];\)\)], "Input"],

Cell[BoxData[
    \(\(figb = 
        ParametricPlot[funs // Evaluate, {s, 0, s3}, 
          PlotRange \[Rule] {\(-dmax\), 0}];\)\)], "Input"],

Cell[BoxData[
    \(s90[R0_?NumericQ] := 
      s /. FindRoot[
          Evaluate[\[Theta][s] /. sol[R0]] \[Equal] \[Pi]\/2, {s, 0.5, 
            0.51}]\)], "Input"],

Cell[BoxData[
    \(a3 = r[s90[R3]] /. sol[R3]\)], "Input"],

Cell[BoxData[
    \(\(aspect = dmax\/\(2  a3\);\)\)], "Input"],

Cell[BoxData[{
    \(\(a3 *= 1.25;\)\), "\[IndentingNewLine]", 
    \(\(dmax *= 1.25;\)\)}], "Input"],

Cell[BoxData[
    \(\(fig2 = 
        Show[figa, figb, 
          PlotRange \[Rule] {{\(-a3\) - 0.01, 
                a3 + 0.01}, {0, \(-dmax\) - 0.01}}, 
          AspectRatio \[Rule] aspect, PlotLabel -> "\<(b)\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[
          GraphicsArray[{fig1, 
              fig2}]] // \[IndentingNewLine]Figure["\<surface15\>", 
          ImageSize \[Rule] 500];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["8.1 SoapBubble", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 3\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[Alpha] = 0.15\ Newton/Meter;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1.2\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell[BoxData[
    \(\[CapitalDelta]p = \(4  \[Alpha]\)\/a // ToUnit[Pascal]\)], "Input"],

Cell[BoxData[
    \(R\_c = \@\(\(2  \[Alpha]\)\/\(\(\[Rho]\_0\) g\_0\)\) // 
        ToUnit[Centimeter]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 937}},
AutoGeneratedPackage->None,
WindowSize->{721, 740},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 35, 0, 95, "Title"],
Cell[1814, 55, 111, 3, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1962, 63, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[2012, 67, 39, 0, 73, "Section"],
Cell[2054, 69, 51, 1, 30, "Input"],
Cell[2108, 72, 26, 0, 33, "Text"],
Cell[2137, 74, 194, 3, 70, "Input"],
Cell[2334, 79, 113, 2, 45, "Input"],
Cell[2450, 83, 71, 1, 30, "Input"],
Cell[2524, 86, 82, 1, 44, "Input"],
Cell[2609, 89, 91, 1, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2737, 95, 33, 0, 73, "Section"],
Cell[2773, 97, 46, 1, 30, "Input"],
Cell[2822, 100, 26, 0, 33, "Text"],
Cell[2851, 102, 278, 4, 90, "Input"],
Cell[3132, 108, 88, 1, 42, "Input"],
Cell[3223, 111, 49, 0, 33, "Text"],
Cell[3275, 113, 57, 1, 30, "Input"],
Cell[3335, 116, 92, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3464, 122, 28, 0, 73, "Section"],
Cell[3495, 124, 46, 1, 30, "Input"],
Cell[3544, 127, 328, 5, 110, "Input"],
Cell[3875, 134, 92, 1, 42, "Input"],
Cell[3970, 137, 85, 1, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4092, 143, 41, 0, 73, "Section"],
Cell[4136, 145, 46, 1, 30, "Input"],
Cell[4185, 148, 26, 0, 33, "Text"],
Cell[4214, 150, 181, 3, 70, "Input"],
Cell[4398, 155, 35, 0, 33, "Text"],
Cell[4436, 157, 80, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4553, 163, 39, 0, 73, "Section"],
Cell[4595, 165, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[4666, 170, 41, 0, 38, "Subsection"],
Cell[4710, 172, 328, 5, 110, "Input"],
Cell[5041, 179, 32, 0, 33, "Text"],
Cell[5076, 181, 109, 2, 51, "Input"],
Cell[5188, 185, 30, 0, 33, "Text"],
Cell[5221, 187, 93, 1, 45, "Input"],
Cell[5317, 190, 30, 0, 33, "Text"],
Cell[5350, 192, 78, 1, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5465, 198, 43, 0, 38, "Subsection"],
Cell[5511, 200, 228, 4, 70, "Input"],
Cell[5742, 206, 32, 0, 33, "Text"],
Cell[5777, 208, 109, 2, 51, "Input"],
Cell[5889, 212, 30, 0, 33, "Text"],
Cell[5922, 214, 93, 1, 45, "Input"],
Cell[6018, 217, 30, 0, 33, "Text"],
Cell[6051, 219, 78, 1, 44, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6190, 227, 40, 0, 95, "Title"],
Cell[6233, 229, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[6304, 234, 38, 0, 73, "Section"],
Cell[6345, 236, 76, 1, 42, "Input"],
Cell[6424, 239, 116, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6577, 246, 30, 0, 73, "Section"],
Cell[6610, 248, 26, 0, 33, "Text"],
Cell[6639, 250, 202, 3, 70, "Input"],
Cell[6844, 255, 22, 0, 33, "Text"],
Cell[6869, 257, 61, 1, 30, "Input"],
Cell[6933, 260, 32, 0, 33, "Text"],
Cell[6968, 262, 300, 6, 70, "Input"],
Cell[7271, 270, 155, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7463, 278, 32, 0, 73, "Section"],
Cell[7498, 280, 26, 0, 33, "Text"],
Cell[7527, 282, 203, 3, 70, "Input"],
Cell[7733, 287, 61, 1, 30, "Input"],
Cell[7797, 290, 295, 6, 70, "Input"],
Cell[8095, 298, 155, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8287, 306, 37, 0, 73, "Section"],
Cell[8327, 308, 287, 5, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8663, 319, 39, 0, 95, "Title"],
Cell[8705, 321, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[8776, 326, 34, 0, 73, "Section"],
Cell[8813, 328, 32, 0, 33, "Text"],
Cell[8848, 330, 187, 3, 81, "Input"],
Cell[9038, 335, 77, 1, 30, "Input"],
Cell[9118, 338, 34, 0, 33, "Text"],
Cell[9155, 340, 135, 3, 44, "Input"],
Cell[9293, 345, 118, 2, 54, "Input"],
Cell[9414, 349, 44, 0, 33, "Text"],
Cell[9461, 351, 323, 6, 70, "Input"],
Cell[9787, 359, 40, 0, 33, "Text"],
Cell[9830, 361, 108, 2, 30, "Input"],
Cell[9941, 365, 77, 1, 30, "Input"],
Cell[10021, 368, 57, 1, 42, "Input"],
Cell[10081, 371, 27, 0, 33, "Text"],
Cell[10111, 373, 71, 1, 30, "Input"],
Cell[10185, 376, 26, 0, 33, "Text"],
Cell[10214, 378, 71, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10322, 384, 35, 0, 73, "Section"],
Cell[10360, 386, 60, 1, 30, "Input"],
Cell[10423, 389, 305, 6, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10765, 400, 29, 0, 73, "Section"],
Cell[10797, 402, 60, 1, 40, "Input"],
Cell[10860, 405, 33, 0, 33, "Text"],
Cell[10896, 407, 115, 2, 30, "Input"],
Cell[11014, 411, 23, 0, 33, "Text"],
Cell[11040, 413, 92, 1, 30, "Input"],
Cell[11135, 416, 31, 0, 33, "Text"],
Cell[11169, 418, 65, 1, 30, "Input"],
Cell[11237, 421, 48, 0, 33, "Text"],
Cell[11288, 423, 50, 1, 30, "Input"],
Cell[11341, 426, 36, 0, 33, "Text"],
Cell[11380, 428, 61, 1, 44, "Input"],
Cell[11444, 431, 27, 0, 33, "Text"],
Cell[11474, 433, 123, 3, 30, "Input"],
Cell[11600, 438, 59, 1, 30, "Input"],
Cell[11662, 441, 136, 3, 43, "Input"],
Cell[11801, 446, 405, 7, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12243, 458, 34, 0, 73, "Section"],
Cell[12280, 460, 33, 0, 33, "Text"],
Cell[12316, 462, 52, 1, 30, "Input"],
Cell[12371, 465, 44, 1, 30, "Input"],
Cell[12418, 468, 50, 0, 33, "Text"],
Cell[12471, 470, 66, 1, 30, "Input"],
Cell[12540, 473, 38, 1, 30, "Input"],
Cell[12581, 476, 59, 0, 33, "Text"],
Cell[12643, 478, 200, 4, 50, "Input"],
Cell[12846, 484, 50, 0, 33, "Text"],
Cell[12899, 486, 230, 4, 66, "Input"],
Cell[13132, 492, 32, 0, 33, "Text"],
Cell[13167, 494, 369, 7, 90, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13585, 507, 46, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[13656, 511, 34, 0, 73, "Section"],
Cell[13693, 513, 46, 1, 30, "Input"],
Cell[13742, 516, 26, 0, 33, "Text"],
Cell[13771, 518, 181, 3, 70, "Input"],
Cell[13955, 523, 29, 0, 33, "Text"],
Cell[13987, 525, 75, 1, 30, "Input"],
Cell[14065, 528, 34, 0, 33, "Text"],
Cell[14102, 530, 135, 3, 44, "Input"],
Cell[14240, 535, 118, 2, 54, "Input"],
Cell[14361, 539, 38, 0, 33, "Text"],
Cell[14402, 541, 323, 6, 70, "Input"],
Cell[14728, 549, 32, 0, 33, "Text"],
Cell[14763, 551, 108, 2, 30, "Input"],
Cell[14874, 555, 77, 1, 30, "Input"],
Cell[14954, 558, 73, 1, 30, "Input"],
Cell[15030, 561, 73, 1, 30, "Input"],
Cell[15106, 564, 42, 1, 31, "Input"],
Cell[15151, 567, 76, 1, 32, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15264, 573, 32, 0, 73, "Section"],
Cell[15299, 575, 33, 0, 33, "Text"],
Cell[15335, 577, 108, 2, 30, "Input"],
Cell[15446, 581, 59, 0, 33, "Text"],
Cell[15508, 583, 72, 1, 30, "Input"],
Cell[15583, 586, 161, 3, 70, "Input"],
Cell[15747, 591, 44, 0, 33, "Text"],
Cell[15794, 593, 69, 1, 30, "Input"],
Cell[15866, 596, 46, 0, 33, "Text"],
Cell[15915, 598, 49, 1, 30, "Input"],
Cell[15967, 601, 49, 1, 30, "Input"],
Cell[16019, 604, 47, 0, 33, "Text"],
Cell[16069, 606, 64, 1, 40, "Input"],
Cell[16136, 609, 30, 0, 33, "Text"],
Cell[16169, 611, 242, 5, 50, "Input"],
Cell[16414, 618, 36, 0, 33, "Text"],
Cell[16453, 620, 59, 1, 43, "Input"],
Cell[16515, 623, 177, 3, 50, "Input"],
Cell[16695, 628, 39, 0, 33, "Text"],
Cell[16737, 630, 272, 5, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17058, 641, 110, 4, 95, "Title"],

Cell[CellGroupData[{
Cell[17193, 649, 34, 0, 73, "Section"],
Cell[17230, 651, 46, 1, 30, "Input"],
Cell[17279, 654, 26, 0, 33, "Text"],
Cell[17308, 656, 183, 3, 70, "Input"],
Cell[17494, 661, 29, 0, 33, "Text"],
Cell[17526, 663, 75, 1, 30, "Input"],
Cell[17604, 666, 34, 0, 33, "Text"],
Cell[17641, 668, 135, 3, 44, "Input"],
Cell[17779, 673, 118, 2, 54, "Input"],
Cell[17900, 677, 37, 0, 33, "Text"],
Cell[17940, 679, 323, 6, 70, "Input"],
Cell[18266, 687, 32, 0, 33, "Text"],
Cell[18301, 689, 108, 2, 30, "Input"],
Cell[18412, 693, 77, 1, 30, "Input"],
Cell[18492, 696, 73, 1, 30, "Input"],
Cell[18568, 699, 73, 1, 30, "Input"],
Cell[18644, 702, 37, 0, 33, "Text"],
Cell[18684, 704, 76, 1, 32, "Input"],
Cell[18763, 707, 42, 1, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18842, 713, 32, 0, 73, "Section"],
Cell[18877, 715, 34, 0, 33, "Text"],
Cell[18914, 717, 108, 2, 30, "Input"],
Cell[19025, 721, 72, 1, 30, "Input"],
Cell[19100, 724, 39, 0, 33, "Text"],
Cell[19142, 726, 161, 3, 70, "Input"],
Cell[19306, 731, 47, 0, 33, "Text"],
Cell[19356, 733, 69, 1, 30, "Input"],
Cell[19428, 736, 49, 1, 30, "Input"],
Cell[19480, 739, 49, 1, 30, "Input"],
Cell[19532, 742, 64, 1, 40, "Input"],
Cell[19599, 745, 242, 5, 50, "Input"],
Cell[19844, 752, 59, 1, 43, "Input"],
Cell[19906, 755, 177, 3, 50, "Input"],
Cell[20086, 760, 274, 5, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20409, 771, 44, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[20478, 775, 34, 0, 73, "Section"],
Cell[20515, 777, 46, 1, 30, "Input"],
Cell[20564, 780, 26, 0, 33, "Text"],
Cell[20593, 782, 196, 3, 70, "Input"],
Cell[20792, 787, 65, 1, 30, "Input"],
Cell[20860, 790, 34, 0, 33, "Text"],
Cell[20897, 792, 135, 3, 44, "Input"],
Cell[21035, 797, 118, 2, 54, "Input"],
Cell[21156, 801, 38, 0, 33, "Text"],
Cell[21197, 803, 323, 6, 70, "Input"],
Cell[21523, 811, 108, 2, 30, "Input"],
Cell[21634, 815, 82, 1, 30, "Input"],
Cell[21719, 818, 83, 1, 30, "Input"],
Cell[21805, 821, 83, 1, 30, "Input"],
Cell[21891, 824, 76, 1, 32, "Input"],
Cell[21970, 827, 47, 1, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22054, 833, 32, 0, 73, "Section"],
Cell[22089, 835, 38, 0, 33, "Text"],
Cell[22130, 837, 118, 2, 30, "Input"],
Cell[22251, 841, 82, 1, 30, "Input"],
Cell[22336, 844, 161, 3, 70, "Input"],
Cell[22500, 849, 31, 0, 33, "Text"],
Cell[22534, 851, 69, 1, 30, "Input"],
Cell[22606, 854, 49, 1, 30, "Input"],
Cell[22658, 857, 49, 1, 30, "Input"],
Cell[22710, 860, 242, 5, 50, "Input"],
Cell[22955, 867, 59, 1, 43, "Input"],
Cell[23017, 870, 177, 3, 50, "Input"],
Cell[23197, 875, 278, 5, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23524, 886, 42, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[23591, 890, 34, 0, 73, "Section"],
Cell[23628, 892, 46, 1, 30, "Input"],
Cell[23677, 895, 26, 0, 33, "Text"],
Cell[23706, 897, 194, 3, 70, "Input"],
Cell[23903, 902, 65, 1, 30, "Input"],
Cell[23971, 905, 34, 0, 33, "Text"],
Cell[24008, 907, 135, 3, 44, "Input"],
Cell[24146, 912, 118, 2, 54, "Input"],
Cell[24267, 916, 38, 0, 33, "Text"],
Cell[24308, 918, 323, 6, 70, "Input"],
Cell[24634, 926, 108, 2, 30, "Input"],
Cell[24745, 930, 82, 1, 30, "Input"],
Cell[24830, 933, 83, 1, 30, "Input"],
Cell[24916, 936, 83, 1, 30, "Input"],
Cell[25002, 939, 76, 1, 32, "Input"],
Cell[25081, 942, 47, 1, 31, "Input"],
Cell[25131, 945, 47, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25215, 951, 32, 0, 73, "Section"],
Cell[25250, 953, 29, 0, 33, "Text"],
Cell[25282, 955, 82, 1, 30, "Input"],
Cell[25367, 958, 161, 3, 70, "Input"],
Cell[25531, 963, 39, 0, 33, "Text"],
Cell[25573, 965, 69, 1, 30, "Input"],
Cell[25645, 968, 49, 1, 30, "Input"],
Cell[25697, 971, 49, 1, 30, "Input"],
Cell[25749, 974, 242, 5, 50, "Input"],
Cell[25994, 981, 49, 1, 30, "Input"],
Cell[26046, 984, 67, 1, 43, "Input"],
Cell[26116, 987, 177, 3, 50, "Input"],
Cell[26296, 992, 282, 5, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26627, 1003, 33, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[26685, 1007, 34, 0, 73, "Section"],
Cell[26722, 1009, 46, 1, 30, "Input"],
Cell[26771, 1012, 26, 0, 33, "Text"],
Cell[26800, 1014, 111, 2, 50, "Input"],
Cell[26914, 1018, 38, 0, 33, "Text"],
Cell[26955, 1020, 478, 9, 129, "Input"],
Cell[27436, 1031, 145, 2, 30, "Input"],
Cell[27584, 1035, 147, 2, 30, "Input"],
Cell[27734, 1039, 82, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[27841, 1044, 54, 0, 38, "Subsection"],
Cell[27898, 1046, 136, 3, 40, "Input"],
Cell[28037, 1051, 106, 2, 30, "Input"],
Cell[28146, 1055, 230, 4, 50, "Input"],
Cell[28379, 1061, 41, 0, 33, "Text"],
Cell[28423, 1063, 69, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28541, 1070, 119, 4, 73, "Section"],
Cell[28663, 1076, 22, 0, 33, "Text"],
Cell[28688, 1078, 43, 1, 30, "Input"],
Cell[28734, 1081, 49, 0, 33, "Text"],
Cell[28786, 1083, 361, 8, 85, "Input"],
Cell[29150, 1093, 265, 5, 50, "Input"],
Cell[29418, 1100, 48, 0, 33, "Text"],
Cell[29469, 1102, 123, 3, 30, "Input"],
Cell[29595, 1107, 31, 0, 33, "Text"],
Cell[29629, 1109, 44, 1, 30, "Input"],
Cell[29676, 1112, 39, 0, 33, "Text"],
Cell[29718, 1114, 58, 1, 30, "Input"],
Cell[29779, 1117, 48, 1, 30, "Input"],
Cell[29830, 1120, 52, 1, 30, "Input"],
Cell[29885, 1123, 52, 1, 30, "Input"],
Cell[29940, 1126, 197, 4, 50, "Input"],
Cell[30140, 1132, 61, 1, 43, "Input"],
Cell[30204, 1135, 316, 6, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30557, 1146, 143, 5, 73, "Section"],
Cell[30703, 1153, 22, 0, 33, "Text"],
Cell[30728, 1155, 45, 1, 30, "Input"],
Cell[30776, 1158, 30, 0, 33, "Text"],
Cell[30809, 1160, 133, 3, 30, "Input"],
Cell[30945, 1165, 105, 2, 30, "Input"],
Cell[31053, 1169, 49, 0, 33, "Text"],
Cell[31105, 1171, 367, 8, 85, "Input"],
Cell[31475, 1181, 63, 1, 30, "Input"],
Cell[31541, 1184, 64, 1, 30, "Input"],
Cell[31608, 1187, 40, 0, 33, "Text"],
Cell[31651, 1189, 47, 1, 30, "Input"],
Cell[31701, 1192, 48, 1, 30, "Input"],
Cell[31752, 1195, 52, 1, 30, "Input"],
Cell[31807, 1198, 52, 1, 30, "Input"],
Cell[31862, 1201, 197, 4, 50, "Input"],
Cell[32062, 1207, 61, 1, 43, "Input"],
Cell[32126, 1210, 199, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32362, 1219, 144, 5, 73, "Section"],
Cell[32509, 1226, 133, 3, 30, "Input"],
Cell[32645, 1231, 108, 2, 30, "Input"],
Cell[32756, 1235, 346, 7, 85, "Input"],
Cell[33105, 1244, 85, 1, 30, "Input"],
Cell[33193, 1247, 89, 1, 30, "Input"],
Cell[33285, 1250, 64, 1, 30, "Input"],
Cell[33352, 1253, 65, 1, 30, "Input"],
Cell[33420, 1256, 63, 1, 30, "Input"],
Cell[33486, 1259, 48, 1, 30, "Input"],
Cell[33537, 1262, 52, 1, 30, "Input"],
Cell[33592, 1265, 52, 1, 30, "Input"],
Cell[33647, 1268, 197, 4, 50, "Input"],
Cell[33847, 1274, 143, 3, 30, "Input"],
Cell[33993, 1279, 166, 4, 40, "Input"],
Cell[34162, 1285, 59, 1, 30, "Input"],
Cell[34224, 1288, 62, 1, 43, "Input"],
Cell[34289, 1291, 101, 2, 50, "Input"],
Cell[34393, 1295, 233, 5, 50, "Input"],
Cell[34629, 1302, 177, 4, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34855, 1312, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[34905, 1316, 33, 0, 73, "Section"],
Cell[34941, 1318, 46, 1, 30, "Input"],
Cell[34990, 1321, 26, 0, 33, "Text"],
Cell[35019, 1323, 268, 4, 90, "Input"],
Cell[35290, 1329, 88, 1, 42, "Input"],
Cell[35381, 1332, 116, 2, 51, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

