(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17149,        683]*)
(*NotebookOutlinePosition[     17821,        706]*)
(*  CellTagsIndexPosition[     17777,        702]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["12. Solids at rest", "Title"],

Cell[BoxData[{
    \(<< Lautrup`\), "\[IndentingNewLine]", 
    \(<< Calculus`VectorAnalysis`\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Elastic tube", "Title"],

Cell[TextData[{
  "This illustrates how to use cylindrical coordinates defined in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to solve the problem."
}], "Text"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Cylindrical coordinates", "Section"],

Cell[BoxData[
    \(\(SetCoordinates[Cylindrical[r, \[Phi], z]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tube field solution", "Section"],

Cell["Ansatz", "Text"],

Cell[BoxData[
    \(\(u = {u\_r[r], 0, 0};\)\)], "Input"],

Cell["Volume force", "Text"],

Cell[BoxData[
    \(f = \(\(-\((\[Mu]\ Laplacian[u] + \((\[Lambda] + \[Mu])\) 
                  Grad[Div[u]])\)\) // Expand\) // 
        Collect[#, {\[Mu], \[Lambda]}] &\)], "Input"],

Cell["Radial component", "Text"],

Cell[BoxData[
    \(f\_r = f[\([1]\)]\)], "Input"],

Cell["Check special form", "Text"],

Cell[BoxData[
    \(f\_r + \((\[Lambda] + 
              2  \[Mu])\) \[PartialD]\_r\((\(1\/r\) \[PartialD]\_r\((r\ u\_r[
                        r])\))\) // Expand\)], "Input"],

Cell["Insert general solution", "Text"],

Cell[BoxData[
    \(\(u\_r[r_] = A\ r + B\/r;\)\)], "Input"],

Cell[BoxData[
    \(f\_r // Expand\)], "Input"],

Cell[TextData[StyleBox["Strain and stress tensors", "Section"]], "Text"],

Cell["Strain", "Text"],

Cell[BoxData[
    \(uu = \(1\/2\) \((Grad[u] + Transpose[Grad[u]])\) // Expand\)], "Input"],

Cell[BoxData[
    \(uu // MatrixForm\)], "Input"],

Cell["Stress", "Text"],

Cell[BoxData[
    \(\[Sigma] = \(2  \[Mu]\ uu + \[Lambda]\ \ IdentityMatrix[3]\ Tr[uu] // 
          Expand\) // Collect[#, A] &\)], "Input"],

Cell[BoxData[
    \(\[Sigma] // MatrixForm\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Boundary conditions", "Section"],

Cell[BoxData[
    \(sol = 
      Solve[{\((\[Sigma][\([1, 1]\)] /. 
                  r \[Rule] a)\) \[Equal] \(-P\), \((\[Sigma][\([1, 1]\)] /. 
                  r \[Rule] b)\) \[Equal] 0}, {A, B}] // First\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Complete solution", "Section"],

Cell[BoxData[
    \(\(lame = {\[Lambda] \[Rule] \(EE\ \[Nu]\)\/\(\((1 - 2  \[Nu])\) \((1 + \
\[Nu])\)\), \[Mu] \[Rule] EE\/\(2 \((1 + \[Nu])\)\)\ };\)\)], "Input"],

Cell[BoxData[
    \(\(u\_r[r] /. sol\) /. lame // Simplify\)], "Input"],

Cell[BoxData[
    \(\(uu[\([1, 1]\)] /. sol\) /. lame // Simplify\)], "Input"],

Cell[BoxData[
    \(\(uu[\([2, 2]\)] /. sol\) /. lame // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\[Sigma][\([1, 1]\)] /. sol\) /. lame // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\[Sigma][\([2, 2]\)] /. sol\) /. lame // Simplify\)], "Input"],

Cell[BoxData[
    \(\(\[Sigma][\([3, 3]\)] /. sol\) /. lame // Simplify\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["12.1.1 Deformation of chair", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(M = 70\ Kilogram;\)\), "\[IndentingNewLine]", 
    \(\(A = 4*7\ Centimeter\^2;\)\), "\[IndentingNewLine]", 
    \(\(L = 50\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(Ey = \(10\^9\) Pascal;\)\)}], "Input"],

Cell["Stress", "Text"],

Cell[BoxData[
    \(P = \(M\ g\_0\)\/A // ToUnit[Bar]\)], "Input"],

Cell["Deformation", "Text"],

Cell[BoxData[
    \(uu = P\/Ey // ToSI\)], "Input"],

Cell["Displacement", "Text"],

Cell[BoxData[
    \(u = uu\ L // ToUnit[Millimeter]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["12.1.2 Tall building", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(A = 63*63\ Meter\^2;\)\), "\[IndentingNewLine]", 
    \(\(L = 413.0\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = 100\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(EE = 2\ \(10\^11\) Pascal;\)\), "\[IndentingNewLine]", 
    \(\(f = 0.01;\)\)}], "Input"],

Cell["Mass of building", "Text"],

Cell[BoxData[
    \(M = A\ L\ \[Rho] // ToSI\)], "Input"],

Cell["Stress", "Text"],

Cell[BoxData[
    \(P = \(M\ g\_0\)\/\(f\ A\) // ToUnit[Pascal]\)], "Input"],

Cell[BoxData[
    \(P // ToUnit[Bar]\)], "Input"],

Cell[BoxData[
    \(DD = \(f\ \ EE\)\/\(\[Rho]\ g\_0\) // ToUnit[Kilometer]\)], "Input"],

Cell[BoxData[
    \(L\/DD // ToSI\)], "Input"],

Cell[BoxData[
    \(L\^2\/DD // ToUnit[Centimeter]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["12.3.1 Wooden stick", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(L = 1\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(a = 1\ Centimeter;\)\ \), "\[IndentingNewLine]", 
    \(\(EE = 10\ Giga\ Pascal;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell["Area moment", "Text"],

Cell[BoxData[
    \(II := \(\(\(\(\[Pi]\)\(\ \)\)\/4\) a\^4 // N\) // ToSI\)], "Input"],

Cell["Force", "Text"],

Cell[BoxData[
    \(F := \(\[Pi]\^2\) \(EE\ II\)\/L\^2 // ToUnit[Newton]\)], "Input"],

Cell[BoxData[
    \(F\/g\_0 // ToSI\)], "Input"],

Cell["A millimeter larger radius", "Text"],

Cell[BoxData[
    \(\(a = 1.1\ Centimeter;\)\)], "Input"],

Cell[BoxData[
    \(F\/g\_0 // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["12.3.2 Steel bow", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 5.0  Millimeter;\)\), "\n", 
    \(\(b = 10.0\ Millimeter;\)\), "\n", 
    \(\(\[Alpha] = 60  \[Degree];\)\), "\n", 
    \(\(L = 200\ Centimeter;\)\), "\n", 
    \(\(EE = 2*^11\ Pascal;\)\), "\n", 
    \(\(g\_0 = AccelerationDueToGravity;\)\)}], "Input"],

Cell["From integrals below", "Text"],

Cell[BoxData[
    \(\(\(\(dL = 0.161945;\)\  (*\ d/L\ *) \[IndentingNewLine]
    \(hL = 0.9324;\)\ \ \ \ \ \  (*\ h/L\ *) \[IndentingNewLine]
    \(\(FFE = 1.0351\) \); \)\(\ \ \ \)\( (*\ F/FE\ *) \)\)\)], "Input"],

Cell["Bow-string distance", "Text"],

Cell[BoxData[
    \(d = dL*L\)], "Input"],

Cell["String length", "Text"],

Cell[BoxData[
    \(h = hL*L\)], "Input"],

Cell["Area moment", "Text"],

Cell[BoxData[
    \(II = \(4\/3\) \(a\^3\) b // ToSI\)], "Input"],

Cell["Euler critical  force", "Text"],

Cell[BoxData[
    \(FE = \(\[Pi]\^2\) \(EE\ II\)\/L\^2 // ToUnit[Newton]\)], "Input"],

Cell["Actual force", "Text"],

Cell[BoxData[
    \(F = FFE*FE\)], "Input"],

Cell[BoxData[
    \(F\/g\_0 // ToSI\)], "Input"],

Cell[BoxData[
    \(\((4\/5)\)\^3\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["12.4.1 Car engine", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(M = 100\ Newton\ Meter;\)\), "\n", 
    \(\(a = 2\ Centimeter;\)\), "\n", 
    \(\(EE = 205\ Giga\ Pascal;\)\), "\n", 
    \(\(\[Nu] = 0.29;\)\), "\n", 
    \(Omega = 3000.0\ RPM // ToSI\)}], "Input"],

Cell["Power", "Text"],

Cell[BoxData[
    \(P = Omega\ M // ToUnit[Kilo\ Watt]\)], "Input"],

Cell[BoxData[
    \(P // ToUnit[Horsepower]\)], "Input"],

Cell["Shear modulus", "Text"],

Cell[BoxData[
    \(\[Mu] = EE\/\(2 \((1 + \[Nu])\)\)\)], "Input"],

Cell["Torsional rigidity", "Text"],

Cell[BoxData[
    \(CC = \(\[Pi]\/2\) \[Mu]\ a\^4 // ToUnit[Newton]\)], "Input"],

Cell["Torsion angle", "Text"],

Cell[BoxData[
    \(\[Tau] = M\/CC // ToSI\)], "Input"],

Cell[BoxData[
    \(\[Tau]\ /Degree\)], "Input"],

Cell["Maximal shear stress", "Text"],

Cell[BoxData[
    \(\[Sigma] = \[Mu]\ \[Tau]\ a // ToUnit[Bar]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Buckling", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Define basic functions", "Section"],

Cell["Cut-off", "Text"],

Cell[BoxData[
    \(\(\[Epsilon] = 10\^\(-6\);\)\)], "Input"],

Cell["Length function", "Text"],

Cell[BoxData[
    \(f[\[Alpha]_] := 
      Module[{\[Theta]}, 
        y /. NDSolve[{\(y'\)[\[Theta]] \[Equal] 
                  1\/\@\(\[Epsilon]\^2 + 2 \((Sin[\[Theta]] - \
Sin[\[Alpha]])\)\), y[\[Alpha]] \[Equal] 0}, 
              y, {\[Theta], \[Alpha], \[Pi] - \[Alpha]}] // First]\)], "Input"],

Cell["Displacement function", "Text"],

Cell[BoxData[
    \(g[\[Alpha]_] := \@\(\[Epsilon]\^2 + 2 \((Sin[#] - Sin[\[Alpha]])\)\) \
&\)], "Input"],

Cell["Height function", "Text"],

Cell[BoxData[
    \(h[\[Alpha]_] := 
      Module[{\[Theta]}, 
        y /. NDSolve[{\(y'\)[\[Theta]] \[Equal] 
                  Sin[\[Theta]]\/\@\(\[Epsilon]\^2 + 2 \((Sin[\[Theta]] - \
Sin[\[Alpha]])\)\), y[\[Alpha]] \[Equal] 0}, 
              y, {\[Theta], \[Alpha], \[Pi] - \[Alpha]}] // First]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Base relation", "Section"],

Cell[TextData[{
  "Force ratio ",
  Cell[BoxData[
      \(TraditionalForm\`F/F\_E\)]]
}], "Text"],

Cell[BoxData[
    \(FFE[\[Alpha]_] := \(1\/\[Pi]\^2\) \(f[\[Alpha]]\)[\[Pi] - \
\[Alpha]]\^2\)], "Input"],

Cell["Maximal displacement d/L", "Text"],

Cell[BoxData[
    \(dL[\[Alpha]_] := \(g[\[Alpha]]\)[\[Pi]\/2]\/\(f[\[Alpha]]\)[\[Pi] - \
\[Alpha]]\)], "Input"],

Cell["Stringed length h/L", "Text"],

Cell[BoxData[
    \(hL[\[Alpha]_] := \(h[\[Alpha]]\)[\[Pi] - \[Alpha]]\/\(f[\[Alpha]]\)[\
\[Pi] - \[Alpha]]\)], "Input"],

Cell[BoxData[
    \(\(deg = Degree // N;\)\)], "Input"],

Cell[BoxData[
    \(\(fig2 = 
        Plot[{dL[\[Alpha]\ deg], FFE[\[Alpha]\ deg], 
            hL[\[Alpha]\ deg]}, {\[Alpha], 0, 89}, 
          AxesLabel \[Rule] {"\<\[Alpha]\>", "\<\>"}, 
          PlotRange \[Rule] {{0, 91}, {0, 1.41}}, 
          PlotStyle \[Rule] {Text[\*"\"\<F/\!\(F\_E\)\>\"", {25, 
                  1.27}, {1, \(-1\)}], 
              Text["\<d/L\>", {25, 0.35}, {1, \(-1\)}], 
              Text["\<h/L\>", {25, 0.7}, {1, \(-1\)}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig2, 
          Graphics[{Dashing[{0.02}], 
              Line[{{0, 1}, {90, 
                    1}}]}]] // \[IndentingNewLine]Figure["\<solids2\>", 
          ImageSize \[Rule] 350];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shape", "Section"],

Cell[BoxData[
    \(x[\[Alpha]_] := \(g[\[Alpha]]\)[#]\/\(f[\[Alpha]]\)[\[Pi] - \[Alpha]] &\
\)], "Input"],

Cell[BoxData[
    \(z[\[Alpha]_] := \(h[\[Alpha]]\)[#]\/\(f[\[Alpha]]\)[\[Pi] - \[Alpha]] &\
\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[{
  "Angle ",
  Cell[BoxData[
      \(TraditionalForm\`60\ degrees\)]]
}], "Subsection"],

Cell[BoxData[
    \(\(\[Alpha] = 60  \[Degree];\)\)], "Input"],

Cell[BoxData[
    \(d[\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(F[\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(\[Lambda][\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(\(fig1a = 
        ParametricPlot[{\(x[\[Alpha]]\)[\[Theta]], \(z[\[Alpha]]\)[\[Theta]]} \
// Evaluate, {\[Theta], \[Alpha], \[Pi] - \[Alpha]}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Angle 30 degrees", "Subsection"],

Cell[BoxData[
    \(\(\[Alpha] = 30  \[Degree];\)\)], "Input"],

Cell[BoxData[
    \(d[\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(F[\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(\[Lambda][\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(\(fig1b = 
        ParametricPlot[{\(x[\[Alpha]]\)[\[Theta]], \(z[\[Alpha]]\)[\[Theta]]} \
// Evaluate, {\[Theta], \[Alpha], \[Pi] - \[Alpha]}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Angle 0 degrees", "Subsection"],

Cell[BoxData[
    \(\(\[Alpha] = 0;\)\)], "Input"],

Cell[BoxData[
    \(d[\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(F[\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(\[Lambda][\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(\[Kappa][\[Alpha]]\)], "Input"],

Cell[BoxData[
    \(\(fig1c = 
        ParametricPlot[{\(x[\[Alpha]]\)[\[Theta]], \(z[\[Alpha]]\)[\[Theta]]} \
// Evaluate, {\[Theta], \[Alpha], \[Pi] - \[Alpha]}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show figure", "Subsection"],

Cell[BoxData[
    \(\(ticks = Table[0.1  n, {n, 0, 10}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b, fig1c, 
          Graphics[{Text["\<60\[Degree]\>", {0.16, 0.47}, {1, \(-1\)}], 
              Text["\<0\[Degree]\>", {0.38, 0.23}, {1, 0}], 
              Text["\<30\[Degree]\>", {0.27, 0.37}, {0, 1}]}], 
          PlotRange \[Rule] {{0, 0.41}, {0, 1.01}}, 
          AspectRatio \[Rule] 1.01/0.41, 
          AxesLabel \[Rule] {"\<x/L\>", "\<z/L\>"}, 
          Ticks \[Rule] {ticks, ticks}, 
          ImageSize \[Rule] 200] // \[IndentingNewLine]Figure["\<solids1\>", 
          ImageSize \[Rule] 150];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["12.3 Gun and bullet", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 5\ Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(L = 1\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(U = 800\ Meter/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Gamma] = 7\/5;\)\), "\[IndentingNewLine]", 
    \(\(m = 5\ Gram;\)\), "\[IndentingNewLine]", 
    \(\(x\_0 = 1\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(x\_1 = L;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1\ Gram/Centimeter\^3;\)\), "\[IndentingNewLine]", 
    \(\(R = MolarGasConstant;\)\), "\[IndentingNewLine]", 
    \(\(M\_mol = 30\ Gram/Mole;\)\), "\[IndentingNewLine]", 
    \(\(d = 5\ Millimeter;\)\), "\[IndentingNewLine]", 
    \(\(b = a + d;\)\), "\[IndentingNewLine]", 
    \(\(EE = 205\ Giga\ Pascal;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = 0.29;\)\)}], "Input"],

Cell["Barrel cross section ", "Text"],

Cell[BoxData[
    \(A = \(\[Pi]\ a\^2 // N\) // ToUnit[Centimeter\^2]\)], "Input"],

Cell["Gunpowder volume", "Text"],

Cell[BoxData[
    \(V\_0 = A\ x\_0 // ToUnit[Centimeter\^3]\)], "Input"],

Cell["Barrel volume", "Text"],

Cell[BoxData[
    \(V\_1 = A\ x\_1\  // ToUnit[Centimeter\^3]\)], "Input"],

Cell["Initial gas volume", "Text"],

Cell[BoxData[
    \(m\_0 = \(V\_0\) \[Rho]\_0 // ToUnit[Gram]\)], "Input"],

Cell["Initial gas pressure", "Text"],

Cell[BoxData[
    \(p\_0 = \(\(\((\[Gamma] - 1)\)\ m\ U\^2\)\/\(2  
                A\ x\_0\)\) \((1 - \((x\_0\/x\_1)\)\^\(\[Gamma] - \
1\))\)\^\(-1\) // ToUnit[Bar]\)], "Input"],

Cell[BoxData[
    \(p\_1 = \(p\_0\) \((x\_0\/x\_1)\)\^\[Gamma] // ToUnit[Bar]\)], "Input"],

Cell["Initial temperature", "Text"],

Cell[BoxData[
    \(T\_0 = \(\(p\_0\) M\_mol\)\/\(R\ \[Rho]\_0\) // ToSI\)], "Input"],

Cell["Exit temperature", "Text"],

Cell[BoxData[
    \(T\_1 = \(T\_0\) \(\(p\_1\) x\_1\)\/\(\(p\_0\) x\_0\) // ToSI\)], "Input"],

Cell["Radial strain", "Text"],

Cell[BoxData[
    \(u\_rr = \(a\^2\/\(b\^2 - a\^2\)\) \((1 - \[Nu] - \((1 + \[Nu])\) 
              b\^2\/a\^2)\) p\_0\/E\)], "Input"],

Cell["Azimuthal strain", "Text"],

Cell[BoxData[
    \(u\_\[Phi]\[Phi] = \(a\^2\/\(b\^2 - 
              a\^2\)\) \((1 - \[Nu] + \((1 + \[Nu])\) b\^2\/a\^2)\) 
        p\_0\/E\)], "Input"],

Cell["Longitudinal strain", "Text"],

Cell[BoxData[
    \(u\_zz = \(-2\) \[Nu]\ \(a\^2\/\(b\^2 - a\^2\)\) p\_0\/E\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
AutoGeneratedPackage->None,
WindowSize->{814, 956},
WindowMargins->{{84, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 35, 0, 95, "Title"],
Cell[1814, 55, 135, 3, 50, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1986, 63, 29, 0, 95, "Title"],
Cell[2018, 65, 175, 5, 33, "Text"],
Cell[2196, 72, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2267, 77, 42, 0, 73, "Section"],
Cell[2312, 79, 79, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2428, 85, 38, 0, 73, "Section"],
Cell[2469, 87, 22, 0, 33, "Text"],
Cell[2494, 89, 57, 1, 30, "Input"],
Cell[2554, 92, 28, 0, 33, "Text"],
Cell[2585, 94, 184, 3, 30, "Input"],
Cell[2772, 99, 32, 0, 33, "Text"],
Cell[2807, 101, 50, 1, 30, "Input"],
Cell[2860, 104, 34, 0, 33, "Text"],
Cell[2897, 106, 176, 3, 42, "Input"],
Cell[3076, 111, 39, 0, 33, "Text"],
Cell[3118, 113, 60, 1, 42, "Input"],
Cell[3181, 116, 47, 1, 30, "Input"],
Cell[3231, 119, 72, 0, 40, "Text"],
Cell[3306, 121, 22, 0, 33, "Text"],
Cell[3331, 123, 91, 1, 42, "Input"],
Cell[3425, 126, 49, 1, 30, "Input"],
Cell[3477, 129, 22, 0, 33, "Text"],
Cell[3502, 131, 141, 2, 30, "Input"],
Cell[3646, 135, 55, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3738, 141, 38, 0, 73, "Section"],
Cell[3779, 143, 221, 4, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4037, 152, 36, 0, 73, "Section"],
Cell[4076, 154, 163, 2, 44, "Input"],
Cell[4242, 158, 71, 1, 30, "Input"],
Cell[4316, 161, 78, 1, 30, "Input"],
Cell[4397, 164, 78, 1, 30, "Input"],
Cell[4478, 167, 84, 1, 30, "Input"],
Cell[4565, 170, 84, 1, 30, "Input"],
Cell[4652, 173, 84, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4785, 180, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[4835, 184, 46, 0, 73, "Section"],
Cell[4884, 186, 46, 1, 30, "Input"],
Cell[4933, 189, 26, 0, 33, "Text"],
Cell[4962, 191, 304, 5, 110, "Input"],
Cell[5269, 198, 22, 0, 33, "Text"],
Cell[5294, 200, 66, 1, 42, "Input"],
Cell[5363, 203, 27, 0, 33, "Text"],
Cell[5393, 205, 51, 1, 44, "Input"],
Cell[5447, 208, 28, 0, 33, "Text"],
Cell[5478, 210, 64, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5579, 216, 39, 0, 73, "Section"],
Cell[5621, 218, 46, 1, 30, "Input"],
Cell[5670, 221, 26, 0, 33, "Text"],
Cell[5699, 223, 365, 6, 130, "Input"],
Cell[6067, 231, 32, 0, 33, "Text"],
Cell[6102, 233, 57, 1, 30, "Input"],
Cell[6162, 236, 22, 0, 33, "Text"],
Cell[6187, 238, 76, 1, 43, "Input"],
Cell[6266, 241, 49, 1, 30, "Input"],
Cell[6318, 244, 88, 1, 44, "Input"],
Cell[6409, 247, 46, 1, 42, "Input"],
Cell[6458, 250, 63, 1, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6558, 256, 38, 0, 73, "Section"],
Cell[6599, 258, 46, 1, 30, "Input"],
Cell[6648, 261, 26, 0, 33, "Text"],
Cell[6677, 263, 240, 4, 90, "Input"],
Cell[6920, 269, 27, 0, 33, "Text"],
Cell[6950, 271, 87, 1, 40, "Input"],
Cell[7040, 274, 21, 0, 33, "Text"],
Cell[7064, 276, 85, 1, 42, "Input"],
Cell[7152, 279, 48, 1, 44, "Input"],
Cell[7203, 282, 42, 0, 33, "Text"],
Cell[7248, 284, 57, 1, 30, "Input"],
Cell[7308, 287, 48, 1, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7393, 293, 35, 0, 73, "Section"],
Cell[7431, 295, 46, 1, 30, "Input"],
Cell[7480, 298, 26, 0, 33, "Text"],
Cell[7509, 300, 281, 6, 130, "Input"],
Cell[7793, 308, 36, 0, 33, "Text"],
Cell[7832, 310, 214, 3, 70, "Input"],
Cell[8049, 315, 35, 0, 33, "Text"],
Cell[8087, 317, 41, 1, 30, "Input"],
Cell[8131, 320, 29, 0, 33, "Text"],
Cell[8163, 322, 41, 1, 30, "Input"],
Cell[8207, 325, 27, 0, 33, "Text"],
Cell[8237, 327, 65, 1, 42, "Input"],
Cell[8305, 330, 37, 0, 33, "Text"],
Cell[8345, 332, 85, 1, 42, "Input"],
Cell[8433, 335, 28, 0, 33, "Text"],
Cell[8464, 337, 43, 1, 30, "Input"],
Cell[8510, 340, 48, 1, 44, "Input"],
Cell[8561, 343, 46, 1, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8644, 349, 36, 0, 73, "Section"],
Cell[8683, 351, 46, 1, 30, "Input"],
Cell[8732, 354, 26, 0, 33, "Text"],
Cell[8761, 356, 223, 5, 110, "Input"],
Cell[8987, 363, 21, 0, 33, "Text"],
Cell[9011, 365, 67, 1, 30, "Input"],
Cell[9081, 368, 56, 1, 30, "Input"],
Cell[9140, 371, 29, 0, 33, "Text"],
Cell[9172, 373, 66, 1, 44, "Input"],
Cell[9241, 376, 34, 0, 33, "Text"],
Cell[9278, 378, 80, 1, 40, "Input"],
Cell[9361, 381, 29, 0, 33, "Text"],
Cell[9393, 383, 55, 1, 42, "Input"],
Cell[9451, 386, 48, 1, 30, "Input"],
Cell[9502, 389, 36, 0, 33, "Text"],
Cell[9541, 391, 75, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9665, 398, 25, 0, 95, "Title"],
Cell[9693, 400, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[9764, 405, 41, 0, 73, "Section"],
Cell[9808, 407, 23, 0, 33, "Text"],
Cell[9834, 409, 61, 1, 30, "Input"],
Cell[9898, 412, 31, 0, 33, "Text"],
Cell[9932, 414, 301, 6, 72, "Input"],
Cell[10236, 422, 37, 0, 33, "Text"],
Cell[10276, 424, 105, 2, 33, "Input"],
Cell[10384, 428, 31, 0, 33, "Text"],
Cell[10418, 430, 313, 6, 72, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10768, 441, 32, 0, 73, "Section"],
Cell[10803, 443, 97, 4, 33, "Text"],
Cell[10903, 449, 105, 2, 42, "Input"],
Cell[11011, 453, 40, 0, 33, "Text"],
Cell[11054, 455, 112, 2, 51, "Input"],
Cell[11169, 459, 35, 0, 33, "Text"],
Cell[11207, 461, 120, 2, 44, "Input"],
Cell[11330, 465, 55, 1, 30, "Input"],
Cell[11388, 468, 476, 9, 90, "Input"],
Cell[11867, 479, 227, 5, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12131, 489, 24, 0, 73, "Section"],
Cell[12158, 491, 106, 2, 44, "Input"],
Cell[12267, 495, 106, 2, 44, "Input"],

Cell[CellGroupData[{
Cell[12398, 501, 102, 4, 38, "Subsection"],
Cell[12503, 507, 62, 1, 30, "Input"],
Cell[12568, 510, 44, 1, 30, "Input"],
Cell[12615, 513, 44, 1, 30, "Input"],
Cell[12662, 516, 52, 1, 30, "Input"],
Cell[12717, 519, 179, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12933, 527, 38, 0, 38, "Subsection"],
Cell[12974, 529, 62, 1, 30, "Input"],
Cell[13039, 532, 44, 1, 30, "Input"],
Cell[13086, 535, 44, 1, 30, "Input"],
Cell[13133, 538, 52, 1, 30, "Input"],
Cell[13188, 541, 179, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13404, 549, 37, 0, 38, "Subsection"],
Cell[13444, 551, 50, 1, 30, "Input"],
Cell[13497, 554, 44, 1, 30, "Input"],
Cell[13544, 557, 44, 1, 30, "Input"],
Cell[13591, 560, 52, 1, 30, "Input"],
Cell[13646, 563, 51, 1, 30, "Input"],
Cell[13700, 566, 179, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13916, 574, 33, 0, 38, "Subsection"],
Cell[13952, 576, 71, 1, 30, "Input"],
Cell[14026, 579, 562, 10, 110, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14649, 596, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[14699, 600, 38, 0, 73, "Section"],
Cell[14740, 602, 46, 1, 30, "Input"],
Cell[14789, 605, 26, 0, 33, "Text"],
Cell[14818, 607, 786, 14, 304, "Input"],
Cell[15607, 623, 37, 0, 33, "Text"],
Cell[15647, 625, 82, 1, 31, "Input"],
Cell[15732, 628, 32, 0, 33, "Text"],
Cell[15767, 630, 72, 1, 31, "Input"],
Cell[15842, 633, 29, 0, 33, "Text"],
Cell[15874, 635, 74, 1, 31, "Input"],
Cell[15951, 638, 34, 0, 33, "Text"],
Cell[15988, 640, 74, 1, 30, "Input"],
Cell[16065, 643, 36, 0, 33, "Text"],
Cell[16104, 645, 178, 3, 47, "Input"],
Cell[16285, 650, 90, 1, 44, "Input"],
Cell[16378, 653, 35, 0, 33, "Text"],
Cell[16416, 655, 85, 1, 44, "Input"],
Cell[16504, 658, 32, 0, 33, "Text"],
Cell[16539, 660, 93, 1, 42, "Input"],
Cell[16635, 663, 29, 0, 33, "Text"],
Cell[16667, 665, 134, 2, 45, "Input"],
Cell[16804, 669, 32, 0, 33, "Text"],
Cell[16839, 671, 153, 3, 45, "Input"],
Cell[16995, 676, 35, 0, 33, "Text"],
Cell[17033, 678, 88, 1, 45, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

