(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9193,        338]*)
(*NotebookOutlinePosition[      9865,        361]*)
(*  CellTagsIndexPosition[      9821,        357]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["20. Rotating fluids", "Title"],

Cell[BoxData[{
    \(<< Lautrup`\), "\n", 
    \(<< Graphics`PlotField3D`\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Focault pendulum", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Local angular velocity", "Text"],

Cell[BoxData[
    \(\[CapitalOmega] = \(\(2  \[Pi]\)\/SiderealDay\) Cos[45\ Degree] // 
        ToSI\)], "Input"],

Cell["Local period of rotation", "Text"],

Cell[BoxData[
    \(\(2  \[Pi]\)\/\[CapitalOmega] // ToUnit[Hour]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ekman layer", "Title"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Ekman fields", "Text"],

Cell[BoxData[{
    \(\(v\_x = 1 - Exp[\(-z\)] Cos[z];\)\), "\n", 
    \(\(v\_y = Exp[\(-z\)] Sin[z];\)\)}], "Input"],

Cell["Verify integrals", "Text"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\( v\_y\) \[DifferentialD]z\)], "Input"],

Cell[BoxData[
    \(\[Integral]\_0\%\[Infinity]\((1 - v\_x)\) \[DifferentialD]z\)], "Input"],

Cell["Plot fields", "Text"],

Cell[BoxData[
    \(\(Plot[{v\_x, v\_y, 1, z}, {z, 0, 5}, 
          AxesLabel -> {"\<z/\[Delta]\>", "\<\>"}, 
          PlotRange -> {{0, 5}, {\(-0.1\), 1.3}}, PlotLabel -> "\<(a)\>", 
          PlotStyle -> {{Text[\*"\"\<\!\(v\_x\)/U\>\"", {2.1, 
                    1.2}]}, {Text[\*"\"\<\!\(v\_y\)/U\>\"", {2.1, 
                    0.2}]}, {Dashing[{0.03}]}, {Dashing[{0.03}]}}] \
// \[IndentingNewLine]Figure["\<rotating1\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell["Plot Ekman spiral", "Text"],

Cell[BoxData[
    \(\(ParametricPlot[{v\_x, v\_y}, {z, 0, 100}, 
          PlotRange -> {{0, 1.1}, {\(-0.05\), 0.4}}, \n
          AxesLabel -> {\*"\"\<\!\(v\_x\)\>\"", \*"\"\<\!\(v\_y\)\>\""}, 
          PlotLabel -> "\<(b)\>"] \
// \[IndentingNewLine]Figure["\<rotating2\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell["Plot vector field", "Text"],

Cell[BoxData[
    \(\(PlotVectorField3D[{v\_x, v\_y, 0}, {x, 0, 1}, {y, 0, 1}, {z, 0.15, 
            2}, ViewPoint \[Rule] {3, \(-1\), 3}, ScaleFactor \[Rule] 0.1, 
          MaxArrowLength \[Rule] 1, PlotPoints \[Rule] 6, 
          VectorHeads \[Rule] 
            True] // \[IndentingNewLine]Figure["\<rotating3\>", 
          ImageSize \[Rule] 200];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Atmosphere", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(\[Nu] = 1.54*^-5\ Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalOmega] = 0.5*^-4\ /Second;\)\)}], "Input"],

Cell[BoxData[
    \(\[Delta] = \@\(\[Nu]\/\[CapitalOmega]\) // ToSI\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["20.3.1 Coriolis effect on a stream", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(d = 10\ Kilometer;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalOmega] = \(1\/2\) 
          10\^\(-4\)\ /Second;\)\), "\[IndentingNewLine]", 
    \(\(U = 1. \ Meter/Second;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = \(10\^\(-6\)\) Meter\^2/Second;\)\)}], "Input"],

Cell["Maximal difference in water level", "Text"],

Cell[BoxData[
    \(\[CapitalDelta]h = \(\(2  \[CapitalOmega]\ U\)\/g\_0\) d // 
        ToUnit[Centimeter]\)], "Input"],

Cell["Rossby number", "Text"],

Cell[BoxData[
    \(Ro = U\/\(2  \[CapitalOmega]\ d\) // ToSI\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Rey = \(U\ d\)\/\[Nu] // ToSI\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bathtub vortex", "Title"],

Cell[CellGroupData[{

Cell["Experimental values at 18 RPM", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(CC = 16\ Centimeter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalOmega] = 18\ RPM // N;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = \(10\^\(-6\)\) Meter\^2/Second;\)\)}], "Input"],

Cell["Rossby radius", "Text"],

Cell[BoxData[
    \(R = \@\(CC\/\(2  \[CapitalOmega]\)\) // ToUnit[Centimeter]\)], "Input"],

Cell["Ekman layer thickness", "Text"],

Cell[BoxData[
    \(\[Delta] = \@\(\[Nu]\/\[CapitalOmega]\) // 
        ToUnit[Millimeter]\)], "Input"],

Cell["Ekman layer discharge rate", "Text"],

Cell[BoxData[
    \(Q = \[Pi]\ CC\ \[Delta] // ToUnit[Centimeter\^3]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Debunking an urban legend", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(L = 50. \ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(a = 2.5\ Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = \(10\^\(-6\)\) Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalOmega] = 0.5*^-4\ /Second;\)\), "\[IndentingNewLine]", 
    \(\(A = 1\ Meter;\)\)}], "Input"],

Cell["Vertical free fall velocity", "Text"],

Cell[BoxData[
    \(W = \@\(2 \( g\_0\) L\) // ToSI\)], "Input"],

Cell["Discharge throug drain", "Text"],

Cell[BoxData[
    \(Q = W\ \[Pi]\ a\^2 // ToUnit[Liter]\)], "Input"],

Cell["Ekman layer thickness", "Text"],

Cell[BoxData[
    \(\[Delta] = \@\(\[Nu]\/\[CapitalOmega]\) // 
        ToUnit[Centimeter]\)], "Input"],

Cell["Circulation constant", "Text"],

Cell[BoxData[
    \(CC = Q\/\(\[Pi]\ \[Delta]\) // ToUnit[Centimeter\^2]\)], "Input"],

Cell["Rossby radius", "Text"],

Cell[BoxData[
    \(R = \@\(CC\/\(2  \[CapitalOmega]\)\) // ToSI\)], "Input"],

Cell["Rotation velocity at rim of bathtub", "Text"],

Cell[BoxData[
    \(2  \[CapitalOmega]\ A // ToUnit[\ Millimeter]\)], "Input"],

Cell["Diffusion time", "Text"],

Cell[BoxData[
    \(t = L\^2\/\(4  \[Nu]\) // ToUnit[Hour]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["20.1 PingPong on a space station", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 1\/2*100\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(v = 4\ Meter/Second;\)\)}], "Input"],

Cell["Angular velocity", "Text"],

Cell[BoxData[
    \(\[CapitalOmega] = \@\(g\_0\/a\) // ToSI\)], "Input"],

Cell["Revolution time", "Text"],

Cell[BoxData[
    \(\(2  \[Pi]\)\/\[CapitalOmega]\)], "Input"],

Cell["Coriolis acceleration", "Text"],

Cell[BoxData[
    \(g\_c = 2  \[CapitalOmega]\ v // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["20.2 Great Belt", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(U\_0 = 1\ Meter/Second;\)\), "\n", 
    \(\(U\_1 = 1.25\ U\_0;\)\), "\n", 
    \(\(\[Rho]\_0 = 1.04  \[Rho]\_1;\)\), "\[IndentingNewLine]", 
    \(\(g\_0 = AccelerationDueToGravity;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalOmega] = 0.5*^-4/Second;\)\), "\[IndentingNewLine]", 
    \(\(d = 20\ Kilo\ Meter;\)\)}], "Input"],

Cell["Change in height of saline separation surface", "Text"],

Cell[BoxData[
    \(\[CapitalDelta]z = \(-\(\(2  \[CapitalOmega]\ \((\(U\_1\) \[Rho]\_1 - \
\(U\_0\) \[Rho]\_0)\) d\)\/\(\((\[Rho]\_1 - \[Rho]\_0)\) g\_0\)\)\) // 
        ToSI\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 937}},
AutoGeneratedPackage->None,
WindowSize->{823, 903},
WindowMargins->{{86, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 36, 0, 95, "Title"],
Cell[1815, 55, 115, 3, 50, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1967, 63, 33, 0, 95, "Title"],
Cell[2003, 65, 46, 1, 30, "Input"],
Cell[2052, 68, 38, 0, 33, "Text"],
Cell[2093, 70, 113, 2, 44, "Input"],
Cell[2209, 74, 40, 0, 33, "Text"],
Cell[2252, 76, 78, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2367, 82, 28, 0, 95, "Title"],
Cell[2398, 84, 51, 1, 30, "Input"],
Cell[2452, 87, 28, 0, 33, "Text"],
Cell[2483, 89, 116, 2, 50, "Input"],
Cell[2602, 93, 32, 0, 33, "Text"],
Cell[2637, 95, 87, 1, 41, "Input"],
Cell[2727, 98, 92, 1, 41, "Input"],
Cell[2822, 101, 27, 0, 33, "Text"],
Cell[2852, 103, 480, 8, 110, "Input"],
Cell[3335, 113, 33, 0, 33, "Text"],
Cell[3371, 115, 326, 6, 70, "Input"],
Cell[3700, 123, 33, 0, 33, "Text"],
Cell[3736, 125, 369, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[4130, 135, 29, 0, 73, "Section"],
Cell[4162, 137, 46, 1, 30, "Input"],
Cell[4211, 140, 146, 2, 50, "Input"],
Cell[4360, 144, 80, 1, 51, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4489, 151, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[4539, 155, 53, 0, 73, "Section"],
Cell[4595, 157, 46, 1, 30, "Input"],
Cell[4644, 160, 26, 0, 33, "Text"],
Cell[4673, 162, 360, 6, 124, "Input"],
Cell[5036, 170, 49, 0, 33, "Text"],
Cell[5088, 172, 120, 2, 44, "Input"],
Cell[5211, 176, 29, 0, 33, "Text"],
Cell[5243, 178, 74, 1, 43, "Input"],
Cell[5320, 181, 31, 0, 33, "Text"],
Cell[5354, 183, 62, 1, 42, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5465, 190, 31, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[5521, 194, 48, 0, 73, "Section"],
Cell[5572, 196, 46, 1, 30, "Input"],
Cell[5621, 199, 26, 0, 33, "Text"],
Cell[5650, 201, 215, 3, 70, "Input"],
Cell[5868, 206, 29, 0, 33, "Text"],
Cell[5900, 208, 91, 1, 51, "Input"],
Cell[5994, 211, 37, 0, 33, "Text"],
Cell[6034, 213, 103, 2, 51, "Input"],
Cell[6140, 217, 42, 0, 33, "Text"],
Cell[6185, 219, 81, 1, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6303, 225, 44, 0, 73, "Section"],
Cell[6350, 227, 46, 1, 30, "Input"],
Cell[6399, 230, 26, 0, 33, "Text"],
Cell[6428, 232, 389, 6, 130, "Input"],
Cell[6820, 240, 43, 0, 33, "Text"],
Cell[6866, 242, 64, 1, 32, "Input"],
Cell[6933, 245, 38, 0, 33, "Text"],
Cell[6974, 247, 68, 1, 30, "Input"],
Cell[7045, 250, 37, 0, 33, "Text"],
Cell[7085, 252, 103, 2, 51, "Input"],
Cell[7191, 256, 36, 0, 33, "Text"],
Cell[7230, 258, 85, 1, 43, "Input"],
Cell[7318, 261, 29, 0, 33, "Text"],
Cell[7350, 263, 77, 1, 51, "Input"],
Cell[7430, 266, 51, 0, 33, "Text"],
Cell[7484, 268, 78, 1, 30, "Input"],
Cell[7565, 271, 30, 0, 33, "Text"],
Cell[7598, 273, 71, 1, 46, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7718, 280, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[7768, 284, 51, 0, 73, "Section"],
Cell[7822, 286, 46, 1, 30, "Input"],
Cell[7871, 289, 26, 0, 33, "Text"],
Cell[7900, 291, 187, 3, 83, "Input"],
Cell[8090, 296, 32, 0, 33, "Text"],
Cell[8125, 298, 72, 1, 51, "Input"],
Cell[8200, 301, 31, 0, 33, "Text"],
Cell[8234, 303, 62, 1, 42, "Input"],
Cell[8299, 306, 37, 0, 33, "Text"],
Cell[8339, 308, 69, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8445, 314, 34, 0, 73, "Section"],
Cell[8482, 316, 46, 1, 30, "Input"],
Cell[8531, 319, 26, 0, 33, "Text"],
Cell[8560, 321, 349, 6, 130, "Input"],
Cell[8912, 329, 61, 0, 33, "Text"],
Cell[8976, 331, 189, 3, 44, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

