(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8923,        320]*)
(*NotebookOutlinePosition[      9597,        343]*)
(*  CellTagsIndexPosition[      9553,        339]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["21. Computational Fluid Dynamics", "Title",
  InitializationCell->True],

Cell[BoxData[{
    \(<< Lautrup`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\), "\[IndentingNewLine]", 
    \(<< \ Graphics`PlotField`\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(Off[InterpolatingFunction::dmval];\)\)], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simulation", "Title"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Read simulation data", "Section"],

Cell[BoxData[{
    \(\(input\  = \ OpenRead["\<cfd.dat\>"];\)\), "\[IndentingNewLine]", 
    \(\(Read[input, Expression]\  (*\ initial\ data\ *) ;\)\)}], "Input"],

Cell["Length along flow (x)", "Text"],

Cell[BoxData[
    \(a\)], "Input"],

Cell["Distance between plates (y)", "Text"],

Cell[BoxData[
    \(b\)], "Input"],

Cell["Number of lattice points along x", "Text"],

Cell[BoxData[
    \(NX\)], "Input"],

Cell["Number of lattice points along y", "Text"],

Cell[BoxData[
    \(NY\)], "Input"],

Cell["Kinematic viscosity", "Text"],

Cell[BoxData[
    \(nu\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds\)], "Input"],

Cell["Entrance plug velocity", "Text"],

Cell[BoxData[
    \(u0\)], "Input"],

Cell["Convergence parameters", "Text"],

Cell[BoxData[
    \(omega\)], "Input"],

Cell["Obtained accuracy", "Text"],

Cell[BoxData[
    \(accuracy\)], "Input"],

Cell[BoxData[{
    \(\(SetOptions[ListInterpolation, 
        InterpolationOrder \[Rule] {1, 1}];\)\), "\n", 
    \(\(SetOptions[Plot3D, PlotRange \[Rule] All, 
        PlotPoints \[Rule] {If[NX \[LessEqual] 50, NX, 50], 
            If[NY \[LessEqual] 50, NY, 50]}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize an iteration", "Section"],

Cell["Read next iteration data", "Text"],

Cell[BoxData[
    \(\(Read[input, Expression];\)\)], "Input"],

Cell["Number of iterations until this point", "Text"],

Cell[BoxData[
    \(iter\)], "Input"],

Cell["Precision obtained", "Text"],

Cell[BoxData[
    \(precision\)], "Input"],

Cell["Value of divergence", "Text"],

Cell[BoxData[
    \(divergence\)], "Input"],

Cell["\"Real time\"", "Text"],

Cell[BoxData[
    \(t\)], "Input"],

Cell[BoxData[
    \(dt\)], "Input"],

Cell["Make interpolations of all the data and plot it", "Text"],

Cell[BoxData[{
    \(\(vxi\  = \ ListInterpolation[vx, {x, y}];\)\), "\n", 
    \(\(vyi\  = \ ListInterpolation[vy, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(fxi\  = \ ListInterpolation[fx, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(fyi\  = \ ListInterpolation[fy, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pi\  = \ ListInterpolation[p, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(hi\  = \ ListInterpolation[h, {x, y}];\)\)}], "Input"],

Cell[BoxData[
    \(\(Plot3D[vxi[x1, y1], {x1, 0, a/4}, {y1, 0, b}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[vyi[x1, y1], {x1, 0, a}, {y1, 0, b}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[fxi[x1, y1], {x1, 0, a}, {y1, 0, b}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[fyi[x1, y1], {x1, 0, a}, {y1, 0, b}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[pi[x1, y1], {x1, 0, a}, {y1, 0, b}];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[hi[x1, y1], {x1, 0, a}, {y1, 0, b}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mid channel flow", "Section"],

Cell[BoxData[
    \(\(Plot[{vxi[x1, b/2], 1.5*u0}, {x1, 0, a}, PlotRange \[Rule] All, 
          PlotLabel -> "\<(b)\>", 
          AxesLabel \[Rule] {"\<x\>", \*"\"\<\!\(v\_x\)\>\""}, 
          PlotStyle -> {Dashing[{}], 
              Dashing[{0.02, 
                  0.02}]}] // \[IndentingNewLine]Figure["\<cfd1\>", 
          ImageSize \[Rule] 250];\)\)], "Input"],

Cell["Find 95% point and normalize", "Text"],

Cell[BoxData[{
    \(FindRoot[vxi[x1, b/2] == 0.95  vxi[a, b/2], {x1, a/10}]\), "\n", 
    \(k = \(x1/b\)/Reynolds /. %\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Entrance flow", "Section"],

Cell[BoxData[
    \(\(poiseuille\  = \ 
        Plot[6  u0\ \ y1 \((b - y1)\), {y1, 0, b}, 
          PlotStyle \[Rule] {Dashing[{0.01, 0.01}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(flowdata\  = 
        Plot[Table[vxi[x1, y1], {x1, 0, a/2, a/NX}] // Evaluate, {y1, 0, b}, 
          PlotRange \[Rule] {{0, b}, All}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[poiseuille, flowdata, PlotRange \[Rule] All, 
          AxesLabel \[Rule] {"\<y\>", \*"\"\<\!\(v\_x\)\>\""}] \
// \[IndentingNewLine]Figure["\<cfd2\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fig. 19.6a Pressure at entrance", "Section"],

Cell[BoxData[
    \(\(Plot[{pi[x1, b/2], 12\ nu\ u0 \((a - x1)\)/b^2}, {x1, 0, a}, 
          PlotRange \[Rule] All, PlotLabel -> "\<(a)\>", 
          AxesLabel \[Rule] {"\<x\>", "\<p\>"}] \
// \[IndentingNewLine]Figure["\<cfd4\>", ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Velocity rise with time", "Title"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[TextData[{
  "Simulation data on ",
  Cell[BoxData[
      \(TraditionalForm\`exit\ velocity\ as\ a\ function\ of\ time\)]]
}], "Text"],

Cell[BoxData[
    \(\(vxdata = {{0, 1}, {0.125, 1.0785}, {0.248, 1.1186}, {0.495, 
            1.1775}, {0.743, 1.2141}, {0.99, 1.2673}, {1.49, 1.3365}, {1.98, 
            1.3874}, {2.48, 1.4231}, {2.97, 1.4476}, {3.96, 1.4753}, {5.01, 
            1.4883}, {7.49, 1.4968}, {9.47, 1.4978}};\)\)], "Input"],

Cell["Make an interpolation", "Text"],

Cell[BoxData[
    \(\(vxi = 
        Interpolation[vxdata, InterpolationOrder \[Rule] 1];\)\)], "Input"],

Cell["Find 95% point", "Text"],

Cell[BoxData[
    \(FindRoot[vxi[x] == 0.95  vxi[10], {x, 0.5}]\)], "Input"],

Cell["Plot the field", "Text"],

Cell[BoxData[
    \(\(Plot[{vxi[x], 1.5}, {x, 0, 10}, PlotRange \[Rule] All, 
          PlotLabel -> "\<(a)\>", 
          PlotStyle \[Rule] {Dashing[{}], Dashing[{0.02, 0.02}]}, 
          AxesLabel \[Rule] {"\<t\>", \*"\"\<\!\(v\_x\)\>\""}] \
// \[IndentingNewLine]Figure["\<cfd3\>", ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Entrance length", "Title"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["\<\
Simulation data on entrance length for different Reynolds numbers\
\>", "Text"],

Cell[BoxData[
    \(\(lx = {{0.001, 0.431}, {0.01, 0.431}, {0.1, 0.432}, {1, 0.440}, {2, 
            0.449}, {3, 0.461}, {4, 0.473}, {5, 0.485}, {6, 0.497}, {10, 
            0.554}, {20, 0.723}, {50, 1.352}, {100, 2.385}, {200, 
            4.280}, {500, 9.99}, {1000, 19.76}, {2000, 39.51}, {5000, 
            95.81}};\)\)], "Input"],

Cell[BoxData[
    \(fit = Fit[lx, {x}, x]\)], "Input"],

Cell[BoxData[
    \(\(lxi = Interpolation[lx];\)\)], "Input"],

Cell[BoxData[
    \(\(LogLogPlot[{lxi[x], fit}, {x, 1, 5000}, 
          PlotRange \[Rule] {{1, 10000}, All}, PlotLabel -> "\<(b)\>", 
          PlotStyle \[Rule] {Dashing[{}], Dashing[{0.02, 0.02}]}, 
          AxesLabel \[Rule] {"\<Re\>", "\<L'/d\>"}] \
// \[IndentingNewLine]Figure["\<cfd5\>", ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 937}},
AutoGeneratedPackage->None,
WindowSize->{728, 740},
WindowMargins->{{122, Automatic}, {57, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 77, 1, 95, "Title",
  InitializationCell->True],
Cell[1856, 56, 187, 4, 70, "Input",
  InitializationCell->True],
Cell[2046, 62, 99, 2, 30, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[2182, 69, 27, 0, 95, "Title"],
Cell[2212, 71, 51, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2288, 76, 39, 0, 73, "Section"],
Cell[2330, 78, 162, 2, 50, "Input"],
Cell[2495, 82, 37, 0, 33, "Text"],
Cell[2535, 84, 34, 1, 30, "Input"],
Cell[2572, 87, 43, 0, 33, "Text"],
Cell[2618, 89, 34, 1, 30, "Input"],
Cell[2655, 92, 48, 0, 33, "Text"],
Cell[2706, 94, 35, 1, 30, "Input"],
Cell[2744, 97, 48, 0, 33, "Text"],
Cell[2795, 99, 35, 1, 30, "Input"],
Cell[2833, 102, 35, 0, 33, "Text"],
Cell[2871, 104, 35, 1, 30, "Input"],
Cell[2909, 107, 31, 0, 33, "Text"],
Cell[2943, 109, 41, 1, 30, "Input"],
Cell[2987, 112, 38, 0, 33, "Text"],
Cell[3028, 114, 35, 1, 30, "Input"],
Cell[3066, 117, 38, 0, 33, "Text"],
Cell[3107, 119, 38, 1, 30, "Input"],
Cell[3148, 122, 33, 0, 33, "Text"],
Cell[3184, 124, 41, 1, 30, "Input"],
Cell[3228, 127, 283, 5, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3548, 137, 41, 0, 73, "Section"],
Cell[3592, 139, 40, 0, 33, "Text"],
Cell[3635, 141, 61, 1, 30, "Input"],
Cell[3699, 144, 53, 0, 33, "Text"],
Cell[3755, 146, 37, 1, 30, "Input"],
Cell[3795, 149, 34, 0, 33, "Text"],
Cell[3832, 151, 42, 1, 30, "Input"],
Cell[3877, 154, 35, 0, 33, "Text"],
Cell[3915, 156, 43, 1, 30, "Input"],
Cell[3961, 159, 29, 0, 33, "Text"],
Cell[3993, 161, 34, 1, 30, "Input"],
Cell[4030, 164, 35, 1, 30, "Input"],
Cell[4068, 167, 63, 0, 33, "Text"],
Cell[4134, 169, 448, 6, 130, "Input"],
Cell[4585, 177, 83, 1, 30, "Input"],
Cell[4671, 180, 81, 1, 30, "Input"],
Cell[4755, 183, 81, 1, 30, "Input"],
Cell[4839, 186, 81, 1, 30, "Input"],
Cell[4923, 189, 80, 1, 30, "Input"],
Cell[5006, 192, 80, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5123, 198, 35, 0, 73, "Section"],
Cell[5161, 200, 371, 7, 70, "Input"],
Cell[5535, 209, 44, 0, 33, "Text"],
Cell[5582, 211, 133, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5752, 218, 32, 0, 73, "Section"],
Cell[5787, 220, 160, 3, 30, "Input"],
Cell[5950, 225, 172, 3, 50, "Input"],
Cell[6125, 230, 194, 3, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6356, 238, 50, 0, 73, "Section"],
Cell[6409, 240, 271, 4, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6729, 250, 40, 0, 95, "Title"],
Cell[6772, 252, 51, 1, 30, "Input"],
Cell[6826, 255, 139, 4, 33, "Text"],
Cell[6968, 261, 306, 4, 70, "Input"],
Cell[7277, 267, 37, 0, 33, "Text"],
Cell[7317, 269, 104, 2, 30, "Input"],
Cell[7424, 273, 30, 0, 33, "Text"],
Cell[7457, 275, 76, 1, 30, "Input"],
Cell[7536, 278, 30, 0, 33, "Text"],
Cell[7569, 280, 324, 5, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7930, 290, 32, 0, 95, "Title"],
Cell[7965, 292, 51, 1, 30, "Input"],
Cell[8019, 295, 89, 2, 33, "Text"],
Cell[8111, 299, 337, 5, 90, "Input"],
Cell[8451, 306, 54, 1, 30, "Input"],
Cell[8508, 309, 61, 1, 30, "Input"],
Cell[8572, 312, 335, 5, 90, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

