(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51634,       1870]*)
(*NotebookOutlinePosition[     52307,       1893]*)
(*  CellTagsIndexPosition[     52263,       1889]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["28. Boundary layers", "Title"],

Cell[BoxData[{
    \(<< Lautrup`\), "\n", 
    \(<< Graphics`\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stokes first problem", "Title"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Identify error function", "Text"],

Cell[BoxData[
    \(f[s_] = \(2\/\@\[Pi]\) \(\[Integral]\_0\%s\( \[ExponentialE]\^\(-t\^2\)\
\) \[DifferentialD]t\)\)], "Input"],

Cell["Slope at zero", "Text"],

Cell[BoxData[
    \(\[Gamma] = \(f'\)[0]\)], "Input"],

Cell[BoxData[
    \(\[Gamma] // N\)], "Input"],

Cell[BoxData[
    \(1\/\[Gamma] // N\)], "Input"],

Cell["Find 99% point", "Text"],

Cell[BoxData[
    \(k /. FindRoot[f[k] \[Equal] 0.99, {k, 0.5}]\)], "Input"],

Cell["Plot", "Text"],

Cell[BoxData[
    \(\(fig1a = 
        Plot[{f[s]}, {s, 0, 2}, PlotRange -> {0, 1.1}, 
          AxesLabel -> {"\<s\>", "\<f(s)\>"}, 
          PlotLabel \[Rule] "\<(a)\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = 
        Graphics[{Dashing[{0.02}], Line[{{0, 0}, {1\/\[Gamma], 1}}], 
            Dashing[{0.02}], Line[{{0, 1}, {2, 1}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b] // \[IndentingNewLine]Figure["\<boundaries1a\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Blasius solution", "Title"],

Cell[CellGroupData[{

Cell["Blasius equation", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Transform to Cartesian coordinats", "Text"],

Cell[BoxData[
    \(\(do[rhs_] := rhs /. s -> y \@\( U\/\(2  \[Nu]\ x\)\);\)\)], "Input"],

Cell["Properties of  Blasius function", "Text"],

Cell[BoxData[
    \(\(g[0] = 0;\)\)], "Input"],

Cell[BoxData[
    \(\(f[s_] = \(g'\)[s];\)\)], "Input"],

Cell["Velocity field", "Text"],

Cell[BoxData[{
    \(\(v\_x = U\ f[s] // do;\)\), "\[IndentingNewLine]", 
    \(\(v\_y = \(-\[PartialD]\_x\(\[Integral]\_0\%y\( 
                    v\_x\) \[DifferentialD]y\)\);\)\)}], "Input"],

Cell["Prandtl equation", "Text"],

Cell[BoxData[
    \(\(zero = \[Nu]\ \[PartialD]\_y\^2 v\_x - \(v\_x\) \[PartialD]\_x v\_x - \
\(v\_y\) \[PartialD]\_y v\_x;\)\)], "Input"],

Cell["Transform back to scaling variable", "Text"],

Cell[BoxData[
    \(do[rhs_] := \(\((rhs /. y \[Rule] s\ \@\(\(2  x\ \[Nu]\)\/U\))\) // 
          PowerExpand\) // Simplify\)], "Input"],

Cell["Velocity field in scaling variables", "Text"],

Cell[BoxData[
    \(v\_x // do\)], "Input"],

Cell[BoxData[
    \(v\_y // do\)], "Input"],

Cell["Blasius equation", "Text"],

Cell[BoxData[
    \(zero\ \ 2  x/U\^2 // do\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve the equation by rescaling", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Upper cutoff", "Text"],

Cell[BoxData[
    \(\(A = 40;\)\)], "Input"],

Cell["Solution to equation", "Text"],

Cell[BoxData[
    \(sol = 
      Block[{f, 
          g}, {f, g} /. 
            NDSolve[{\(f''\)[s] == \(-\ g[s]\)\ \(f'\)[s], \(g'\)[s] \[Equal] 
                  f[s], \ g[0] \[Equal] 0, 
                f[0] \[Equal] 0, \(f'\)[0] \[Equal] 1}, {f, g}, {s, 0, A}, 
              AccuracyGoal \[Rule] 12, PrecisionGoal \[Rule] 12] // 
          First]\)], "Input"],

Cell["Scaling constant", "Text"],

Cell[BoxData[
    \(a = \@\(sol[\([1]\)]\)[A]\)], "Input"],

Cell["Blasius functions", "Text"],

Cell[BoxData[{
    \(\(f[
          s_] = \(1\/a\^2\) \(sol[\([1]\)]\)[\ 
            s\/a];\)\), "\[IndentingNewLine]", 
    \(\(g[s_] = \(1\/a\) \(sol[\([2]\)]\)[\ s\/a];\)\)}], "Input"],

Cell["Slope", "Text"],

Cell[BoxData[
    \(\[Mu] = \(f'\)[0]\)], "Input"],

Cell[BoxData[
    \(\[Mu] \@ 2\)], "Input"],

Cell["99% point", "Text"],

Cell[BoxData[
    \(s\_99 = s /. FindRoot[f[s] \[Equal] 0.99, {s, 0.5}]\)], "Input"],

Cell[BoxData[
    \(\(s\_99\) \@2\)], "Input"],

Cell["Helping function", "Text"],

Cell[BoxData[
    \(\(h[s_]\  = \ s\ f[s] - g[s];\)\)], "Input"],

Cell[BoxData[
    \(hinf = h[A]\)], "Input"],

Cell[BoxData[
    \(\(8  \[Mu]\)\/\@2\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots", "Section"],

Cell[BoxData[
    \(\(fig2a = 
        Plot[{f[s], \[Mu]\ s, 1}, {s, 0, 4}, PlotRange \[Rule] {0, 1}, 
            AxesLabel -> {"\<s\>", "\<f(s)\>"}, 
            PlotStyle -> {{}, {Dashing[{0.02}]}, {Dashing[{0.02}]}, \
{Dashing[{0.01}]}}, PlotLabel \[Rule] "\<(a)\>"] // 
          Figure["\<boundaries2a\>", ImageSize \[Rule] 250];\)\)], "Input"],

Cell[BoxData[
    \(\(fig2b = 
        Plot[{h[s], hinf}, {s, 0, 4}, PlotRange \[Rule] All, 
            AxesLabel -> {"\<s\>", "\<h(s)\>"}, 
            PlotStyle -> {{}, {Dashing[{0.02}]}}, 
            PlotLabel \[Rule] "\<(b)\>"] \
// \[IndentingNewLine]Figure["\<boundaries2b\>", 
            ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Special integrals for the Blasius solution", "Section"],

Cell[BoxData[
    \(\[Lambda]\_wall = 1\/\[Mu]\)], "Input"],

Cell[BoxData[
    \(\[Lambda]\_disp = NIntegrate[1 - f[s], {s, 0, A}]\)], "Input"],

Cell[BoxData[
    \(\[Lambda]\_mom = NIntegrate[\((1 - f[s])\) f[s], {s, 0, A}]\)], "Input"],

Cell[BoxData[
    \(\[Lambda]\_ener = 
      NIntegrate[\((1 - f[s]\^2)\) f[s], {s, 0, A}]\)], "Input"],

Cell[BoxData[
    \(\[Lambda]\_heat = 1/NIntegrate[\(f'\)[s]\^2, {s, 0, A}]\)], "Input"],

Cell[BoxData[
    \(2 \( \[Lambda]\_wall\) \[Lambda]\_mom\)], "Input"],

Cell[BoxData[
    \(\(\[Lambda]\_ener\) \[Lambda]\_heat\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Blasius flow plot", "Section"],

Cell[BoxData[
    \(\(\[Psi][x_, y_] = \ 
        Which[x \[LessEqual] 0, Abs[y], Abs[y] > \ 100\ \@\(2  x\), 
          Abs[y\ ] - \(\@\(2  x\)\) hinf, 
          True, \(\@\(\(2\)\(\ \)\(x\)\(\ \)\)\) 
            g[Abs[y]\/\@\(2  x\)]];\)\)], "Input"],

Cell[BoxData[
    \(\(plot1 = 
        ContourPlot[\[Psi][x, y], {x, \(-3\), 10}, {y, \(-15\), 15}, 
          ContourShading \[Rule] False, PlotPoints \[Rule] 300, 
          Contours \[Rule] 12, FrameLabel -> {"\<x\>", "\<y\>"}, 
          RotateLabel -> False, 
          AspectRatio \[Rule] 1/GoldenRatio];\)\)], "Input"],

Cell[BoxData[
    \(\(\[Delta][x_] = 5 \@ x;\)\)], "Input"],

Cell[BoxData[
    \(\(plot2 = 
        Plot[{\(-\[Delta][x]\), \[Delta][x]}, {x, 0, 10}, 
          PlotStyle -> {{Thickness[0.007], Dashing[{0.03}]}}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[plot1, plot2, 
          Graphics[{Dashing[{0.01}], Line[{{\(-3\), 0}, {0, 0}}], 
              Dashing[{}], \[IndentingNewLine]Thickness[0.007], 
              Line[{{0, 0}, {10, 
                    0}}]}]] // \[IndentingNewLine]Figure["\<boundaries3\>", 
          ImageSize \[Rule] 500];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Turbulent boundary layers", "Title"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Friction coefficient", "Section"],

Cell["Special values of the Reynolds number", "Text"],

Cell[BoxData[{
    \(\(R\_0 = \ 0.5\ 10\^6;\)\), "\[IndentingNewLine]", 
    \(\(R\_1 = \ 3\ 10\^6;\)\), "\[IndentingNewLine]", 
    \(\(R\_2 = 10\^9;\)\), "\[IndentingNewLine]", 
    \(\(R\_3 = 10\^10;\)\)}], "Input"],

Cell["Laminar friction coefficient", "Text"],

Cell[BoxData[
    \(\(C\_lam[r_] = 0.664\/\@r;\)\)], "Input"],

Cell["Smooth plate friction coefficient", "Text"],

Cell[BoxData[
    \(\(C\_smooth[r_] = 0.027\/r\^\(1\/7\);\)\)], "Input"],

Cell[BoxData[
    \(\(C\_rough = C\_smooth[R\_2];\)\)], "Input"],

Cell[BoxData[
    \(\(fig5a = LogLogPlot[C\_lam[r], {r, 1, R\_0}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig5b = LogLogPlot[C\_smooth[r], {r, R\_0, R\_2}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig5c = LogLogPlot[C\_rough, {r, R\_2, R\_3}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig5a, fig5b, fig5c, 
          Graphics[{Dashing[{0.02}], 
              Line[{{5.7, \(-3.5\)}, {5.7, \(-0.9\)}}], 
              Line[{{9, \(-3.5\)}, {9, \(-0.9\)}}], 
              Text["\<laminar\>", {4.5, \(-1.5\)}], 
              Text["\<smooth\nplate\>", {7.5, \(-3.1\)}], 
              Text["\<rough\nplate\>", {9.6, \(-3.1\)}], 
              Text["\<turbulent\>", {8, \(-1.5\)}], 
              Text[\*"\"\<\!\(c\_f\)~\!\(Re\_x\^\(-\(1\/2\)\)\)\>\"", {4.5, \
\(-2.0\)}], 
              Text[\*"\"\<\!\(c\_f\)~\!\(Re\_x\^\(-\(1\/7\)\)\)\>\"", {7.5, \
\(-2.4\)}], 
              Text[\*"\"\<\!\(c\_f\)~const\>\"", {9.8, \(-2.7\)}]}], \
\[IndentingNewLine]AxesOrigin \[Rule] {2.7, \(-3.5\)}, 
          PlotRange \[Rule] {{2.7, 10.2}, {\(-3.5\), \(-0.9\)}}, 
          AxesLabel \[Rule] {\*"\"\<\!\(Re\_x\)\>\"", \
\*"\"\<\!\(c\_f\)\>\""}, 
          Ticks \[Rule] {Table[{n, "\<10\>"\^n}, {n, 3, 10}], 
              Table[{\(-n\), 10\^\(-n\) // N}, {n, 1, 
                  4}]}] // \[IndentingNewLine]Figure["\<boundaries5\>"];\)\)],\
 "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["True boundary layer thickness", "Section"],

Cell["Laminar case", "Text"],

Cell[BoxData[
    \(\(\[Delta]\_lam[r_] = 5 \@ r;\)\)], "Input"],

Cell["Smooth wall case", "Text"],

Cell[BoxData[
    \(\(\[Delta]\_smooth[r_] = 
        5 \@ R\_0 + 0.16 \((r\^\(6\/7\) - \ R\_0\^\(6\/7\))\);\)\)], "Input"],

Cell["Rough wall case", "Text"],

Cell[BoxData[
    \(\(\[Delta]\_rough[r_] = \[Delta]\_smooth[R\_2] + 
          10.3 \( 1\/2\) \(C\_rough\) \((r - R\_2)\);\)\)], "Input"],

Cell["Sublayer", "Text"],

Cell[BoxData[
    \(\(\[Delta]\_\[Nu][r_] = 
        If[r < R\_2, 206\ r\^\(1\/42\), 206\ R\_2\^\(1\/42\)];\)\)], "Input"],

Cell[BoxData[
    \(206\ R\_2\^\(1\/42\) // N\)], "Input"],

Cell["Make log-log plot", "Text"],

Cell[BoxData[
    \(\(fig6a = LogLogPlot[\[Delta]\_lam[r], {r, 1, R\_0}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig6b = 
        LogLogPlot[{\[Delta]\_smooth[r], \[Delta]\_\[Nu][r]}, {r, R\_0, 
            R\_2}, PlotDivision \[Rule] 100, MaxBend \[Rule] 1];\)\)], "Input"],

Cell[BoxData[
    \(\(fig6c = 
        LogLogPlot[{\[Delta]\_rough[r], \[Delta]\_\[Nu][r]}, {r, R\_2, 
            R\_3}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig6d = 
        Graphics[{Dashing[{0.02}], Line[{{5.7, 1.5}, {5.7, 8}}], 
            Line[{{9, 1.5}, {9, 8}}], Text["\<laminar\>", {4.5, 7}], 
            Text["\<smooth\nplate\>", {7.2, 3}], 
            Text["\<rough\nplate\>", {9.5, 3}], 
            Text["\<turbulent\>", {8, 7}], 
            Text[\*"\"\<\[Delta]~\!\(x\^\(1\/2\)\)\>\"", {4.5, 2.5}], 
            Text[\*"\"\<\[Delta]~\!\(x\^\(6\/7\)\)\>\"", {7.5, 5}], 
            Text["\<\[Delta]~x\>", {9.5, 6.9}], 
            Text[\*"\"\<\!\(\[Delta]\_\[Nu]\)~\!\(x\^\(1\/42\)\)\>\"", {7.5, 
                2.2}], Text[\*"\"\<\!\(\[Delta]\_\[Nu]\)~const\>\"", {9.7, 
                2.2}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig6a, fig6b, fig6c, fig6d, AxesOrigin \[Rule] {2.9, 1.5}, 
          PlotRange \[Rule] {{2.9, 10.2}, {1.5, 8}}, 
          AxesLabel \[Rule] {\*"\"\<\!\(Re\_x\)=\!\(Ux\/\[Nu]\)\>\"", \*"\"\<\
\!\(Re\_\[Delta]\)=\!\(U\[Delta]\/\[Nu]\)\>\""}, 
          Ticks \[Rule] {Table[{n, "\<10\>"\^n}, {n, 3, 10}], 
              Table[{n, "\<10\>"\^n}, {n, 1, 
                  8}]}] // \[IndentingNewLine]Figure["\<boundaries6\>"];\)\)],\
 "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Falkner-Skan solutions", "Title"],

Cell[CellGroupData[{

Cell["Falkner-Skan equation", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Transform to Cartesian variables", "Text"],

Cell[BoxData[
    \(\(do[rhs_] := rhs /. s \[Rule] y\/\[Delta][x];\)\)], "Input"],

Cell["Velocity field", "Text"],

Cell[BoxData[{
    \(\(v\_x = U[x]\ \(g'\)[s] // do;\)\), "\[IndentingNewLine]", 
    \(\(v\_y = \(-\[PartialD]\_x\ \((U[x] \[Delta][x] g[s] // 
                do)\)\);\)\)}], "Input"],

Cell["Transform back to scaling variable", "Text"],

Cell[BoxData[
    \(do[rhs_] := \(\((rhs /. y \[Rule] s\ \ \[Delta][x])\) // PowerExpand\) // 
        Simplify\)], "Input"],

Cell["Prandtl equation", "Text"],

Cell[BoxData[
    \(zero = 
      U[x] \(U'\)[
              x] + \[Nu]\ \[PartialD]\_y\(\[PartialD]\_y v\_x\) - \(v\_x\) \
\[PartialD]\_x v\_x - \(v\_y\) \[PartialD]\_y v\_x // do\)], "Input"],

Cell["Introduce constants \[Alpha] and \[Beta]", "Text"],

Cell[BoxData[
    \(\(\(U'\)[x] = \(\[Nu]\ \[Beta]\)\/\[Delta][x]\^2;\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{
          SuperscriptBox["\[Delta]", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}], 
        "=", \(\(\((\[Alpha] - \[Beta])\) \[Nu]\)\/\(\[Delta][x]\ U[x]\)\)}], 
      ";"}]], "Input"],

Cell["The Falkner-Skan equation", "Text"],

Cell[BoxData[
    \(zero\ \ \[Delta][x]\^2\/\(\[Nu]\ U[x]\) // Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Solve Falkner-Skan ", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Relation between m and \[Beta]", "Text"],

Cell[BoxData[
    \(m[\[Beta]_] := \[Beta]\/\(2 - \[Beta]\)\)], "Input"],

Cell["Solution to Falkner-Skan equation by ballistic method", "Text"],

Cell[BoxData[
    \(sol[\[Mu]_?NumericQ, \[Beta]_?NumericQ, A_?NumericQ] := 
      Module[{f, g, 
          h}, {f, g, h} /. 
            NDSolve[{\(h'\)[
                    s] \[Equal] \(-g[s]\)\ h[
                        s] - \[Beta] \((1 - f[s]\^2)\), \(g'\)[s] \[Equal] 
                  f[s], \(f'\)[s] \[Equal] h[s], \ g[0] \[Equal] 0, 
                f[0] \[Equal] 0, h[0] \[Equal] \[Mu]}, {f, g, h}, {s, 0, A}, 
              AccuracyGoal \[Rule] 12, PrecisionGoal \[Rule] 12, 
              InterpolationPrecision \[Rule] 12] // First]\)], "Input"],

Cell["Basic solutions", "Text"],

Cell[BoxData[{
    \(F[\[Mu]_?NumericQ, \[Beta]_?NumericQ, 
        A_?NumericQ] := \(sol[\[Mu], \[Beta], 
          A]\)[\([1]\)]\), "\[IndentingNewLine]", 
    \(G[\[Mu]_, \[Beta]_, 
        A_] := \(sol[\[Mu], \[Beta], A]\)[\([2]\)]\)}], "Input"],

Cell["\<\
Critical value of \[Beta] and m corresponding to vanishing slope\
\>", "Text"],

Cell[BoxData[
    \(\[Beta]c = 
      Block[{\[Beta], A = 20}, \[Beta] /. 
          FindRoot[\(F[0, \[Beta], A]\)[A] \[Equal] 
              1, {\[Beta], \(-0.19\), \(-0.191\)}, AccuracyGoal \[Rule] 12, 
            MaxIterations \[Rule] 30]]\)], "Input"],

Cell[BoxData[
    \(mc = m[\[Beta]c]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determine slope by ballistics", "Section"],

Cell["Definition of \[Xi]", "Text"],

Cell[BoxData[
    \(\[Beta][\[Xi]_] := \[Beta]c \((1 - \[Xi]\^2)\)\)], "Input"],

Cell["Bounds for \[Xi]", "Text"],

Cell[BoxData[{
    \(\[Xi]a[\[Beta]_] := \@\(1 - \[Beta]\/\[Beta]c\)\), \
"\[IndentingNewLine]", 
    \(\[Xi]b[\[Beta]_] := \(-\@\(1 - \[Beta]\/\[Beta]c\)\)\)}], "Input"],

Cell["Trial functions", "Text"],

Cell[BoxData[
    \(\[Mu]0[\[Xi]_] := 
      0.59  \[Xi]\ \((\(1 + \[Xi]\)\/\(2 + \[Xi]\))\)\^\(3/4\)\)], "Input"],

Cell[BoxData[
    \(A0[\[Xi]_] := 
      20\/\(\((1 + \[Xi])\)\^\(1/4\)\ \((2 + \[Xi])\)\)\)], "Input"],

Cell["Some values", "Text"],

Cell[BoxData[
    \(A0[0]\)], "Input"],

Cell[BoxData[
    \(A0[1] // N\)], "Input"],

Cell[BoxData[
    \(A0[\(-0.92\)]\)], "Input"],

Cell["Solution of slope", "Text"],

Cell[BoxData[
    \(\[Mu]1[\[Xi]_?NumericQ] := 
      Block[{\[Mu], A = A0[\[Xi]], B = \[Mu]0[\[Xi]]}, \[Mu] /. 
          FindRoot[\(F[\[Mu], \[Beta][\[Xi]], A]\)[A] \[Equal] 1, {\[Mu], B, 
              0.0001 + B}, DampingFactor \[Rule] 0.6, 
            AccuracyGoal \[Rule] 10, MaxIterations \[Rule] 30]]\)], "Input"],

Cell["Check", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot slope", "Section"],

Cell["Bounds of plot", "Text"],

Cell[BoxData[
    \(\(\[Xi]1 = \(-0.98\);\)\)], "Input"],

Cell[BoxData[
    \(\(\[Xi]2 = 2.5;\)\)], "Input"],

Cell[BoxData[
    \(\[Xi]3 = \[Xi]a[2.01]\)], "Input"],

Cell["Compare initial guess with solution", "Text"],

Cell[BoxData[
    \(\(Plot[{\[Mu]1[\[Xi]], \[Mu]0[\[Xi]]}, {\[Xi], \[Xi]1, \[Xi]3}, 
        PlotStyle \[Rule] {Dashing[{}], Dashing[{0.02}]}];\)\)], "Input"],

Cell["Make an interpolating function (ignor error messages)", "Text"],

Cell[BoxData[
    \(\(\[Mu] = 
        FunctionInterpolation[\[Mu]1[\[Xi]], {\[Xi], \[Xi]1, \[Xi]3}, 
          InterpolationPrecision \[Rule] 6];\)\)], "Input"],

Cell["Put plot together", "Text"],

Cell[BoxData[
    \(\(fig1a = 
        ParametricPlot[{m[\[Beta][\[Xi]]], \[Mu][\[Xi]]}, {\[Xi], 
            0, \[Xi]2}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = 
        ParametricPlot[{{m[\[Beta][\[Xi]]], \[Mu][\[Xi]]}}, {\[Xi], \[Xi]1, 
            0}, PlotStyle \[Rule] {Dashing[{0.005, 0.01}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1c = 
        Graphics[{Dashing[{0.02}], 
            Line[{{\(-0.2\), 0}, {0.2, 0}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b, fig1c, PlotLabel -> "\<(a)\>", 
          PlotRange \[Rule] {{\(-0.1\), 0.2}, {\(-0.2\), 0.8}}, 
          AxesOrigin \[Rule] {0, \(-0.2\)}, 
          AxesLabel \[Rule] {"\<m\>", "\<f'(0)\>"}] // 
        Figure["\<boundaries10\>", ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Velocity profiles", "Section"],

Cell["Insert found solutions", "Text"],

Cell[BoxData[
    \(f[\[Xi]_] := F[\[Mu][\[Xi]], \[Beta][\[Xi]], A0[\[Xi]]]\)], "Input"],

Cell["Select \[Xi] values", "Text"],

Cell[BoxData[
    \(\(\[Xi]s = {\(-0.9202\), \(-0.830\), \(-0.686\), \(-0.492\), 0.492, 1, 
          1.636, 2.456, 3.3};\)\)], "Input"],

Cell["Calculate \[Beta] , m and function", "Text"],

Cell[BoxData[
    \(\[Beta]s = Map[\[Beta], \[Xi]s]\)], "Input"],

Cell[BoxData[
    \(ms = Map[m, \[Beta]s]\)], "Input"],

Cell[BoxData[
    \(\(fs = Map[f, \[Xi]s];\)\)], "Input"],

Cell["\<\
Define value of function (picks out limit from interpolating function)\
\>", "Text"],

Cell[BoxData[
    \(value[f_, s_] := If[s < f[\([1, 1, 2]\)], f[s], 1]\)], "Input"],

Cell["Define plot texts", "Text"],

Cell[BoxData[
    \(\(texts = {Text["\<-0.07\>", {3.3, 0.4}], 
          Text["\<-0.05\>", {4.1, 0.3}], Text["\<-0.03\>", {4.9, 0.2}], 
          Text["\<-0.015\>", {6, 0.1}], Text["\<-0.07\>", {1.85, 0.6}], 
          Text["\<0\>", {1.62, 0.7}], Text["\<0.2\>", {1.45, 0.8}], 
          Text["\<1.0\>", {1.45, 0.9}], 
          Text["\<\[Infinity]\>", {1.3, 0.96}]};\)\)], "Input"],

Cell[BoxData[
    \(\(fig2a = 
        Plot[Map[value[#, s] &, fs] // Evaluate, {s, 0, 10}, 
          PlotRange \[Rule] {\(-0.2\), 1}, 
          PlotStyle \[Rule] texts];\)\)], "Input"],

Cell["Critical curve", "Text"],

Cell[BoxData[
    \(\(fig2b = 
        Plot[\(f[0]\)[s], {s, 0, 6}, 
          PlotStyle \[Rule] {Dashing[{0.005, 0.01}], 
              Text[\*"\"\<\!\(m\_c\)\>\"", {2.6, 0.5}]}, 
          PlotRange \[Rule] All];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig2a, fig2b, 
          Graphics[{Dashing[{0.02}], Line[{{0, 1}, {9, 1}}]}], 
          PlotRange \[Rule] {\(-0.2\), 1}, 
          AxesLabel \[Rule] {"\<s\>", "\<f(s)\>"}] \
// \[IndentingNewLine]Figure["\<boundaries9\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Displacement shape factor", "Section"],

Cell["Value h(\[Infinity])", "Text"],

Cell[BoxData[
    \(Sdisp1[\[Xi]_] := 
      A0[\[Xi]] - \(G[\[Mu][\[Xi]], \[Beta][\[Xi]], A0[\[Xi]]]\)[
          A0[\[Xi]]]\)], "Input"],

Cell["Critical value", "Text"],

Cell[BoxData[
    \(h0 = Sdisp1[0]\)], "Input"],

Cell["Make interpolation (ignore errors)", "Text"],

Cell[BoxData[
    \(Sdisp = 
      FunctionInterpolation[Sdisp1[\[Xi]], {\[Xi], \[Xi]1, \[Xi]3}, 
        InterpolationPrecision \[Rule] 6]\)], "Input"],

Cell[BoxData[
    \(\(fig10a = 
        ParametricPlot[{m[\[Beta][\[Xi]]], Sdisp[\[Xi]]}, {\[Xi], 
            0, \[Xi]2}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig10b = 
        ParametricPlot[{m[\[Beta][\[Xi]]], Sdisp[\[Xi]]}, {\[Xi], \[Xi]1, 0}, 
          PlotStyle \[Rule] Dashing[{0.005, 0.01}]];\)\)], "Input"],

Cell[BoxData[
    \(\(fig10c = 
        Graphics[{Dashing[{0.02}], 
            Line[{{\(-0.1\), h0}, {0.24, h0}}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig10a, fig10b, fig10c, PlotRange \[Rule] {0, 10}, 
          AxesLabel \[Rule] {"\<m\>", "\<h(\[Infinity])\>"}, 
          PlotLabel -> "\<(b)\>"] \
// \[IndentingNewLine]Figure["\<boundaries15\>", 
          ImageSize \[Rule] 250];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wall Approximation (problem 28.6)", "Title"],

Cell[CellGroupData[{

Cell["Theory", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Solution for the slope", "Text"],

Cell[BoxData[
    \(\(\[Lambda][
          x_] = \(4\/3\) \(U[x]\/\[Delta][
                x]\) \((1 + \(\(U'\)[x] \[Delta][x]\^2\)\/\(4  \
\[Nu]\))\);\)\)], "Input"],

Cell["Wall condition", "Text"],

Cell[BoxData[
    \(\(zero = \[Lambda][x] \[Delta][
              x] - \(\(U[x] \(U'\)[
                    x]\)\/\[Nu]\) \[Delta][x]\^2 + \(\(\[Lambda][
                    x] \(\[Lambda]'\)[
                    x]\)\/\(6  \[Nu]\)\) \[Delta][x]\^4;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differential equation for \[Mu]", "Section"],

Cell[BoxData[
    \(\(zero // Expand\) // 
      Collect[#, {\(\[Delta]'\)[x], \[Delta][x]}] &\)], "Input"],

Cell[BoxData[
    \(\(\[Delta][
          x_] = \@\(\(\[Nu]\ \((3  \[Mu][x] - 4)\)\)\/\(U'\)[x]\);\)\)], \
"Input"],

Cell[BoxData[
    \(zero1[U_] = \(zero\ \ 12 \(\( U'\)[x]/U[x]\^2\)/\[Mu][x] // Expand\) // 
        Collect[#, {\(\[Mu]'\)[
                x], \(U'\)[x]\/U[x], \(U''\)[x]\/\(U'\)[x]}] &\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve differential equation", "Section"],

Cell[BoxData[
    \(\(rhs[U_, 
          x_] = \(24\/\[Mu][x]\) \(\(2 - \[Mu][x]\)\/\(8 - 
                  3  \[Mu][x]\)\) \(U'\)[x]\/U[x] - \[Mu][
              x]\ \(\(4 - 3  \[Mu][x]\)\/\(8 - 
                  3  \[Mu][
                      x]\)\) \((2 \( U'\)[x]\/U[x] + \
\(U''\)[x]\/\(U'\)[x])\);\)\)], "Input"],

Cell[BoxData[
    \(\(\[Epsilon] = 10\^\(-12\);\)\)], "Input"],

Cell[BoxData[
    \(sol[U_] := 
      Block[{\[Mu]}, \[Mu] /. 
            NDSolve[{\(\[Mu]'\)[x] \[Equal] 
                  rhs[U, x], \[Mu][\[Epsilon]] \[Equal] 
                  4\/3}, \[Mu], {x, \[Epsilon], 1}, 
              StoppingTest \[Rule] \[Mu][x] < \ 10\^\(-6\), 
              AccuracyGoal \[Rule] 10, PrecisionGoal \[Rule] 10] // 
          First]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example flows", "Section"],

Cell["Define a set of 9 decelerating functions", "Text"],

Cell[BoxData[
    \(\(Us = 
        Thread[Function[
            x, {1 - x, \@\(1 - x\), \((1 - x)\)\^2, 1\/\(1 + x\), 
              1\/\((1 + x)\)\^2, 1 - x\^2, 1 - x\^4, 1 - x\^8, 
              Cos[x]}]];\)\)], "Input"],

Cell[BoxData[
    \(length = Length[Us]\)], "Input"],

Cell["Exact values from White", "Text"],

Cell[BoxData[
    \(\(exact = {0.120, 0.218, 0.0637, 0.151, 0.0713, 0.271, 0.462, 0.640, 
          0.389};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Primitive approximation to separation", "Section"],

Cell["Critical velocity", "Text"],

Cell[BoxData[
    \(Uc = \[ExponentialE]\^\(\(-4\)/27\) // N\)], "Input"],

Cell["Determine critical point", "Text"],

Cell[BoxData[
    \(xc[U_] := x /. FindRoot[U[x] \[Equal] Uc, {x, 0.1}]\)], "Input"],

Cell[BoxData[
    \(xcs = Map[xc, Us]\)], "Input"],

Cell["Deviations from exact values", "Text"],

Cell[BoxData[
    \(dev = \(xcs - exact\)\/exact\)], "Input"],

Cell["Average deviations", "Text"],

Cell[BoxData[
    \(\@\(Plus @@ \(dev\^2\)\/length\)\)], "Input"],

Cell["Dimensionless slope", "Text"],

Cell[BoxData[
    \(\[Mu][
        U_] := \(4\/3\) \@\(1 + \(27\/4\) Log[\ U[#]\/U[0]]\) &\)], "Input"],

Cell["Applied to all examples", "Text"],

Cell[BoxData[
    \(\(\[Mu]s = Map[\[Mu], Us];\)\)], "Input"],

Cell["Construct curves", "Text"],

Cell[BoxData[
    \(plot\[Mu]1[n_] := 
      Block[{\[Mu] = \[Mu]s[\([n]\)], xc = xcs[\([n]\)]}, 
        Plot[\[Mu][x], {x, 0, xc}, PlotPoints \[Rule] 200, 
          PlotStyle \[Rule] {Dashing[{0.01}], 
              Text[n, {xc + 
                    If[n \[Equal] 3, \(-0.01\), 0.01], \[Mu][xc - 0.0001] + 
                    0.1}]}, DisplayFunction \[Rule] Identity]]\)], "Input"],

Cell[BoxData[
    \(\(figa = 
        Show[Table[plot\[Mu]1[n], {n, length}], 
          DisplayFunction \[Rule] $DisplayFunction, 
          AxesLabel \[Rule] {"\<x\>", "\<\[Mu]\>"}, 
          PlotRange \[Rule] {0, 1.4}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determine separation point from differential equation", "Section"],

Cell[BoxData[
    \(\(\[Mu]s = Map[sol, Us];\)\)], "Input"],

Cell[BoxData[
    \(xcs = Map[#[\([1, 1, 2]\)] &, \[Mu]s] // SetAccuracy[#, 4] &\)], "Input"],

Cell[BoxData[
    \(dev = \(xcs - exact\)\/exact\)], "Input"],

Cell[BoxData[
    \(\@\(Plus @@ \(dev\^2\)\/length\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the solutions", "Section"],

Cell[BoxData[
    \(plot\[Mu][n_] := 
      Block[{\[Mu] = \[Mu]s[\([n]\)], xc = xcs[\([n]\)]}, 
        Plot[\[Mu][x], {x, \[Epsilon], xc}, 
          PlotStyle \[Rule] 
            Text[n, {xc + If[n \[Equal] 3, \(-0.01\), 0.01], \[Mu][xc] + 
                  0.1}], DisplayFunction \[Rule] Identity]]\)], "Input"],

Cell[BoxData[
    \(\(Show[figa, {Table[plot\[Mu][n], {n, length}]}, 
        DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<x\>", "\<\[Mu]\>"}, 
        PlotRange \[Rule] {0, 1.4}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Profile plot", "Section"],

Cell[BoxData[
    \(\(f[\[Mu]_, s_] := \(4\/3\) \[Mu]\ s + 2 \((1 - \[Mu])\)\ s\^2\  - 
          1\/3\ \((3 - 2  \[Mu])\) s\^4;\)\)], "Input"],

Cell[BoxData[
    \(\(fig20a = 
        Plot[Thread[f[{1.5, 1, 0.5, \(-0.5\), \(-1\), \(-1.5\)}, s]] // 
            Evaluate, {s, 0, 1}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig20b = 
        Plot[f[0, s], {s, 0, 1}, 
          PlotStyle \[Rule] Dashing[{0.01}]];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig20a, fig20b, 
        Graphics[{Dashing[{0.02}], Line[{{0, 1}, {1, 1}}], 
            Text["\<\[Mu]=1.5\>", {0.28, 0.6}], 
            Text["\<\[Mu]=-1.5\>", {0.63, 0.2}]}], 
        AxesLabel \[Rule] {"\<y/\[Delta]\>", \
\*"\"\<\!\(v\_x\)/U\>\""}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Thickness scales", "Section"],

Cell[BoxData[
    \(\(S\_wall = \(4\/3\) \[Mu];\)\)], "Input"],

Cell[BoxData[
    \(S\_disp = \[Integral]\_0\%1 f[\[Mu], s] \[DifferentialD]s // 
        Expand\)], "Input"],

Cell[BoxData[
    \(S\_mom = \[Integral]\_0\%1 f[\[Mu], 
              s] \((1 - f[\[Mu], s])\) \[DifferentialD]s // Expand\)], "Input"],

Cell[BoxData[
    \(\(S\_wall\) S\_disp /. \[Mu] \[Rule] 1 // N\)], "Input"],

Cell[BoxData[
    \(S\_disp\/S\_mom /. \[Mu] \[Rule] 1 // N\)], "Input"],

Cell[BoxData[
    \(S\_wall/S\_mom /. \[Mu] \[Rule] 1 // N\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pohlhausen Approximation (problem 28.7)", "Title"],

Cell[CellGroupData[{

Cell["Profiles", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["General form of velocity profile", "Text"],

Cell[BoxData[
    \(\(v\_x = 
        U \((\[Mu]  y\/\[Delta] + a \((y\/\[Delta])\)\^2 + 
              b \((y\/\[Delta])\)\^3 + 
              c \((y\/\[Delta])\)\^4)\);\)\)], "Input"],

Cell["Smoothness conditions", "Text"],

Cell[BoxData[
    \(unity = v\_x/U /. y \[Rule] \[Delta] // Simplify\)], "Input"],

Cell[BoxData[
    \(zero1 = \[PartialD]\_y\((v\_x)\) \[Delta]/U /. y \[Rule] \[Delta] // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(zero2 = \[PartialD]\_y\^2\((v\_x)\)\ \(\[Delta]\^2/2\)/U /. 
          y \[Rule] \[Delta] // Simplify\)], "Input"],

Cell["Solve for the unknowns", "Text"],

Cell[BoxData[
    \(sol = 
      Solve[{unity \[Equal] 1, zero1 \[Equal] 0, zero2 \[Equal] 0}, {a, b, 
            c}] // First\)], "Input"],

Cell["Dimensionless velocity", "Text"],

Cell[BoxData[
    \(f = \(v\_x\/U /. sol\) /. y \[Rule] \[Delta]\ s // Expand\)], "Input"],

Cell["Check that the first three orders are ok for s=1", "Text"],

Cell[BoxData[
    \(Series[f, {s, 1, 5}] // Expand\)], "Input"],

Cell["Shape factors", "Text"],

Cell[BoxData[
    \(S\_disp = \[Integral]\_0\%1\((1 - f)\) \[DifferentialD]s // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(S\_mom = \[Integral]\_0\%1\((1 - f)\) f \[DifferentialD]s // 
        Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Karman relation", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Wall curvature condition", "Text"],

Cell[BoxData[
    \(\(\[Delta][
          x_] = \@\(\(6  \[Nu]\ \ \((\[Mu][x] - 2)\)\)\/\(U'\)[x]\);\)\)], \
"Input"],

Cell["Thicknesses", "Text"],

Cell[BoxData[{
    \(\(\[Delta]\_wall = \[Delta][x]\/\[Mu][x];\)\), "\[IndentingNewLine]", 
    \(\(\[Delta]\_disp = \(\(8 - \[Mu][x]\)\/20\) \[Delta][
            x];\)\), "\[IndentingNewLine]", 
    \(\(\[Delta]\_mom = \(\(144 + 12\ \[Mu][x] - 
                5\ \[Mu][x]\^2\)\/1260\) \[Delta][x];\)\)}], "Input"],

Cell["Karman relation", "Text"],

Cell[BoxData[
    \(\(karman = \[PartialD]\_x \[Delta]\_mom + \(\(U'\)[x]\/U[
                    x]\) \((\[Delta]\_disp + 
                  2  \[Delta]\_mom)\) - \[Nu]\/\(U[x]\ \[Delta]\_wall\) // 
          Expand;\)\)], "Input"],

Cell[CellGroupData[{

Cell["Simplify the Karman relation in several stages", "Subsection"],

Cell[BoxData[
    \(karman1 = \(\(karman\ \[Delta]\_mom\ \(U'\)[x] \(3675/16\)/\[Nu] // 
            Expand\) // FullSimplify\) // 
        Collect[#, {\(\[Mu]'\)[
                x], \(U'\)[x]\/U[x], \(U''\)[x]\/\(U'\)[x]}] &\)], "Input"],

Cell[BoxData[
    \(karman2 = \((karman1 // FullSimplify)\) // 
        Collect[#, {\(\[Mu]'\)[
                x], \(U'\)[x]\/U[x], \(U''\)[x]\/\(U'\)[x]}] &\)], "Input"],

Cell[BoxData[
    \(karman3 = \(\(karman2\ 144*16/\ \((\(-144\) + \[Mu][
                        x]\ \((\(-12\) + 5\ \[Mu][x])\))\) // FullSimplify\) // 
          Expand\) // 
        Collect[#, {\(\[Mu]'\)[
                x], \(U'\)[x]\/U[x], \(U''\)[x]\/\(U'\)[x]}] &\)], "Input"],

Cell["Factor polynomials", "Text"],

Cell[BoxData[
    \(Factor[\(-96\) - 76\ \[Mu][x] + 25\ \[Mu][x]\^2]\)], "Input"],

Cell[BoxData[
    \(Factor[\(-288\) + 120\ \[Mu][x] + 22\ \[Mu][x]\^2 - 
        5\ \[Mu][x]\^3]\)], "Input"],

Cell[BoxData[
    \(Factor[
      3168 - 1320\ \[Mu][x] + 38\ \[Mu][x]\^2 + 20\ \[Mu][x]\^3 + 
        4 \((\(-288\) + 120\ \[Mu][x] + 22\ \[Mu][x]\^2 - 
              5\ \[Mu][x]\^3)\)]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integrate the Karman relation", "Section"],

Cell[BoxData[
    \(\(\[Epsilon] = 10\^\(-12\);\)\)], "Input"],

Cell["Final form of the right hand side", "Text"],

Cell[BoxData[
    \(\(rhs[U_, x_] = 
        42 \(\( 48 - 20\ \[Mu][x] + 
                  3\ \[Mu][x]\^2\)\/\(\((4 - \[Mu][x])\) \((24 + 
                      25  \[Mu][x])\)\)\) \(U'\)[x]\/U[x] - \(\(\((2 - \[Mu][
                        x])\) \((144 + 12  \[Mu][x] - 
                      5  \[Mu][x]\^2)\)\)\/\(\((4 - \[Mu][x])\) \((24 + 
                      25  \[Mu][x])\)\)\) \((\(U''\)[x]\/\(U'\)[x] - 
                4 \( U'\)[x]\/U[x])\);\)\)], "Input"],

Cell["Check that it solves the previous result", "Text"],

Cell[BoxData[
    \(karman3 /. \(\[Mu]'\)[x] \[Rule] rhs[U, x] // FullSimplify\)], "Input"],

Cell["Differential equation", "Text"],

Cell[BoxData[
    \(sol[U_] := 
      Block[{\[Mu]}, \[Mu] /. 
            NDSolve[{\(\[Mu]'\)[x] \[Equal] 
                  rhs[U, x], \[Mu][\[Epsilon]] \[Equal] 
                  2}, \[Mu], {x, \[Epsilon], 2}, 
              StoppingTest \[Rule] \[Mu][x] < 0, AccuracyGoal \[Rule] 12, 
              PrecisionGoal \[Rule] 12] // First]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example flows", "Section"],

Cell["Define a set of 9 decelerating functions", "Text"],

Cell[BoxData[
    \(\(Us = 
        Thread[Function[
            x, {1 - x, \@\(1 - x\), \((1 - x)\)\^2, 1\/\(1 + x\), 
              1\/\((1 + x)\)\^2, 1 - x\^2, 1 - x\^4, 1 - x\^8, 
              Cos[x]}]];\)\)], "Input"],

Cell[BoxData[
    \(length = Length[Us]\)], "Input"],

Cell["Exact values from White", "Text"],

Cell[BoxData[
    \(\(exact = {0.120, 0.218, 0.0637, 0.151, 0.0713, 0.271, 0.462, 0.640, 
          0.389};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determine separation points", "Section"],

Cell[BoxData[
    \(\(\[Mu]s = Map[sol, Us];\)\)], "Input"],

Cell[BoxData[
    \(xcs = Map[#[\([1, 1, 2]\)] &, \[Mu]s] // SetAccuracy[#, 4] &\)], "Input"],

Cell[BoxData[
    \(dev = \(xcs - exact\)\/exact\)], "Input"],

Cell[BoxData[
    \(\@\(Plus @@ \(dev\^2\)\/length\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the solutions", "Section"],

Cell[BoxData[
    \(plot\[Mu][n_] := 
      Block[{\[Mu] = \[Mu]s[\([n]\)], xc = xcs[\([n]\)]}, 
        Plot[\[Mu][x], {x, 0, xc}, 
          PlotStyle \[Rule] 
            Text[n, {xc + If[n \[Equal] 3, \(-0.01\), 0.01], \[Mu][xc] + 
                  0.1}], DisplayFunction \[Rule] Identity]]\)], "Input"],

Cell[BoxData[
    \(\(Show[{Table[plot\[Mu][n], {n, length}]}, 
        DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<x\>", "\<\[Mu]\>"}, 
        PlotRange \[Rule] {0, 2}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Flow plot", "Section"],

Cell[BoxData[
    \(Clear[\[Mu]]\)], "Input"],

Cell["Choice of flow function", "Text"],

Cell[BoxData[
    \(\(U[x_] = 1 - x;\)\)], "Input"],

Cell[BoxData[
    \(\[Mu] = sol[U]\)], "Input"],

Cell["Choice of viscosity", "Text"],

Cell[BoxData[
    \(\(\[Nu] = 0.1;\)\)], "Input"],

Cell["Thickness scale", "Text"],

Cell[BoxData[
    \(\(\[Delta][
          x_] = \@\(\(6  \[Nu]\ \ \((\[Mu][x] - 2)\)\)\/\(U'\)[x]\);\)\)], \
"Input"],

Cell["Stream function (its contours are streamlines)", "Text"],

Cell[BoxData[
    \(\(\[Psi][x_, y_] = 
        U[x] \[Delta][
              x] \((\(1\/5\) \(s\^5\) \((3 - \[Mu][x])\) - 
                s\^3\ \((\(-2\) + \[Mu][x])\) + \(1\/2\) 
                  s\^2\ \[Mu][x] + \(1\/4\) 
                  s\^4\ \((\(-8\) + 3\ \[Mu][x])\))\) /. 
          s \[Rule] y/\[Delta][x];\)\)], "Input"],

Cell["Plot streamlines near separation (ignore errors)", "Text"],

Cell[BoxData[
    \(\(ContourPlot[\[Psi][x, y], {x, 0.156, 0.1681}, {y, 0, 0.15}, 
        ContourShading \[Rule] False, PlotPoints \[Rule] 200, 
        Contours \[Rule] 80, FrameLabel -> {"\<x\>", "\<y\>"}, 
        RotateLabel -> False, 
        AspectRatio \[Rule] 1/GoldenRatio];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pohlhausen family plot", "Section"],

Cell[BoxData[
    \(\(f[\[Mu]_, s_] := 
        s\^4\ \((3 - \[Mu])\) - 3\ s\^2\ \((\(-2\) + \[Mu])\) + s\ \[Mu] + 
          s\^3\ \((\(-8\) + 3\ \[Mu])\);\)\)], "Input"],

Cell[BoxData[
    \(\(fig20a = 
        Plot[Thread[
              f[{\(-5\), \(-4\), \(-3\), \(-2\), \(-1\), 1, 2, 3, 4, 5}, s]] // 
            Evaluate, {s, 0, 1}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig20b = 
        Plot[f[0, s], {s, 0, 1}, 
          PlotStyle \[Rule] Dashing[{0.01}]];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig20a, fig20b, 
          Graphics[{Dashing[{0.02}], Line[{{0, 1}, {1, 1}}], 
              Text["\<\[Mu]=5\>", {0.1, 0.6}], 
              Text["\<\[Mu]=-5\>", {0.58, 0.4}]}], 
          AxesLabel \[Rule] {"\<y/\[Delta]\>", \*"\"\<\!\(v\_x\)/U\>\""}] \
// \[IndentingNewLine]Figure["\<boundaries8\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integral approximation", "Title"],

Cell[CellGroupData[{

Cell["Shape factors", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Pohlhausen form", "Text"],

Cell[BoxData[
    \(\(f = 
        s\^4\ \((3 - \[Mu])\) - 3\ s\^2\ \((\(-2\) + \[Mu])\) + s\ \[Mu] + 
          s\^3\ \((\(-8\) + 3\ \[Mu])\);\)\)], "Input"],

Cell["All shape factors", "Text"],

Cell[BoxData[
    \(\(S\_wall = \[Mu];\)\)], "Input"],

Cell[BoxData[
    \(S\_disp = \[Integral]\_0\%1\((1 - f)\) \[DifferentialD]s // 
        Factor\)], "Input"],

Cell[BoxData[
    \(S\_mom = \[Integral]\_0\%1\((1 - f)\) f \[DifferentialD]s // 
        Factor\)], "Input"],

Cell[BoxData[
    \(%/\((4/35)\) // Expand\)], "Input"],

Cell[BoxData[
    \(S\_ener = \[Integral]\_0\%1\((1 - f\^2)\) f \[DifferentialD]s // 
        Factor\)], "Input"],

Cell[BoxData[
    \(%/\((876\/5005)\) // Expand\)], "Input"],

Cell[BoxData[
    \(%/\((4/35)\) // Expand\)], "Input"],

Cell[BoxData[
    \(S\_heat = \[Integral]\_0\%1\(\((\[PartialD]\_s 
                    f)\)\^2\) \[DifferentialD]s // Factor\)], "Input"],

Cell[BoxData[
    \(%/\((48\/35)\) // Expand\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_mom/\[Delta]\_ener\)]],
  " ratio"
}], "Section"],

Cell[BoxData[
    \(\(A = S\_mom\/S\_ener // Simplify;\)\)], "Input"],

Cell[BoxData[{
    \(\(A // Series[#, {\[Mu], 0, 5}] &\) // Normal\), "\n", 
    \(%/\((143\/219)\) // Expand\), "\n", 
    \(% // N\)}], "Input"],

Cell[BoxData[
    \(\(Plot[A, {\[Mu], 0, 2}, PlotRange \[Rule] {0.63, 0.66}, 
          AxesLabel \[Rule] {"\<\[Mu]\>", \*"\"\<\!\(mom\/ener\)\>\""}, 
          PlotLabel -> "\<(a)\>"] \
// \[IndentingNewLine]Figure["\<boundaries14\>", 
          ImageSize \[Rule] 300];\)\)], "Input"],

Cell[BoxData[
    \(A\_1 = A /. \[Mu] \[Rule] 0 // N\)], "Input"],

Cell[BoxData[
    \(A\_2 = A /. \[Mu] \[Rule] 2 // N\)], "Input"],

Cell[BoxData[
    \(\(A\_1 - A\_2\)\/\(A\_1 + A\_2\)\)], "Input"],

Cell[BoxData[
    \(\(A\_1 + A\_2\)\/2\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_heat/\[Delta]\_ener\)]],
  " ratio"
}], "Section"],

Cell[BoxData[{
    \(B = \(S\_heat\) S\_ener // Expand\), "\[IndentingNewLine]", 
    \(%/\((42048\/175175)\) // Expand\), "\[IndentingNewLine]", 
    \(% // N\)}], "Input"],

Cell[BoxData[
    \(\(Plot[B, {\[Mu], 0, 2}, PlotRange \[Rule] {0.230, 0.275}, 
          AxesLabel \[Rule] {"\<\[Mu]\>", \*"\"\<\!\(ener\/heat\)\>\""}, 
          PlotLabel -> "\<(b)\>"] \
// \[IndentingNewLine]Figure["\<boundaries13\>", 
          ImageSize \[Rule] 300];\)\)], "Input"],

Cell[BoxData[
    \(B\_1 = B /. \[Mu] \[Rule] 0 // N\)], "Input"],

Cell[BoxData[
    \(B\_2 = B /. \[Mu] \[Rule] 2 // N\)], "Input"],

Cell[BoxData[
    \(\(B\_1 - B\_2\)\/\(B\_1 + B\_2\)\)], "Input"],

Cell[BoxData[
    \(\(B\_1 + B\_2\)\/2\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Approximative solution", "Section"],

Cell["Right hand side of eq. (28-83)", "Text"],

Cell[BoxData[
    \(R[\[Mu]_] = \(\(\(S\_ener\) S\_wall\)\/\(2 \( S\_mom\) S\_heat\) - \
1\)\/\(2 \((S\_disp\/S\_mom - 1)\)\) // Simplify\)], "Input"],

Cell["Expand for small \[Mu]", "Text"],

Cell[BoxData[{
    \(\(R[\[Mu]] // Series[#, {\[Mu], 0, 3}] &\) // Normal\), "\n", 
    \(% // N\)}], "Input"],

Cell["First vanishing point", "Text"],

Cell[BoxData[
    \(FindRoot[R[\[Mu]] \[Equal] 0, {\[Mu], 0, 2}]\)], "Input"],

Cell["All roots", "Text"],

Cell[BoxData[
    \(Solve[R[\[Mu]] \[Equal] 0, \[Mu]] // N\)], "Input"],

Cell[BoxData[
    \(\(Plot[R[\[Mu]], {\[Mu], 0, 2}, 
        AxesLabel \[Rule] {"\<\[Mu]\>", "\<R\>"}, 
        PlotLabel -> "\<(a)\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example flows", "Section"],

Cell["Define a set of 9 decelerating functions", "Text"],

Cell[BoxData[
    \(\(Us = 
        Thread[Function[
            x, {1 - x, \@\(1 - x\), \((1 - x)\)\^2, 1\/\(1 + x\), 
              1\/\((1 + x)\)\^2, 1 - x\^2, 1 - x\^4, 1 - x\^8, 
              Cos[x]}]];\)\)], "Input"],

Cell[BoxData[
    \(length = Length[Us]\)], "Input"],

Cell["Exact values from White", "Text"],

Cell[BoxData[
    \(\(exact = {0.120, 0.218, 0.0637, 0.151, 0.0713, 0.271, 0.462, 0.640, 
          0.389};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Separation points", "Section"],

Cell[BoxData[
    \(\(x0 = 0.02;\)\)], "Input"],

Cell[BoxData[
    \(sol[U_] := 
      x /. FindRoot[\(\(U'\)[x] \(\[Integral]\_0\%x\ \(U[x1]\^5\) \
\[DifferentialD]x1\)\)\/U[x]\^6 \[Equal] \(-\(1\/5\)\), {x, x0, 
            1.01  x0}]\)], "Input"],

Cell[BoxData[
    \(xcs = Map[sol, Us] // SetAccuracy[#, 4] &\)], "Input"],

Cell["Deviations", "Text"],

Cell[BoxData[
    \(dev = \(xcs - exact\)\/exact\)], "Input"],

Cell["Average", "Text"],

Cell[BoxData[
    \(\@\(Plus @@ \(dev\^2\)\/length\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cylinder separation", "Section"],

Cell[BoxData[
    \(\(x0 = 1.5;\)\)], "Input"],

Cell[BoxData[
    \(xc = sol[Sin[#] &]\)], "Input"],

Cell[BoxData[
    \(xc\/Degree // ToSI\)], "Input"],

Cell[BoxData[
    \(\(Hiemenz[x_] = 1.814\ x - 0.271  x\^3 - 0.0471\ x\^5;\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[{Sin[x], Hiemenz[x]}, {x, 0, \[Pi]}, 
        AxesLabel \[Rule] \ {"\<x\>", "\<U\>"}, 
        PlotStyle \[Rule] {Dashing[{0.01}], Dashing[{}]}];\)\)], "Input"],

Cell[BoxData[
    \(xc = sol[Hiemenz]\)], "Input"],

Cell[BoxData[
    \(xc\/Degree // ToSI\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Energy plus momentum (problem 28.8)", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Pohlhausen shape factors (from above)", "Section"],

Cell[BoxData[{
    \(\(S\_wall = \[Mu][x];\)\), "\[IndentingNewLine]", 
    \(\(S\_disp = \(8 - \[Mu][x]\)\/20;\)\), "\[IndentingNewLine]", 
    \(\(S\_mom = \(144 + 12\ \[Mu][x] - 5\ \[Mu][x]\^2\)\/1260;\)\), "\
\[IndentingNewLine]", 
    \(\(S\_ener = \(10512 + 876\ \[Mu][x] - 253\ \[Mu][x]\^2 - 21\ \
\[Mu][x]\^3\)\/60060;\)\), "\[IndentingNewLine]", 
    \(\(S\_heat = 
        1\/35\ \((48 - 4\ \[Mu][x] + 3\ \[Mu][x]\^2)\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Momentum condition", "Section"],

Cell["This must vanish", "Text"],

Cell[BoxData[
    \(\(mom = \[PartialD]\_x\((\(U[x]\^2\) \[Delta][x]\ S\_mom)\) + 
            U[x] \(U'\)[x] \[Delta][
                x]\ S\_disp - \[Nu]\ \(U[x]\/\[Delta][x]\) S\_wall // 
          Expand;\)\)], "Input"],

Cell["Simplify in stages to get final equation", "Text"],

Cell[BoxData[
    \(mom1 = \(mom\ \[Delta][x]\ /U[x]\^2 // Expand\) // 
        Collect[#, {\(\[Mu]'\)[x], \(\[Delta]'\)[
                x], \(U'\)[x]\/U[x], \[Delta][x]}] &\)], "Input"],

Cell[BoxData[
    \(mom2 = \(mom1\ \ 24\ *105\ U[x]/\[Nu] /. {\[Delta][
                  x] -> \@\(\[Nu]\ \[Gamma][x]\/U[x]\), \(\[Delta]'\)[
                  x] \[Rule] \[PartialD]\_x\@\( \[Nu]\ \[Gamma][x]\/U[x]\)} // 
          Expand\) // 
        Collect[#, {\(\[Mu]'\)[x], \(\[Gamma]'\)[
                x], \(U'\)[x]\/U[x], \[Gamma][x]}] &\)], "Input"],

Cell["Factor coefficients", "Text"],

Cell[BoxData[
    \(Factor[1440 - 90\ \[Mu][x] - 15\ \[Mu][x]\^2]\)], "Input"],

Cell[BoxData[
    \(Factor[24 - 20\ \[Mu][x]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Energy condition", "Section"],

Cell["This must vanish", "Text"],

Cell[BoxData[
    \(\(ener = \(1\/2\) \[PartialD]\_x\((\(U[x]\^3\) \[Delta][x] 
                    S\_ener)\) - \[Nu]\ \(U[x]\^2\/\[Delta][x]\) S\_heat // 
          Expand;\)\)], "Input"],

Cell["Simplify in stages to get final equation", "Text"],

Cell[BoxData[
    \(ener1 = \(ener\ /U[x]\^3 // Expand\) // 
        Collect[#, {\(\[Mu]'\)[x], \(\[Delta]'\)[
                x], \(U'\)[x]\/U[x], \[Delta][x]}] &\)], "Input"],

Cell[BoxData[
    \(ener2 = \(ener1\ \ \ 10010*24\ \[Gamma][x]/\[Delta][x] /. {\[Delta][
                  x] -> \@\(\[Nu]\ \[Gamma][x]\/U[x]\), \(\[Delta]'\)[
                  x] \[Rule] \[PartialD]\_x\@\( \[Nu]\ \[Gamma][x]\/U[x]\)} // 
          Expand\) // 
        Collect[#, {\(\[Mu]'\)[x], \(\[Gamma]'\)[
                x], \(U'\)[x]\/U[x], \[Gamma][x]}] &\)], "Input"],

Cell["Factor coefficients", "Text"],

Cell[BoxData[
    \(Factor[\(-329472\) + 27456\ \[Mu][x] - 20592\ \[Mu][x]\^2]\)], "Input"],

Cell[BoxData[
    \(Factor[1752 - 1012\ \[Mu][x] - 126\ \[Mu][x]\^2]\)], "Input"],

Cell[BoxData[
    \(Factor[
      52560 + 4380\ \[Mu][x] - 1265\ \[Mu][x]\^2 - 
        105\ \[Mu][x]\^3]\)], "Input"],

Cell[BoxData[
    \(Factor[\(-329472\) + 27456\ \[Mu][x] - 20592\ \[Mu][x]\^2]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algebraic equation", "Section"],

Cell[TextData[{
  "Equate the two values of ",
  StyleBox["\[Gamma]'[0]", "Input"]
}], "Text"],

Cell[BoxData[
    \(sol = 
      Solve[\(2520  \[Mu]\)\/\(144 + 12  \[Mu] - 5  \[Mu]\^2\) \[Equal] \
\(6864 \((48 - 4  \[Mu] + 3  \[Mu]\^2)\)\)\/\(10512 + 876  \[Mu] - 253  \[Mu]\
\^2 - 21  \[Mu]\^3\), \[Mu]] // N\)], "Input"],

Cell["First solution", "Text"],

Cell[BoxData[
    \(\[Mu]\_0 = \[Mu] /. sol[\([2]\)] // Re\)], "Input"],

Cell["Corresponding derivative", "Text"],

Cell[BoxData[
    \(\[Gamma]\_1 = \(2520  \[Mu]\)\/\(144 + 12  \[Mu] - 5  \[Mu]\^2\) /. \
\[Mu] \[Rule] \[Mu]\_0\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve for derivatives", "Section"],

Cell[BoxData[
    \({\[Gamma]p[x_, U_], \[Mu]p[x_, 
          U_]} = {\(\[Gamma]'\)[x], \(\[Mu]'\)[x]} /. 
          Solve[{mom2 \[Equal] 0, 
              ener2 \[Equal] 0}, {\(\[Mu]'\)[x], \(\[Gamma]'\)[x]}] // 
        First\)], "Input"],

Cell[BoxData[
    \(\(\[Mu]p[x, U] // Simplify\) // Collect[#, {\(U'\)[x]}] &\)], "Input"],

Cell[BoxData[
    \(\(\[Gamma]p[x, U] // Simplify\) // Collect[#, {\(U'\)[x]}] &\)], "Input"],

Cell["Differential equation stops at the critical point", "Text"],

Cell[BoxData[
    \(\(\[Epsilon] = 10\^\(-9\);\)\)], "Input"],

Cell[BoxData[
    \(dsol[U_] := 
      Block[{\[Mu], \[Gamma]}, {\[Mu], \[Gamma]} /. 
            NDSolve[{\(\[Mu]'\)[x] \[Equal] \[Mu]p[x, U], \(\[Gamma]'\)[
                    x] \[Equal] \[Gamma]p[x, 
                    U], \[Gamma][\[Epsilon]] \[Equal] \[Gamma]\_1\
\ \ \[Epsilon]\ , \[Mu][\[Epsilon]] \[Equal] \[Mu]\_0}, {\[Gamma], \[Mu]}, \
{x, \[Epsilon], 1}, StoppingTest \[Rule] \[Mu][x] \[LessEqual] 10\^\(-6\)] // 
          First]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example flows", "Section"],

Cell["Define a set of 9 decelerating functions", "Text"],

Cell[BoxData[
    \(\(Us = 
        Thread[Function[
            x, {1 - x, \@\(1 - x\), \((1 - x)\)\^2, 1\/\(1 + x\), 
              1\/\((1 + x)\)\^2, 1 - x\^2, 1 - x\^4, 1 - x\^8, 
              Cos[x]}]];\)\)], "Input"],

Cell[BoxData[
    \(length = Length[Us]\)], "Input"],

Cell["Exact values from White", "Text"],

Cell[BoxData[
    \(\(exact = {0.120, 0.218, 0.0637, 0.151, 0.0713, 0.271, 0.462, 0.640, 
          0.389};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determine separation point", "Section"],

Cell["Get all solutions", "Text"],

Cell[BoxData[
    \(\(sols = Map[dsol, Us];\)\)], "Input"],

Cell["Extract critical points", "Text"],

Cell[BoxData[
    \(xcs = 
      Map[#[\([1, 1, 1, 2]\)] &, sols] // SetAccuracy[#, 4] &\)], "Input"],

Cell["Deviations", "Text"],

Cell[BoxData[
    \(dev = \(xcs - exact\)\/exact\)], "Input"],

Cell["Rms deviation", "Text"],

Cell[BoxData[
    \(\@\(Plus @@ \(dev\^2\)\/length\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the solutions", "Section"],

Cell[BoxData[
    \(plot\[Mu][n_] := 
      Block[{\[Mu] = sols[\([n, 1]\)], xc = xcs[\([n]\)]}, 
        Plot[\[Mu][x], {x, 0, xc}, 
          PlotStyle \[Rule] 
            Text[n, {xc + If[n \[Equal] 3, \(-0.01\), 0.01], \[Mu][xc] + 
                  0.1}], DisplayFunction \[Rule] Identity]]\)], "Input"],

Cell[BoxData[
    \(\(Show[{Table[plot\[Mu][n], {n, 9}]}, 
          DisplayFunction \[Rule] $DisplayFunction, 
          AxesLabel \[Rule] {"\<x\>", "\<\[Mu]\>"}, PlotRange \[Rule] {0, 2}, 
          PlotLabel -> "\<(a)\>"] \
// \[IndentingNewLine]Figure["\<boundaries11\>", 
          ImageSize \[Rule] 300];\)\)], "Input"],

Cell[BoxData[
    \(plot\[Gamma][n_] := 
      Block[{\[Mu] = sols[\([n, 2]\)], xc = xcs[\([n]\)]}, 
        Plot[\[Mu][x], {x, 0, xc}, 
          PlotStyle \[Rule] Text[n, {xc, \[Mu][xc] + 1}], 
          DisplayFunction \[Rule] Identity]]\)], "Input"],

Cell[BoxData[
    \(\(Show[{Table[plot\[Gamma][n], {n, 9}]}, 
          DisplayFunction \[Rule] $DisplayFunction, 
          AxesLabel \[Rule] {"\<x\>", "\<\[Gamma]\>"}, PlotRange \[Rule] All, 
          PlotLabel -> "\<(b)\>"] \
// \[IndentingNewLine]Figure["\<boundaries12\>", 
          ImageSize \[Rule] 300];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["28.4.1 Weather vane", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(L = 30  Centimeter;\)\), "\n", 
    \(\(K\  = \ 20\ Centimeter;\)\), "\n", 
    \(\(U\  = \ 10\ Meter/Second;\)\), "\n", 
    \(\(\[Nu] = 
        1.5\ \(10\^\(-5\)\) \(\(\ \)\(Meter\^2\)\)\/Second;\)\), "\n", 
    \(\(\[Rho]\  = \ 1.2\ Kilogram/Meter\^3;\)\)}], "Input"],

Cell["Area", "Text"],

Cell[BoxData[
    \(A\  = \ K\ L\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Reynolds = \(U\ L\)\/\[Nu] // ToSI\)], "Input"],

Cell["Drag coefficient", "Text"],

Cell[BoxData[
    \(C\_D = 2.65\/\@Reynolds\)], "Input"],

Cell["Drag itself", "Text"],

Cell[BoxData[
    \(drag\  = \ \(1\/2\) \[Rho]\ \(U\^2\) A\ C\_D // 
        ToUnit[Newton]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["28.6 The wall approximation", "Section"],

Cell["See the analysis  above.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["28.7 The Pohlhausen approximation", "Section"],

Cell["See the analysis  above.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["28.8 Energy plus momentum approximation", "Section"],

Cell["See the analysis  above.", "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
AutoGeneratedPackage->None,
WindowSize->{840, 903},
WindowMargins->{{83, Automatic}, {69, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 36, 0, 95, "Title"],
Cell[1815, 55, 103, 3, 50, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1955, 63, 37, 0, 95, "Title"],
Cell[1995, 65, 51, 1, 30, "Input"],
Cell[2049, 68, 39, 0, 33, "Text"],
Cell[2091, 70, 128, 2, 48, "Input"],
Cell[2222, 74, 29, 0, 33, "Text"],
Cell[2254, 76, 53, 1, 30, "Input"],
Cell[2310, 79, 46, 1, 30, "Input"],
Cell[2359, 82, 49, 1, 44, "Input"],
Cell[2411, 85, 30, 0, 33, "Text"],
Cell[2444, 87, 76, 1, 30, "Input"],
Cell[2523, 90, 20, 0, 33, "Text"],
Cell[2546, 92, 188, 4, 30, "Input"],
Cell[2737, 98, 170, 3, 44, "Input"],
Cell[2910, 103, 139, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3086, 110, 33, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[3144, 114, 35, 0, 73, "Section"],
Cell[3182, 116, 46, 1, 30, "Input"],
Cell[3231, 119, 49, 0, 33, "Text"],
Cell[3283, 121, 89, 1, 51, "Input"],
Cell[3375, 124, 47, 0, 33, "Text"],
Cell[3425, 126, 46, 1, 30, "Input"],
Cell[3474, 129, 55, 1, 30, "Input"],
Cell[3532, 132, 30, 0, 33, "Text"],
Cell[3565, 134, 194, 3, 62, "Input"],
Cell[3762, 139, 32, 0, 33, "Text"],
Cell[3797, 141, 138, 2, 30, "Input"],
Cell[3938, 145, 50, 0, 33, "Text"],
Cell[3991, 147, 137, 2, 54, "Input"],
Cell[4131, 151, 51, 0, 33, "Text"],
Cell[4185, 153, 43, 1, 30, "Input"],
Cell[4231, 156, 43, 1, 30, "Input"],
Cell[4277, 159, 32, 0, 33, "Text"],
Cell[4312, 161, 56, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4405, 167, 50, 0, 73, "Section"],
Cell[4458, 169, 51, 1, 30, "Input"],
Cell[4512, 172, 28, 0, 33, "Text"],
Cell[4543, 174, 44, 1, 30, "Input"],
Cell[4590, 177, 36, 0, 33, "Text"],
Cell[4629, 179, 366, 8, 90, "Input"],
Cell[4998, 189, 32, 0, 33, "Text"],
Cell[5033, 191, 58, 1, 32, "Input"],
Cell[5094, 194, 33, 0, 33, "Text"],
Cell[5130, 196, 188, 4, 76, "Input"],
Cell[5321, 202, 21, 0, 33, "Text"],
Cell[5345, 204, 50, 1, 30, "Input"],
Cell[5398, 207, 43, 1, 32, "Input"],
Cell[5444, 210, 25, 0, 33, "Text"],
Cell[5472, 212, 84, 1, 30, "Input"],
Cell[5559, 215, 46, 1, 32, "Input"],
Cell[5608, 218, 32, 0, 33, "Text"],
Cell[5643, 220, 64, 1, 30, "Input"],
Cell[5710, 223, 44, 1, 30, "Input"],
Cell[5757, 226, 50, 1, 48, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5844, 232, 24, 0, 73, "Section"],
Cell[5871, 234, 350, 6, 70, "Input"],
Cell[6224, 242, 336, 7, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6597, 254, 61, 0, 73, "Section"],
Cell[6661, 256, 59, 1, 44, "Input"],
Cell[6723, 259, 82, 1, 30, "Input"],
Cell[6808, 262, 92, 1, 30, "Input"],
Cell[6903, 265, 103, 2, 31, "Input"],
Cell[7009, 269, 88, 1, 31, "Input"],
Cell[7100, 272, 70, 1, 30, "Input"],
Cell[7173, 275, 68, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7278, 281, 36, 0, 73, "Section"],
Cell[7317, 283, 254, 5, 48, "Input"],
Cell[7574, 290, 325, 6, 50, "Input"],
Cell[7902, 298, 59, 1, 32, "Input"],
Cell[7964, 301, 167, 3, 30, "Input"],
Cell[8134, 306, 333, 6, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8516, 318, 42, 0, 95, "Title"],
Cell[8561, 320, 51, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[8637, 325, 39, 0, 73, "Section"],
Cell[8679, 327, 53, 0, 33, "Text"],
Cell[8735, 329, 218, 4, 90, "Input"],
Cell[8956, 335, 44, 0, 33, "Text"],
Cell[9003, 337, 61, 1, 48, "Input"],
Cell[9067, 340, 49, 0, 33, "Text"],
Cell[9119, 342, 72, 1, 50, "Input"],
Cell[9194, 345, 64, 1, 30, "Input"],
Cell[9261, 348, 81, 1, 30, "Input"],
Cell[9345, 351, 87, 1, 30, "Input"],
Cell[9435, 354, 83, 1, 30, "Input"],
Cell[9521, 357, 1084, 21, 189, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10642, 383, 48, 0, 73, "Section"],
Cell[10693, 385, 28, 0, 33, "Text"],
Cell[10724, 387, 64, 1, 32, "Input"],
Cell[10791, 390, 32, 0, 33, "Text"],
Cell[10826, 392, 123, 2, 43, "Input"],
Cell[10952, 396, 31, 0, 33, "Text"],
Cell[10986, 398, 138, 2, 42, "Input"],
Cell[11127, 402, 24, 0, 33, "Text"],
Cell[11154, 404, 122, 2, 37, "Input"],
Cell[11279, 408, 58, 1, 36, "Input"],
Cell[11340, 411, 33, 0, 33, "Text"],
Cell[11376, 413, 88, 1, 30, "Input"],
Cell[11467, 416, 183, 3, 30, "Input"],
Cell[11653, 421, 137, 3, 30, "Input"],
Cell[11793, 426, 692, 12, 106, "Input"],
Cell[12488, 440, 468, 8, 106, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13005, 454, 39, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[13069, 458, 40, 0, 73, "Section"],
Cell[13112, 460, 51, 1, 30, "Input"],
Cell[13166, 463, 48, 0, 33, "Text"],
Cell[13217, 465, 81, 1, 42, "Input"],
Cell[13301, 468, 30, 0, 33, "Text"],
Cell[13334, 470, 185, 3, 50, "Input"],
Cell[13522, 475, 50, 0, 33, "Text"],
Cell[13575, 477, 124, 2, 30, "Input"],
Cell[13702, 481, 32, 0, 33, "Text"],
Cell[13737, 483, 193, 4, 30, "Input"],
Cell[13933, 489, 56, 0, 33, "Text"],
Cell[13992, 491, 84, 1, 44, "Input"],
Cell[14079, 494, 265, 7, 44, "Input"],
Cell[14347, 503, 41, 0, 33, "Text"],
Cell[14391, 505, 84, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14512, 511, 39, 0, 73, "Section"],
Cell[14554, 513, 51, 1, 30, "Input"],
Cell[14608, 516, 46, 0, 33, "Text"],
Cell[14657, 518, 72, 1, 44, "Input"],
Cell[14732, 521, 69, 0, 33, "Text"],
Cell[14804, 523, 561, 10, 114, "Input"],
Cell[15368, 535, 31, 0, 33, "Text"],
Cell[15402, 537, 249, 5, 50, "Input"],
Cell[15654, 544, 88, 2, 33, "Text"],
Cell[15745, 548, 256, 5, 70, "Input"],
Cell[16004, 555, 49, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16090, 561, 48, 0, 73, "Section"],
Cell[16141, 563, 35, 0, 33, "Text"],
Cell[16179, 565, 79, 1, 31, "Input"],
Cell[16261, 568, 32, 0, 33, "Text"],
Cell[16296, 570, 170, 3, 96, "Input"],
Cell[16469, 575, 31, 0, 33, "Text"],
Cell[16503, 577, 114, 2, 45, "Input"],
Cell[16620, 581, 103, 2, 44, "Input"],
Cell[16726, 585, 27, 0, 33, "Text"],
Cell[16756, 587, 38, 1, 30, "Input"],
Cell[16797, 590, 43, 1, 30, "Input"],
Cell[16843, 593, 46, 1, 30, "Input"],
Cell[16892, 596, 33, 0, 33, "Text"],
Cell[16928, 598, 322, 5, 70, "Input"],
Cell[17253, 605, 21, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17311, 610, 29, 0, 73, "Section"],
Cell[17343, 612, 30, 0, 33, "Text"],
Cell[17376, 614, 56, 1, 30, "Input"],
Cell[17435, 617, 50, 1, 30, "Input"],
Cell[17488, 620, 54, 1, 30, "Input"],
Cell[17545, 623, 51, 0, 33, "Text"],
Cell[17599, 625, 158, 2, 30, "Input"],
Cell[17760, 629, 69, 0, 33, "Text"],
Cell[17832, 631, 161, 3, 30, "Input"],
Cell[17996, 636, 33, 0, 33, "Text"],
Cell[18032, 638, 137, 3, 30, "Input"],
Cell[18172, 643, 183, 3, 30, "Input"],
Cell[18358, 648, 128, 3, 30, "Input"],
Cell[18489, 653, 312, 5, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18838, 663, 36, 0, 73, "Section"],
Cell[18877, 665, 38, 0, 33, "Text"],
Cell[18918, 667, 88, 1, 30, "Input"],
Cell[19009, 670, 35, 0, 33, "Text"],
Cell[19047, 672, 136, 2, 30, "Input"],
Cell[19186, 676, 50, 0, 33, "Text"],
Cell[19239, 678, 64, 1, 30, "Input"],
Cell[19306, 681, 54, 1, 30, "Input"],
Cell[19363, 684, 57, 1, 30, "Input"],
Cell[19423, 687, 94, 2, 33, "Text"],
Cell[19520, 691, 83, 1, 30, "Input"],
Cell[19606, 694, 33, 0, 33, "Text"],
Cell[19642, 696, 382, 6, 70, "Input"],
Cell[20027, 704, 187, 4, 30, "Input"],
Cell[20217, 710, 30, 0, 33, "Text"],
Cell[20250, 712, 229, 5, 50, "Input"],
Cell[20482, 719, 266, 5, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20785, 729, 44, 0, 73, "Section"],
Cell[20832, 731, 36, 0, 33, "Text"],
Cell[20871, 733, 138, 3, 30, "Input"],
Cell[21012, 738, 30, 0, 33, "Text"],
Cell[21045, 740, 47, 1, 30, "Input"],
Cell[21095, 743, 50, 0, 33, "Text"],
Cell[21148, 745, 152, 3, 30, "Input"],
Cell[21303, 750, 138, 3, 30, "Input"],
Cell[21444, 755, 178, 3, 30, "Input"],
Cell[21625, 760, 132, 3, 30, "Input"],
Cell[21760, 765, 275, 5, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22084, 776, 50, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[22159, 780, 25, 0, 73, "Section"],
Cell[22187, 782, 51, 1, 30, "Input"],
Cell[22241, 785, 38, 0, 33, "Text"],
Cell[22282, 787, 167, 4, 47, "Input"],
Cell[22452, 793, 30, 0, 33, "Text"],
Cell[22485, 795, 264, 5, 43, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22786, 805, 50, 0, 73, "Section"],
Cell[22839, 807, 107, 2, 30, "Input"],
Cell[22949, 811, 115, 3, 51, "Input"],
Cell[23067, 816, 200, 3, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23304, 824, 46, 0, 73, "Section"],
Cell[23353, 826, 321, 7, 44, "Input"],
Cell[23677, 835, 62, 1, 30, "Input"],
Cell[23742, 838, 377, 8, 106, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24156, 851, 32, 0, 73, "Section"],
Cell[24191, 853, 56, 0, 33, "Text"],
Cell[24250, 855, 223, 5, 44, "Input"],
Cell[24476, 862, 52, 1, 30, "Input"],
Cell[24531, 865, 39, 0, 33, "Text"],
Cell[24573, 867, 122, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24732, 874, 56, 0, 73, "Section"],
Cell[24791, 876, 33, 0, 33, "Text"],
Cell[24827, 878, 73, 1, 30, "Input"],
Cell[24903, 881, 40, 0, 33, "Text"],
Cell[24946, 883, 84, 1, 30, "Input"],
Cell[25033, 886, 50, 1, 30, "Input"],
Cell[25086, 889, 44, 0, 33, "Text"],
Cell[25133, 891, 61, 1, 42, "Input"],
Cell[25197, 894, 34, 0, 33, "Text"],
Cell[25234, 896, 65, 1, 50, "Input"],
Cell[25302, 899, 35, 0, 33, "Text"],
Cell[25340, 901, 103, 2, 51, "Input"],
Cell[25446, 905, 39, 0, 33, "Text"],
Cell[25488, 907, 61, 1, 30, "Input"],
Cell[25552, 910, 32, 0, 33, "Text"],
Cell[25587, 912, 386, 7, 90, "Input"],
Cell[25976, 921, 238, 5, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26251, 931, 72, 0, 73, "Section"],
Cell[26326, 933, 59, 1, 30, "Input"],
Cell[26388, 936, 93, 1, 30, "Input"],
Cell[26484, 939, 61, 1, 42, "Input"],
Cell[26548, 942, 65, 1, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26650, 948, 37, 0, 73, "Section"],
Cell[26690, 950, 317, 6, 70, "Input"],
Cell[27010, 958, 223, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27270, 967, 31, 0, 73, "Section"],
Cell[27304, 969, 143, 2, 42, "Input"],
Cell[27450, 973, 153, 3, 30, "Input"],
Cell[27606, 978, 126, 3, 30, "Input"],
Cell[27735, 983, 294, 6, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28066, 994, 35, 0, 73, "Section"],
Cell[28104, 996, 62, 1, 42, "Input"],
Cell[28169, 999, 109, 2, 42, "Input"],
Cell[28281, 1003, 136, 2, 42, "Input"],
Cell[28420, 1007, 76, 1, 30, "Input"],
Cell[28499, 1010, 72, 1, 45, "Input"],
Cell[28574, 1013, 71, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28694, 1020, 56, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[28775, 1024, 27, 0, 73, "Section"],
Cell[28805, 1026, 51, 1, 30, "Input"],
Cell[28859, 1029, 48, 0, 33, "Text"],
Cell[28910, 1031, 185, 4, 41, "Input"],
Cell[29098, 1037, 37, 0, 33, "Text"],
Cell[29138, 1039, 81, 1, 30, "Input"],
Cell[29222, 1042, 119, 2, 30, "Input"],
Cell[29344, 1046, 134, 2, 30, "Input"],
Cell[29481, 1050, 38, 0, 33, "Text"],
Cell[29522, 1052, 140, 3, 30, "Input"],
Cell[29665, 1057, 38, 0, 33, "Text"],
Cell[29706, 1059, 90, 1, 40, "Input"],
Cell[29799, 1062, 64, 0, 33, "Text"],
Cell[29866, 1064, 63, 1, 30, "Input"],
Cell[29932, 1067, 29, 0, 33, "Text"],
Cell[29964, 1069, 110, 2, 42, "Input"],
Cell[30077, 1073, 111, 2, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30225, 1080, 34, 0, 73, "Section"],
Cell[30262, 1082, 51, 1, 30, "Input"],
Cell[30316, 1085, 40, 0, 33, "Text"],
Cell[30359, 1087, 117, 3, 51, "Input"],
Cell[30479, 1092, 27, 0, 33, "Text"],
Cell[30509, 1094, 316, 5, 115, "Input"],
Cell[30828, 1101, 31, 0, 33, "Text"],
Cell[30862, 1103, 232, 4, 44, "Input"],

Cell[CellGroupData[{
Cell[31119, 1111, 68, 0, 38, "Subsection"],
Cell[31190, 1113, 239, 4, 44, "Input"],
Cell[31432, 1119, 171, 3, 44, "Input"],
Cell[31606, 1124, 284, 5, 65, "Input"],
Cell[31893, 1131, 34, 0, 33, "Text"],
Cell[31930, 1133, 81, 1, 31, "Input"],
Cell[32014, 1136, 109, 2, 31, "Input"],
Cell[32126, 1140, 199, 4, 31, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32374, 1150, 48, 0, 73, "Section"],
Cell[32425, 1152, 62, 1, 30, "Input"],
Cell[32490, 1155, 49, 0, 33, "Text"],
Cell[32542, 1157, 469, 8, 47, "Input"],
Cell[33014, 1167, 56, 0, 33, "Text"],
Cell[33073, 1169, 91, 1, 30, "Input"],
Cell[33167, 1172, 37, 0, 33, "Text"],
Cell[33207, 1174, 352, 7, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33596, 1186, 32, 0, 73, "Section"],
Cell[33631, 1188, 56, 0, 33, "Text"],
Cell[33690, 1190, 223, 5, 44, "Input"],
Cell[33916, 1197, 52, 1, 30, "Input"],
Cell[33971, 1200, 39, 0, 33, "Text"],
Cell[34013, 1202, 122, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34172, 1209, 46, 0, 73, "Section"],
Cell[34221, 1211, 59, 1, 30, "Input"],
Cell[34283, 1214, 93, 1, 30, "Input"],
Cell[34379, 1217, 61, 1, 42, "Input"],
Cell[34443, 1220, 65, 1, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34545, 1226, 37, 0, 73, "Section"],
Cell[34585, 1228, 308, 6, 70, "Input"],
Cell[34896, 1236, 215, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35148, 1245, 28, 0, 73, "Section"],
Cell[35179, 1247, 45, 1, 30, "Input"],
Cell[35227, 1250, 39, 0, 33, "Text"],
Cell[35269, 1252, 51, 1, 30, "Input"],
Cell[35323, 1255, 47, 1, 30, "Input"],
Cell[35373, 1258, 35, 0, 33, "Text"],
Cell[35411, 1260, 49, 1, 30, "Input"],
Cell[35463, 1263, 31, 0, 33, "Text"],
Cell[35497, 1265, 117, 3, 51, "Input"],
Cell[35617, 1270, 62, 0, 33, "Text"],
Cell[35682, 1272, 333, 7, 42, "Input"],
Cell[36018, 1281, 64, 0, 33, "Text"],
Cell[36085, 1283, 299, 5, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36421, 1293, 41, 0, 73, "Section"],
Cell[36465, 1295, 171, 3, 30, "Input"],
Cell[36639, 1300, 182, 4, 30, "Input"],
Cell[36824, 1306, 126, 3, 30, "Input"],
Cell[36953, 1311, 345, 6, 90, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[37347, 1323, 39, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[37411, 1327, 32, 0, 73, "Section"],
Cell[37446, 1329, 51, 1, 30, "Input"],
Cell[37500, 1332, 31, 0, 33, "Text"],
Cell[37534, 1334, 158, 3, 30, "Input"],
Cell[37695, 1339, 33, 0, 33, "Text"],
Cell[37731, 1341, 53, 1, 30, "Input"],
Cell[37787, 1344, 108, 2, 42, "Input"],
Cell[37898, 1348, 109, 2, 42, "Input"],
Cell[38010, 1352, 55, 1, 30, "Input"],
Cell[38068, 1355, 113, 2, 42, "Input"],
Cell[38184, 1359, 60, 1, 42, "Input"],
Cell[38247, 1362, 55, 1, 30, "Input"],
Cell[38305, 1365, 138, 2, 42, "Input"],
Cell[38446, 1369, 57, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38540, 1375, 116, 4, 73, "Section"],
Cell[38659, 1381, 69, 1, 44, "Input"],
Cell[38731, 1384, 146, 3, 84, "Input"],
Cell[38880, 1389, 285, 5, 61, "Input"],
Cell[39168, 1396, 65, 1, 30, "Input"],
Cell[39236, 1399, 65, 1, 30, "Input"],
Cell[39304, 1402, 65, 1, 44, "Input"],
Cell[39372, 1405, 51, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39460, 1411, 117, 4, 73, "Section"],
Cell[39580, 1417, 173, 3, 84, "Input"],
Cell[39756, 1422, 288, 5, 61, "Input"],
Cell[40047, 1429, 65, 1, 30, "Input"],
Cell[40115, 1432, 65, 1, 30, "Input"],
Cell[40183, 1435, 65, 1, 44, "Input"],
Cell[40251, 1438, 51, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40339, 1444, 41, 0, 73, "Section"],
Cell[40383, 1446, 46, 0, 33, "Text"],
Cell[40432, 1448, 150, 2, 69, "Input"],
Cell[40585, 1452, 38, 0, 33, "Text"],
Cell[40626, 1454, 110, 2, 50, "Input"],
Cell[40739, 1458, 37, 0, 33, "Text"],
Cell[40779, 1460, 77, 1, 30, "Input"],
Cell[40859, 1463, 25, 0, 33, "Text"],
Cell[40887, 1465, 71, 1, 30, "Input"],
Cell[40961, 1468, 151, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41149, 1476, 32, 0, 73, "Section"],
Cell[41184, 1478, 56, 0, 33, "Text"],
Cell[41243, 1480, 223, 5, 44, "Input"],
Cell[41469, 1487, 52, 1, 30, "Input"],
Cell[41524, 1490, 39, 0, 33, "Text"],
Cell[41566, 1492, 122, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41725, 1499, 36, 0, 73, "Section"],
Cell[41764, 1501, 47, 1, 30, "Input"],
Cell[41814, 1504, 200, 4, 50, "Input"],
Cell[42017, 1510, 74, 1, 30, "Input"],
Cell[42094, 1513, 26, 0, 33, "Text"],
Cell[42123, 1515, 61, 1, 42, "Input"],
Cell[42187, 1518, 23, 0, 33, "Text"],
Cell[42213, 1520, 65, 1, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42315, 1526, 38, 0, 73, "Section"],
Cell[42356, 1528, 46, 1, 30, "Input"],
Cell[42405, 1531, 51, 1, 30, "Input"],
Cell[42459, 1534, 51, 1, 42, "Input"],
Cell[42513, 1537, 89, 1, 30, "Input"],
Cell[42605, 1540, 187, 3, 30, "Input"],
Cell[42795, 1545, 50, 1, 30, "Input"],
Cell[42848, 1548, 51, 1, 42, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42948, 1555, 52, 0, 95, "Title"],
Cell[43003, 1557, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[43074, 1562, 56, 0, 73, "Section"],
Cell[43133, 1564, 446, 8, 171, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43616, 1577, 37, 0, 73, "Section"],
Cell[43656, 1579, 32, 0, 33, "Text"],
Cell[43691, 1581, 223, 4, 44, "Input"],
Cell[43917, 1587, 56, 0, 33, "Text"],
Cell[43976, 1589, 187, 3, 44, "Input"],
Cell[44166, 1594, 361, 6, 88, "Input"],
Cell[44530, 1602, 35, 0, 33, "Text"],
Cell[44568, 1604, 78, 1, 31, "Input"],
Cell[44649, 1607, 58, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44744, 1613, 35, 0, 73, "Section"],
Cell[44782, 1615, 32, 0, 33, "Text"],
Cell[44817, 1617, 189, 3, 47, "Input"],
Cell[45009, 1622, 56, 0, 33, "Text"],
Cell[45068, 1624, 176, 3, 44, "Input"],
Cell[45247, 1629, 378, 6, 88, "Input"],
Cell[45628, 1637, 35, 0, 33, "Text"],
Cell[45666, 1639, 91, 1, 31, "Input"],
Cell[45760, 1642, 81, 1, 31, "Input"],
Cell[45844, 1645, 118, 3, 31, "Input"],
Cell[45965, 1650, 91, 1, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46093, 1656, 37, 0, 73, "Section"],
Cell[46133, 1658, 94, 3, 34, "Text"],
Cell[46230, 1663, 226, 4, 47, "Input"],
Cell[46459, 1669, 30, 0, 33, "Text"],
Cell[46492, 1671, 71, 1, 30, "Input"],
Cell[46566, 1674, 40, 0, 33, "Text"],
Cell[46609, 1676, 125, 2, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46771, 1683, 40, 0, 73, "Section"],
Cell[46814, 1685, 240, 5, 30, "Input"],
Cell[47057, 1692, 90, 1, 30, "Input"],
Cell[47150, 1695, 93, 1, 30, "Input"],
Cell[47246, 1698, 65, 0, 33, "Text"],
Cell[47314, 1700, 61, 1, 30, "Input"],
Cell[47378, 1703, 457, 8, 93, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47872, 1716, 32, 0, 73, "Section"],
Cell[47907, 1718, 56, 0, 33, "Text"],
Cell[47966, 1720, 223, 5, 44, "Input"],
Cell[48192, 1727, 52, 1, 30, "Input"],
Cell[48247, 1730, 39, 0, 33, "Text"],
Cell[48289, 1732, 122, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48448, 1739, 45, 0, 73, "Section"],
Cell[48496, 1741, 33, 0, 33, "Text"],
Cell[48532, 1743, 58, 1, 30, "Input"],
Cell[48593, 1746, 39, 0, 33, "Text"],
Cell[48635, 1748, 101, 2, 30, "Input"],
Cell[48739, 1752, 26, 0, 33, "Text"],
Cell[48768, 1754, 61, 1, 42, "Input"],
Cell[48832, 1757, 29, 0, 33, "Text"],
Cell[48864, 1759, 65, 1, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48966, 1765, 37, 0, 73, "Section"],
Cell[49006, 1767, 309, 6, 70, "Input"],
Cell[49318, 1775, 325, 6, 70, "Input"],
Cell[49646, 1783, 253, 5, 50, "Input"],
Cell[49902, 1790, 328, 6, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[50279, 1802, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[50329, 1806, 38, 0, 73, "Section"],
Cell[50370, 1808, 46, 1, 30, "Input"],
Cell[50419, 1811, 26, 0, 33, "Text"],
Cell[50448, 1813, 294, 6, 127, "Input"],
Cell[50745, 1821, 20, 0, 33, "Text"],
Cell[50768, 1823, 45, 1, 30, "Input"],
Cell[50816, 1826, 31, 0, 33, "Text"],
Cell[50850, 1828, 67, 1, 42, "Input"],
Cell[50920, 1831, 32, 0, 33, "Text"],
Cell[50955, 1833, 56, 1, 48, "Input"],
Cell[51014, 1836, 27, 0, 33, "Text"],
Cell[51044, 1838, 104, 2, 42, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[51197, 1846, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[51247, 1850, 46, 0, 73, "Section"],
Cell[51296, 1852, 40, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51373, 1857, 52, 0, 73, "Section"],
Cell[51428, 1859, 40, 0, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51505, 1864, 58, 0, 73, "Section"],
Cell[51566, 1866, 40, 0, 33, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

