(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14460,        552]*)
(*NotebookOutlinePosition[     15133,        575]*)
(*  CellTagsIndexPosition[     15089,        571]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["30. Heat", "Title",
  InitializationCell->True],

Cell[BoxData[{
    \(<< Lautrup`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Heat diffusion", "Title"],

Cell[CellGroupData[{

Cell["Planar heat diffusion", "Section"],

Cell[BoxData[
    \(\(CleanGlobal[];\)\)], "Input"],

Cell["Gaussian temperature distribution", "Text"],

Cell[BoxData[
    \(\(T = \(T\_0\) \(a\/\@\(a\^2 + 4  \[Kappa]\ t\)\) 
          Exp[\(-\(x\^2\/\(a\^2 + 4  \[Kappa]\ t\)\)\)];\)\)], "Input"],

Cell["Check it satisfies the heat equation", "Text"],

Cell[BoxData[
    \(\[PartialD]\_t T - \[Kappa]\ \[PartialD]\_x\^2 T // Simplify\)], "Input"],

Cell["Make typical plot", "Text"],

Cell[BoxData[
    \(\(Plot[{2  Exp[\(-5\) x\^2], Exp[\(-x\^2\)], 
            0.5  Exp[\(-x\^2\)/5]}, {x, \(-3\), 3}, PlotRange \[Rule] All, 
          Ticks \[Rule] None, 
          AxesLabel \[Rule] {"\<x\>", "\<T\>"}] \
// \[IndentingNewLine]Figure["\<heat1\>", 
          ImageSize \[Rule] 200];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spherical heat diffusion", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Gaussian distribution", "Text"],

Cell[BoxData[
    \(\(T = 
        T\_0 + \ \[CapitalTheta]\ a\^\(3/2\)\ \(\((a\^2 + 
                    4  \[Kappa]\ t)\)\^\(\(-3\)/
                  2\)\) \[ExponentialE]\^\(-\ \(r\^2\/\(a\^2 + 4  \[Kappa]\ t\
\)\)\);\)\)], "Input"],

Cell["Check it satisfies the heat equation", "Text"],

Cell[BoxData[
    \(\(\[PartialD]\_t 
            T - \[Kappa]\ \((\[PartialD]\_r\^2 
                  T + \(2\/r\) \[PartialD]\_r T)\) // Expand\) // 
      Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Average temperature of Denmark as a function of depth for year 2000\
\>", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters in SI units", "Text"],

Cell[BoxData[{
    \(\(\[CapitalTheta] = 8;\)\), "\[IndentingNewLine]", 
    \(\(\[Tau] = 1\ Year // NToSI;\)\), "\[IndentingNewLine]", 
    \(\(d = 1.12;\)\), "\[IndentingNewLine]", 
    \(\(T\_0 = 8;\)\)}], "Input"],

Cell["Wave length", "Text"],

Cell[BoxData[
    \(\[Lambda] = 2  \[Pi]\ d\)], "Input"],

Cell["Temperature distribution", "Text"],

Cell[BoxData[
    \(\(T[t_, z_] = 
        T\_0 + \[CapitalTheta]\ \(\[ExponentialE]\^\(\(-\ z\)/d\)\) 
            Cos[2  \[Pi]\ t\/\[Tau] - z\/d];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[{T[0, z], T[0.5  \[Tau], z], 8}, {z, 0, \[Lambda]}, 
          PlotRange \[Rule] {0, 16}, 
          AxesLabel -> {"\<z[m]\>", \*"\"\<T\!\([\^o\)C]\>\""}, \
\[IndentingNewLine]PlotStyle \[Rule] {Text["\<Summer\>", {1, 14}], 
              Text["\<Winter\>", {1, 2}], {Dashing[{}], Dashing[{}], 
                Dashing[{0.02}]}}] // \[IndentingNewLine]Figure["\<heat3\>"];\
\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Blasius boundary layer with heat flow", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Solve Blasius equation by rescaling", "Section"],

Cell["Cutoff", "Text"],

Cell[BoxData[
    \(\(A = 250;\)\)], "Input"],

Cell["Solution", "Text"],

Cell[BoxData[
    \(sol = 
      Block[{g, 
          G}, {g, G} /. 
            NDSolve[{\(g'''\)[s] == \(-\ g[s]\)\ \(g''\)[s], \(G'\)[
                    s] \[Equal] g[s], \ 
                g[0] \[Equal] 0, \(g'\)[0] \[Equal] 0, \(g''\)[0] \[Equal] 1, 
                G[0] \[Equal] 0}, {g, G}, {s, 0, A}] // First]\)], "Input"],

Cell["Scaling factor", "Text"],

Cell[BoxData[
    \(\[Alpha] = \(sol[\([1]\)]'\)[A]\)], "Input"],

Cell["Final solution", "Text"],

Cell[BoxData[{
    \(\(g[
          s_] = \(1\/\@\[Alpha]\) \(sol[\([1]\)]\)[\ 
            s\/\@\[Alpha]];\)\), "\[IndentingNewLine]", 
    \(\(G[s_] = \(sol[\([2]\)]\)[\ s\/\@\[Alpha]];\)\)}], "Input"],

Cell["Plot shapes", "Text"],

Cell[BoxData[
    \(\(Plot[g[s], {s, 0, A}, PlotRange \[Rule] All];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[G[s], {s, 0, A}, PlotRange \[Rule] All];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integrated heat function", "Section"],

Cell["Heat function as a function of Prandtl number", "Text"],

Cell[BoxData[
    \(H[s_, Pr_] := 
      Module[{u}, NIntegrate[Exp[\(-Pr\)\ G[u]], {u, 0, s}]]\)], "Input"],

Cell["Heat distribution function", "Text"],

Cell[BoxData[
    \(F[s_, Pr_] := 1 - H[s, Pr]\/H[A, Pr]\)], "Input"],

Cell["Make plots", "Text"],

Cell[BoxData[
    \(\(Plot[{F[s, 0.1], F[s, 1], F[s, 10]}, {s, 0, 10}, 
          PlotRange \[Rule] {0, 1}, AxesLabel \[Rule] {"\<s\>", "\<F\>"}, 
          PlotLabel -> "\<(a)\>", 
          PlotStyle \[Rule] {Text["\<0.1\>", {4, 0.32}, {\(-1\), 0}], 
              Text["\<Pr=1\>", {2, 0.25}, {\(-1\), 0}], 
              Text["\<10\>", {1, 0.13}, {\(-1\), 
                  0}]}] // \[IndentingNewLine]Figure["\<heat4\>", 
          ImageSize \[Rule] 300];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Slope", "Section"],

Cell["As a function of Prandtl number", "Text"],

Cell[BoxData[
    \(slope[Pr_] := 1\/H[A, Pr]\)], "Input"],

Cell[BoxData[
    \(\(figa = 
        LogLogPlot[{slope[Pr]}, {Pr, 0.001, 1}, PlotPoints \[Rule] 1000, 
          PlotRange \[Rule] All, PlotLabel -> "\<(b)\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(figb = 
        LogLogPlot[{slope[Pr]}, {Pr, 1, 1000}, PlotPoints \[Rule] 1000, 
          PlotRange \[Rule] All, PlotLabel -> "\<(b)\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(figc = 
        LogLogPlot[{0.80  Pr\^\(1/2\), 0.48  Pr\^\(1/3\)}, {Pr, 0.001, 1000}, 
          PlotStyle \[Rule] {Dashing[{0.02, 0.02}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[figa, figb, figc, PlotRange \[Rule] {\(-2\), 1}, 
          AxesLabel \[Rule] {"\<Pr\>", "\<-F'(0)\>"}] \
// \[IndentingNewLine]Figure["\<heat5\>", 
          ImageSize \[Rule] 300];\)\)], "Input"],

Cell["Special values", "Text"],

Cell[BoxData[
    \(slope[1]\)], "Input"],

Cell[BoxData[
    \(slope[0.73]\)], "Input"],

Cell[BoxData[
    \(slope[6]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["30.1.1 Geothermal heat flow", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 6371\ Kilometer;\)\), "\[IndentingNewLine]", 
    \(\(f = 0.29;\)\), "\[IndentingNewLine]", 
    \(\(q\_c = 0.06\ Watt\/Meter\^2;\)\), "\[IndentingNewLine]", 
    \(\(q\_s = 0.10  Watt\/Meter\^2;\)\), "\[IndentingNewLine]", 
    \(\(k = 2\ \(Watt/Kelvin\)/Meter;\)\)}], "Input"],

Cell["Heat rate", "Text"],

Cell[BoxData[
    \(dotQ = 
      4  \[Pi]\ \(a\^2\) \((\(q\_c\) f + \(q\_s\) \((1 - f)\))\) // 
        ToUnit[Watt]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["30.2.1 Geothermal gradient", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(q\_c = 0.06\ Watt\/Meter\^2;\)\), "\[IndentingNewLine]", 
    \(\(k = 2\ \(Watt/Kelvin\)/Meter;\)\)}], "Input"],

Cell["Geothermal gradient", "Text"],

Cell[BoxData[
    \(gradT = q\_c\/k // ToSI\)], "Input"],

Cell[BoxData[
    \(gradT // ToUnit[Kelvin/Kilometer]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["30.2.2 Porridge", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Kappa] = 1.4\ \(10\^\(-7\)\) Meter\^2\/Second;\)\), "\n", 
    \(\(L = 5\ Centimeter;\)\)}], "Input"],

Cell["Diffusion time", "Text"],

Cell[BoxData[
    \(t = L\^2\/\(4  \[Kappa]\) // ToSI\)], "Input"],

Cell[BoxData[
    \(t // ToUnit[Hour]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["30.2.3 Soil heating", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(k = 0.5\ Watt\/\(Kelvin\ Meter\);\)\), "\[IndentingNewLine]", 
    \(\(\[Rho] = 2\ Gram\/Centimeter\^3;\)\), "\[IndentingNewLine]", 
    \(\(c\_0 = 2\ Joule\/\(Gram\ Kelvin\);\)\), "\[IndentingNewLine]", 
    \(\(\[Tau] = 1\ Year;\)\), "\[IndentingNewLine]", 
    \(\(L = 1\ Meter;\)\)}], "Input"],

Cell["Heat diffusivity", "Text"],

Cell[BoxData[
    \(\[Kappa] = k\/\(\[Rho]\ c\_0\) // ToSI\)], "Input"],

Cell["Penetration depth", "Text"],

Cell[BoxData[
    \(d = \@\(\(\[Kappa]\ \[Tau]\)\/\[Pi]\) // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["30.2.4 Geothermal heat production", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(dotQ = 45.*^12\ Watt;\)\), "\[IndentingNewLine]", 
    \(\(a = 6371. \ Kilometer;\)\), "\[IndentingNewLine]", 
    \(\(k = 2\ \(Watt/Kelvin\)/Meter;\)\)}], "Input"],

Cell["Average rate of heat production", "Text"],

Cell[BoxData[
    \(h\_0 = dotQ\/\(\(4\/3\) \[Pi]\ a\^3\) // ToUnit[Watt]\)], "Input"],

Cell["Central temperature excess estimate", "Text"],

Cell[BoxData[
    \(\[CapitalDelta]T = \(\(h\_0\) a\^2\)\/\(6\ k\) // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["30.2.5 Human heat flow", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters;", "Text"],

Cell[BoxData[{
    \(\(dotQ = 100. \ Watt;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1000. \ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(M = 70. \ Kilogram;\)\), "\[IndentingNewLine]", 
    \(\(k = 0.6\ Watt\/\(Kelvin\ Meter\);\)\)}], "Input"],

Cell["Volume", "Text"],

Cell[BoxData[
    \(V = M\/\[Rho]\_0 // ToSI\)], "Input"],

Cell["Average heat production", "Text"],

Cell[BoxData[
    \(h\_0 = dotQ\/V // ToUnit[Kilo\ Watt]\)], "Input"],

Cell["Radius in the spherical approximation", "Text"],

Cell[BoxData[
    \(a = \((\(3\/\(4  \[Pi]\)\) V)\)\^\(1/3\) // ToSI\)], "Input"],

Cell["Average temperature excess", "Text"],

Cell[BoxData[
    \(\[CapitalTheta] = \(\(h\_0\) a\^2\)\/\(15  k\) // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["30.3.1 Cooling hot porridge", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(\[Kappa] = 1.4\ \(10\^\(-7\)\) Meter\^2\/Second;\)\), "\n", 
    \(\(L = 1  Centimeter;\)\), "\[IndentingNewLine]", 
    \(\(U = 10\ Centimeter/Second;\)\)}], "Input"],

Cell["Diffusion time", "Text"],

Cell[BoxData[
    \(t = L\^2\/\(4  \[Kappa]\) // ToSI\)], "Input"],

Cell[BoxData[
    \(t // ToUnit[Minute]\)], "Input"],

Cell["Peclet number", "Text"],

Cell[BoxData[
    \(Pe = \ \(U\ L\)\/\[Kappa] // ToSI\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["30.4.2 Human heat loss", "Section"],

Cell["Parameters for air", "Text"],

Cell[BoxData[{
    \(\(L\_x = 0.5\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(L\_z = 4\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(U = 1  Meter/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = 
        1.6\ 10\^\(-5\)\ Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalTheta] = 10\ Kelvin;\)\), "\[IndentingNewLine]", 
    \(\(k = 0.025\ \(Watt/Kelvin\)/Meter;\)\), "\[IndentingNewLine]", 
    \(\(s = 0.42;\)\)}], "Input"],

Cell["Heat loss", "Text"],

Cell[BoxData[
    \(dotQ = 
      s\ *\ k\ \[CapitalTheta]\ \(L\_z\) \@\(\(2\ U\ L\_x\)\/\[Nu]\)\)], \
"Input"],

Cell["Water parameters", "Text"],

Cell[BoxData[{
    \(\(\[Nu] = 
        8.6\ 10\^\(-7\)\ Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[CapitalTheta] = 10\ Kelvin;\)\), "\[IndentingNewLine]", 
    \(\(k = 0.6\ \(Watt/Kelvin\)/Meter;\)\), "\[IndentingNewLine]", 
    \(\(s = 0.87;\)\)}], "Input"],

Cell[BoxData[
    \(dotQ = 
      s\ *\ k\ \[CapitalTheta]\ \(L\_z\) \@\(\(2\ U\ L\_x\)\/\[Nu]\)\)], \
"Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["30.6 Human heat flow", "Section"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(dotQ = 100. \ Watt;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1000. \ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(M = 70. \ Kilogram;\)\), "\[IndentingNewLine]", 
    \(\(k = 0.6\ Watt\/\(Kelvin\ Meter\);\)\), "\[IndentingNewLine]", 
    \(\(s = 5\ Centimeter;\)\)}], "Input"],

Cell["Volume", "Text"],

Cell[BoxData[
    \(V = M\/\[Rho]\_0 // ToSI\)], "Input"],

Cell["Average heat production", "Text"],

Cell[BoxData[
    \(h\_0 = dotQ\/V // N\)], "Input"],

Cell["Effective radius", "Text"],

Cell[BoxData[
    \(a = \((\(3\/\(4  \[Pi]\)\) V)\)\^\(1/3\) // 
        ToUnit[Centimeter]\)], "Input"],

Cell["Core thickness", "Text"],

Cell[BoxData[
    \(\(c = a - s;\)\)], "Input"],

Cell["Central temperature difference", "Text"],

Cell[BoxData[
    \(\[CapitalTheta] = \(\(h\_0\) \((a\^2 - c\^2)\)\)\/\(6  k\) // 
        ToSI\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell["", "Title"]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
AutoGeneratedPackage->None,
WindowSize->{988, 838},
WindowMargins->{{90, Automatic}, {Automatic, 68}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 53, 1, 95, "Title",
  InitializationCell->True],
Cell[1832, 56, 129, 3, 50, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1998, 64, 31, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[2054, 68, 40, 0, 73, "Section"],
Cell[2097, 70, 51, 1, 30, "Input"],
Cell[2151, 73, 49, 0, 33, "Text"],
Cell[2203, 75, 142, 2, 51, "Input"],
Cell[2348, 79, 52, 0, 33, "Text"],
Cell[2403, 81, 93, 1, 30, "Input"],
Cell[2499, 84, 33, 0, 33, "Text"],
Cell[2535, 86, 314, 6, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2886, 97, 43, 0, 73, "Section"],
Cell[2932, 99, 46, 1, 30, "Input"],
Cell[2981, 102, 37, 0, 33, "Text"],
Cell[3021, 104, 236, 5, 44, "Input"],
Cell[3260, 111, 52, 0, 33, "Text"],
Cell[3315, 113, 180, 4, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3532, 122, 94, 2, 73, "Section"],
Cell[3629, 126, 46, 1, 30, "Input"],
Cell[3678, 129, 38, 0, 33, "Text"],
Cell[3719, 131, 217, 4, 90, "Input"],
Cell[3939, 137, 27, 0, 33, "Text"],
Cell[3969, 139, 56, 1, 30, "Input"],
Cell[4028, 142, 40, 0, 33, "Text"],
Cell[4071, 144, 163, 3, 42, "Input"],
Cell[4237, 149, 416, 7, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4702, 162, 54, 0, 95, "Title"],
Cell[4759, 164, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[4830, 169, 54, 0, 73, "Section"],
Cell[4887, 171, 22, 0, 33, "Text"],
Cell[4912, 173, 45, 1, 30, "Input"],
Cell[4960, 176, 24, 0, 33, "Text"],
Cell[4987, 178, 333, 7, 90, "Input"],
Cell[5323, 187, 30, 0, 33, "Text"],
Cell[5356, 189, 64, 1, 30, "Input"],
Cell[5423, 192, 30, 0, 33, "Text"],
Cell[5456, 194, 203, 4, 88, "Input"],
Cell[5662, 200, 27, 0, 33, "Text"],
Cell[5692, 202, 82, 1, 30, "Input"],
Cell[5777, 205, 82, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5896, 211, 43, 0, 73, "Section"],
Cell[5942, 213, 61, 0, 33, "Text"],
Cell[6006, 215, 108, 2, 30, "Input"],
Cell[6117, 219, 42, 0, 33, "Text"],
Cell[6162, 221, 69, 1, 44, "Input"],
Cell[6234, 224, 26, 0, 33, "Text"],
Cell[6263, 226, 475, 8, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6775, 239, 24, 0, 73, "Section"],
Cell[6802, 241, 47, 0, 33, "Text"],
Cell[6852, 243, 58, 1, 44, "Input"],
Cell[6913, 246, 176, 3, 30, "Input"],
Cell[7092, 251, 175, 3, 30, "Input"],
Cell[7270, 256, 177, 3, 31, "Input"],
Cell[7450, 261, 224, 4, 50, "Input"],
Cell[7677, 267, 30, 0, 33, "Text"],
Cell[7710, 269, 41, 1, 30, "Input"],
Cell[7754, 272, 44, 1, 30, "Input"],
Cell[7801, 275, 41, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7891, 282, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[7941, 286, 46, 0, 73, "Section"],
Cell[7990, 288, 46, 1, 30, "Input"],
Cell[8039, 291, 26, 0, 33, "Text"],
Cell[8068, 293, 305, 5, 138, "Input"],
Cell[8376, 300, 25, 0, 33, "Text"],
Cell[8404, 302, 130, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8571, 310, 45, 0, 73, "Section"],
Cell[8619, 312, 26, 0, 33, "Text"],
Cell[8648, 314, 134, 2, 63, "Input"],
Cell[8785, 318, 35, 0, 33, "Text"],
Cell[8823, 320, 56, 1, 40, "Input"],
Cell[8882, 323, 66, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8985, 329, 34, 0, 73, "Section"],
Cell[9022, 331, 46, 1, 30, "Input"],
Cell[9071, 334, 26, 0, 33, "Text"],
Cell[9100, 336, 126, 2, 66, "Input"],
Cell[9229, 340, 30, 0, 33, "Text"],
Cell[9262, 342, 66, 1, 46, "Input"],
Cell[9331, 345, 50, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9418, 351, 38, 0, 73, "Section"],
Cell[9459, 353, 46, 1, 30, "Input"],
Cell[9508, 356, 26, 0, 33, "Text"],
Cell[9537, 358, 320, 5, 153, "Input"],
Cell[9860, 365, 32, 0, 33, "Text"],
Cell[9895, 367, 71, 1, 44, "Input"],
Cell[9969, 370, 33, 0, 33, "Text"],
Cell[10005, 372, 78, 1, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10120, 378, 52, 0, 73, "Section"],
Cell[10175, 380, 46, 1, 30, "Input"],
Cell[10224, 383, 26, 0, 33, "Text"],
Cell[10253, 385, 187, 3, 70, "Input"],
Cell[10443, 390, 47, 0, 33, "Text"],
Cell[10493, 392, 86, 1, 51, "Input"],
Cell[10582, 395, 51, 0, 33, "Text"],
Cell[10636, 397, 87, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10760, 403, 41, 0, 73, "Section"],
Cell[10804, 405, 46, 1, 30, "Input"],
Cell[10853, 408, 27, 0, 33, "Text"],
Cell[10883, 410, 262, 4, 104, "Input"],
Cell[11148, 416, 22, 0, 33, "Text"],
Cell[11173, 418, 57, 1, 44, "Input"],
Cell[11233, 421, 39, 0, 33, "Text"],
Cell[11275, 423, 69, 1, 42, "Input"],
Cell[11347, 426, 53, 0, 33, "Text"],
Cell[11403, 428, 81, 1, 44, "Input"],
Cell[11487, 431, 42, 0, 33, "Text"],
Cell[11532, 433, 87, 1, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11656, 439, 46, 0, 73, "Section"],
Cell[11705, 441, 46, 1, 30, "Input"],
Cell[11754, 444, 26, 0, 33, "Text"],
Cell[11783, 446, 190, 3, 86, "Input"],
Cell[11976, 451, 30, 0, 33, "Text"],
Cell[12009, 453, 66, 1, 46, "Input"],
Cell[12078, 456, 52, 1, 30, "Input"],
Cell[12133, 459, 29, 0, 33, "Text"],
Cell[12165, 461, 66, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12268, 467, 41, 0, 73, "Section"],
Cell[12312, 469, 34, 0, 33, "Text"],
Cell[12349, 471, 442, 8, 150, "Input"],
Cell[12794, 481, 25, 0, 33, "Text"],
Cell[12822, 483, 111, 3, 51, "Input"],
Cell[12936, 488, 32, 0, 33, "Text"],
Cell[12971, 490, 272, 5, 90, "Input"],
Cell[13246, 497, 111, 3, 51, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13406, 506, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[13456, 510, 39, 0, 73, "Section"],
Cell[13498, 512, 26, 0, 33, "Text"],
Cell[13527, 514, 318, 5, 125, "Input"],
Cell[13848, 521, 22, 0, 33, "Text"],
Cell[13873, 523, 57, 1, 44, "Input"],
Cell[13933, 526, 39, 0, 33, "Text"],
Cell[13975, 528, 52, 1, 42, "Input"],
Cell[14030, 531, 32, 0, 33, "Text"],
Cell[14065, 533, 104, 2, 44, "Input"],
Cell[14172, 537, 30, 0, 33, "Text"],
Cell[14205, 539, 47, 1, 30, "Input"],
Cell[14255, 542, 46, 0, 33, "Text"],
Cell[14304, 544, 108, 2, 46, "Input"]
}, Open  ]]
}, Open  ]],
Cell[14439, 550, 17, 0, 95, "Title"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

