(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42310,       1519]*)
(*NotebookOutlinePosition[     43004,       1543]*)
(*  CellTagsIndexPosition[     42960,       1539]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["32. Turbulence", "Title"],

Cell[BoxData[{
    \(<< Lautrup`\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\), "\[IndentingNewLine]", 
    \(<< Graphics`MultipleListPlot`\), "\[IndentingNewLine]", 
    \(SetOptions[Integrate, GenerateConditions \[Rule] False]\)}], "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Energy spectrum and 5/3 law", "Title"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[CellGroupData[{

Cell["Data extracted from Grant et al (1962)", "Section"],

Cell["\<\
data={{0.1952, -2.0833}, {0.2471, -2.0833}, {0.299, -2.0833}, {0.1952, \
-2.0194}, {0.2731, -2.0194}, 
 {0.1952, -1.8917}, {0.1433, -1.8278}, {0.1433, -1.7639}, {0.1173, -1.6361}, \
{0.1173, -1.5083}, 
 {0.0913, -1.4444}, {-0.0125, -1.3167}, {0.0394, -1.1889}, {0.0135, -1.125}, \
{-0.0277, -0.9659}, 
 {-0.0486, -0.8978}, {-0.0416, -0.8126}, {-0.0832, -0.7445}, {-0.0971, \
-0.6253}, 
 {-0.1318, -0.506}, {-0.1526, -0.3868}, {-0.1873, -0.2846}, {-0.2081, \
-0.1654}, 
 {-0.2289, -0.0973}, {-0.2913, -0.0291}, {-0.2358, -0.0121}, {-0.3121, \
0.0731}, 
 {-0.2428, 0.1412}, {-0.3676, 0.2434}, {-0.4023, 0.3797}, {-0.4301, 0.4478}, \
{-0.4439, 0.567}, 
 {-0.4647, 0.6181}, {-0.5202, 0.7374}, {-0.541, 0.8225}, {-0.5896, 0.9077}, \
{-0.5757, 0.9929}, 
 {-0.6867, 1.078}, {-0.7075, 1.1462}, {-0.7699, 1.2313}, {-0.8462, 1.3335}, \
{-0.8185, 1.4187}, 
 {-0.8532, 1.4868}, {-0.8671, 1.5209}, {-0.8948, 1.589}, {-0.9642, 1.6742}, \
{-1.0266, 1.6912}, 
 {-1.0266, 1.7593}, {-1.089, 1.8445}, {-1.096, 1.8615}, {-1.2327, 1.8778}, \
{-1.0613, 1.9297}, 
 {-1.1029, 1.9467}, {-1.1584, 1.9637}, {-1.1306, 1.9637}, {-1.1653, 2.0659}, \
{-1.2846, 2.0694}, 
 {-1.2587, 2.1333}, {-1.2587, 2.1972}, {-1.4404, 2.2611}, {-1.3625, 2.2611}, \
{-1.3885, 2.325}, 
 {-1.4404, 2.4528}, {-1.4923, 2.5167}, {-1.6221, 2.7722}, {-1.5702, 2.7722}, \
{-1.7779, 2.8361}, 
 {-1.6481, 2.8361}, {-1.6481, 2.9}, {-1.726, 2.9639}, {-1.8298, 3.0278}, \
{-1.8038, 3.0917}, 
 {-1.9337, 3.1556}, {-1.9077, 3.2833}, {-1.9596, 3.3472}, {-2.1154, 3.475}, \
{-2.0115, 3.5389}, 
 {-2.0375, 3.6028}, {-2.1413, 3.7306}, {-2.3231, 3.9222}, {-2.2452, 3.9861}, \
{-2.349, 4.05}, 
 {-2.2192, 4.05}, {-2.375, 4.1139}, {-2.3231, 4.1778}, {-2.375, 4.2417}, \
{-2.4529, 4.3056}, 
 {-2.6346, 4.5611}, {-2.7125, 4.8167}, {-3.05, 5.2639}, {-2.9721, 5.3278}, \
{-3.3875, 5.8389}, 
 {-3.3096, 5.9667}, {-3.6731, 6.0306}, {-3.6471, 6.35}, {-3.9587, 6.6694}, \
{-4.0106, 6.7972}, 
 {-4.2962, 7.3083}};\
\>", "Input"],

Cell[BoxData[
    \(\(fig1a = 
        ListPlot[data, Frame \[Rule] True, Axes \[Rule] False, 
          FrameLabel \[Rule] {\*"\"\<\!\(log\_10\)k\>\"", \
\*"\"\<\!\(log\_10\)E\>\""}];\)\)], "Input"],

Cell[BoxData[{
    \(\(fit = \(-\(5\/3\)\) x;\)\), "\[IndentingNewLine]", 
    \(\(fig1b = Plot[fit, {x, \(-4.5\), 0}];\)\)}], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, 
          fig1b] // \[IndentingNewLine]Figure["\<turbulence1\>"];\)\)], \
"Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wall interpolation function", "Title"],

Cell[CellGroupData[{

Cell["Simple interpolation", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(fp[s_] = 
        1\/\(1 + \((\[Alpha] + \[Beta])\)\ s\^3\) + \(A\ \[Beta]\ s\^3\)\/\(A \
+ \[Beta]\ s\^4\);\)\)], "Input"],

Cell[BoxData[
    \(f[s_] = \[Integral]\_0\%s fp[s] \[DifferentialD]s // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\(f'\)[s] // Apart\)], "Input"],

Cell[BoxData[
    \(Series[f[s], {s, 0, 4}]\)], "Input"],

Cell[BoxData[
    \(B = Limit[f[s] - A\ Log[s], s \[Rule] \[Infinity]] // Expand\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laws of the wall ", "Title"],

Cell[CellGroupData[{

Cell["Data from Kim, Moser, and Mansour", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(Get["\<turbulence.mkm.m\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(data = profiles[\([3]\)];\)\)], "Input"],

Cell[BoxData[
    \(Rey0 = data[\([\(-1\), 1]\)]\)], "Input"],

Cell[BoxData[
    \(\(fig = 
        MultipleListPlot[data, 
          SymbolShape \[Rule] {PlotSymbol[Triangle, 2, Filled \[Rule] False], 
              PlotSymbol[Box, 2, Filled \[Rule] False], 
              PlotSymbol[Diamond, 2, Filled \[Rule] False]}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make low data fit to logarithmic law", "Section"],

Cell[BoxData[
    \(\(lodata = Select[data, #[\([1]\)] < \ 100 &];\)\)], "Input"],

Cell[BoxData[
    \(\(figa = ListPlot[lodata];\)\)], "Input"],

Cell[BoxData[
    \(fit = 
      FindFit[Select[lodata, #[\([1]\)] > 30 &], A\ Log[s] + B, {A, B}, 
        s]\)], "Input"],

Cell[BoxData[
    \(1\/A /. fit\)], "Input"],

Cell[BoxData[
    \(s0 = s /. FindRoot[s \[Equal] A\ Log[s] + B /. fit, {s, 10}]\)], "Input"],

Cell[BoxData[
    \(\(figb = 
        Plot[A\ Log[s] + B /. fit, {s, 1, 110}, 
          PlotStyle \[Rule] Dashing[{0.01}]];\)\)], "Input"],

Cell[BoxData[
    \(\(figc = 
        Plot[s, {s, 0, 17}, PlotStyle \[Rule] Dashing[{0.01}]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make fit to all data", "Section"],

Cell[BoxData[
    \(\(f[s_] = 
        1\/4\ A\ \((\(-Log[A]\) + 
                Log[A + 
                    s\^4\ \[Beta]])\) + \(\@3\ \[Pi] - 6\ \@3\ ArcTan[\(1 - 2\
\ s\ \((\[Alpha] + \[Beta])\)\^\(1/3\)\)\/\@3] + 6\ Log[1 + s\ \((\[Alpha] + \
\[Beta])\)\^\(1/3\)] - 3\ Log[1 - s\ \((\[Alpha] + \[Beta])\)\^\(1/3\) + s\^2\
\ \((\[Alpha] + \[Beta])\)\^\(2/3\)]\)\/\(18\ \((\[Alpha] + \[Beta])\)\^\(1/3\
\)\);\)\)], "Input"],

Cell[BoxData[
    \(ffit = 
      FindFit[lodata, f[s] /. fit, {{\[Alpha], 0.001}, {\[Beta], 0.0001}}, 
          s] \[Union] fit\)], "Input"],

Cell[BoxData[
    \(B \[Rule] \((\ \(2\ \[Pi]\)\/\(3\ \@3\ \((\[Alpha] + \
\[Beta])\)\^\(1/3\)\) - 1\/4\ A\ Log[A] + 1\/4\ A\ Log[\[Beta]] /. 
          ffit)\)\)], "Input"],

Cell[BoxData[
    \(\(figd = Plot[f[s] /. ffit, {s, 0, 100}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[figa, figb, figc, figd, 
          Graphics[{Dashing[{0.001, 0.02}], Line[{{s0, 0}, {s0, 17}}]}], 
          PlotRange \[Rule] {{0, 100}, {0, 17}}, 
          AxesLabel \[Rule] {\*"\"\<y/\!\(\[Delta]\_0\)\>\"", \*"\"\<\!\(v\_x\
\)/\!\(u\_0\)\>\""}] // \[IndentingNewLine]Figure["\<turbulence2\>"];\)\)], \
"Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Logarithmic law of the wall", "Title"],

Cell[CellGroupData[{

Cell["Profile data from Zagarola and Smits", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(Get["\<turbulence.zs.m\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(fdata = Flatten[profiles, 1];\)\)], "Input"],

Cell[BoxData[{
    \(\(pdata = fdata[\([All, {4, 5}]\)];\)\), "\[IndentingNewLine]", 
    \(\(pdata[\([All, 1]\)] = Log[10, fdata[\([All, 4]\)]];\)\)}], "Input"],

Cell[BoxData[
    \(Length[pdata]\)], "Input"],

Cell[BoxData[
    \(\(figa = 
        ListPlot[pdata, PlotStyle \[Rule] PointSize[0.004]];\)\)], "Input"],

Cell[BoxData[
    \(\(data = \(Select[
            fdata, #[\([1]\)] < 0.1 &]\)[\([All, {4, 5}]\)];\)\)], "Input"],

Cell[BoxData[{
    \(\(pdata = data;\)\), "\[IndentingNewLine]", 
    \(\(pdata[\([All, 1]\)] = Log[10, pdata[\([All, 1]\)]];\)\)}], "Input"],

Cell[BoxData[
    \(Length[pdata]\)], "Input"],

Cell[BoxData[
    \(\(figh = 
        ListPlot[pdata, PlotStyle \[Rule] PointSize[0.006]];\)\)], "Input"],

Cell[BoxData[
    \(\(figc = 
        LogLinearPlot[s, {s, 0, 20}, PlotStyle \[Rule] Dashing[{0.012}], 
          PlotPoints \[Rule] 1000];\)\)], "Input"],

Cell[BoxData[
    \(\(figd = 
        Plot[8.7\ 10\^\(0.137  ls\), {ls, 0.3, 5}, 
          PlotStyle \[Rule] Dashing[Dot]];\)\)], "Input"],

Cell[BoxData[
    \(\(f[s_] = 
        1\/4\ A\ \((\(-Log[A]\) + 
                Log[A + 
                    s\^4\ \[Beta]])\) + \(\@3\ \[Pi] - 6\ \@3\ ArcTan[\(1 - 2\
\ s\ \((\[Alpha] + \[Beta])\)\^\(1/3\)\)\/\@3] + 6\ Log[1 + s\ \((\[Alpha] + \
\[Beta])\)\^\(1/3\)] - 3\ Log[1 - s\ \((\[Alpha] + \[Beta])\)\^\(1/3\) + s\^2\
\ \((\[Alpha] + \[Beta])\)\^\(2/3\)]\)\/\(18\ \((\[Alpha] + \[Beta])\)\^\(1/3\
\)\);\)\)], "Input"],

Cell[BoxData[
    \(ffit = 
      FindFit[data, f[s], {{A, 2.2}, {\[Alpha], 0.001}, {\[Beta], 0.001}}, 
        s]\)], "Input"],

Cell[BoxData[
    \(ffit = 
      ffit \[Union] {B -> \(2\ \[Pi]\)\/\(3\ \@3\ \((\[Alpha] + \
\[Beta])\)\^\(1/3\)\) - 1\/4\ A\ Log[A] + 1\/4\ A\ Log[\[Beta]] /. 
            ffit}\)], "Input"],

Cell[BoxData[
    \(\(fige = 
        Plot[f[10\^ls] /. ffit, {ls, 0, 6}, 
          PlotPoints \[Rule] 500];\)\)], "Input"],

Cell[BoxData[
    \(\(figb = 
        LogLinearPlot[A\ Log[s] + B /. ffit, {s, 2, 10\^6}, 
          PlotRange \[Rule] {{1, 10\^6}, {0, 40}}, 
          PlotStyle \[Rule] Dashing[{0.012}]];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fige, figb, figh];\)\)], "Input"],

Cell[BoxData[
    \(s0 = 
      s /. FindRoot[s \[Equal] A\ Log[s] + B /. ffit, {s, 10}]\)], "Input"],

Cell[BoxData[
    \(ls0 = Log[10, s0]\)], "Input"],

Cell[BoxData[
    \(\(ticks = Table[{n, "\<10\>"\^n}, {n, 0, 8}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[figb, figa, figc, figd, fige, 
          Graphics[{Dashing[{0.001, 0.02}], Line[{{ls0, 0}, {ls0, 20}}]}], 
          AxesLabel \[Rule] {\*"\"\<y/\!\(\[Delta]\_0\)\>\"", \*"\"\<\!\(v\_x\
\)/\!\(u\_0\)\>\""}, AxesOrigin \[Rule] {0, 0}, 
          Ticks \[Rule] {ticks, 
              Automatic}] \
// \[IndentingNewLine]Figure["\<turbulence3\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The near-wall region", "Section"],

Cell[BoxData[
    \(\(lim = 100;\)\)], "Input"],

Cell[BoxData[
    \(\(fig1 = 
        ListPlot[data, PlotRange \[Rule] {{0, lim}, {0, 28}}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig2 = Plot[f[s] /. ffit, {s, 0, lim}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig3 = 
        Plot[8.7\ s\^0.137, {s, 0, 500}, 
          PlotStyle \[Rule] Dashing[Dot]];\)\)], "Input"],

Cell[BoxData[
    \(\(fig4 = Plot[s, {s, 0, 15}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1, fig2, fig3, fig4];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wake functions", "Section"],

Cell[BoxData[
    \(\(pdata = profiles[\([All, All, {2, 5}]\)];\)\)], "Input"],

Cell[BoxData[{
    \(\(qdata = \(1\/2\) 
          Rey0s \((1 - pdata[\([All, All, 1]\)]\^2)\);\)\), "\n", 
    \(\(qdata = Map[f[#] /. ffit &, qdata];\)\)}], "Input"],

Cell[BoxData[
    \(\(pdata[\([All, All, 2]\)] -= qdata;\)\)], "Input"],

Cell[BoxData[
    \(\(wdata = Flatten[pdata, 1];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1a = ListPlot[wdata];\)\)], "Input"],

Cell[BoxData[
    \(\(w[r_] = CC \((1 - r\^2)\)\^2;\)\)], "Input"],

Cell[BoxData[
    \(\(w[r_] = CC\ Cos[\(\[Pi]\/2\) r]\^2;\)\)], "Input"],

Cell[BoxData[
    \(fit = 
      FindFit[Select[wdata, #[\([1]\)] < 0.9 &], w[r], {{CC, 1}}, 
        r]\)], "Input"],

Cell[BoxData[
    \(\(fig1b = Plot[w[r] /. fit, {r, \(-1\), 1}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b, 
        AxesLabel \[Rule] {\*"\"\<\!\(r\/a\)\>\"", "\<w\>"}];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Planar Couette flow", "Title"],

Cell[CellGroupData[{

Cell["Data from Schlichting fig. 17.2 b", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(Rey0 = 733;\)\)], "Input"],

Cell["\<\
data={{0.083, -8.5567}, {0.1246, -7.0103}, {0.173, -6.2543}, {0.2353, \
-5.6014}, {0.3183, -4.5704}, 
 {0.3806, -3.8832}, {0.4844, -3.1959}, {0.6298, -2.0619}, {0.7958, -1.134}, \
{1.1557, 0.7216}, 
 {1.3149, 1.7182}, {1.5017, 2.9553}, {1.5779, 3.4708}, {1.654, 4.1581}, \
{1.7509, 5.2577}, 
 {1.8131, 5.8763}, {1.8685, 6.8041}, {1.917, 8.3505}};\
\>", "Input"],

Cell[BoxData[
    \(length = Length[data]\)], "Input"],

Cell[BoxData[{
    \(\(gdata = data;\)\), "\[IndentingNewLine]", 
    \(\(gdata[\([All, 1]\)] /= 2;\)\)}], "Input"],

Cell[BoxData[
    \(\(fig2a = 
        MultipleListPlot[gdata, 
          SymbolShape \[Rule] 
            PlotSymbol[Box, 2, Filled \[Rule] False]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make fit to wake function", "Section"],

Cell[BoxData[
    \(\(w[y] = 0;\)\)], "Input"],

Cell[BoxData[
    \(\(w[y_] = DD\ \(y\^2\) \(\((1 - y)\)\^2\) \((1 - 2  y)\);\)\)], "Input"],

Cell[BoxData[
    \(\(w[y_] = DD\ Sin[2  \[Pi]\ y];\)\)], "Input"],

Cell[BoxData[
    \(\(g[y_] = A\ Log[y\/\(1 - y\)] - \((1 - 2  y)\) CC;\)\)], "Input"],

Cell[BoxData[
    \(\(prefit = {A \[Rule] 2.42};\)\)], "Input"],

Cell[BoxData[
    \(fit = 
      FindFit[Take[gdata, {2, \(-2\)}], 
          g[y] + w[y] /. prefit, {{CC, 0.2}, {DD, 0}}, y] \[Union] 
        prefit\)], "Input"],

Cell[BoxData[
    \(CC + A\ Log[2] /. fit\)], "Input"],

Cell[BoxData[
    \(\(wdata = 
        Map[{#[\([1]\)], #[\([2]\)] - g[#[\([1]\)]] /. fit} &, 
          gdata];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1a = ListPlot[wdata];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = Plot[w[y] /. fit, {y, 0, 1}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make velocity defect plot", "Section"],

Cell[BoxData[
    \(\(fig2b = Plot[g[y] + w[y] /. fit, {y, 0.02, 0.98}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig2a, fig2b, 
          AxesLabel \[Rule] {\*"\"\<\!\(y\/d\)\>\"", \*"\"\<\!\(\(v\_x - \
U/2\)\/u\_0\)\>\""}] // \[IndentingNewLine]Figure["\<turbulence5\>"];\)\)], \
"Input"],

Cell[BoxData[
    \(rms = \@\(Plus @@ Map[\((#[\([2]\)] - \((g[#[\([1]\)]] + w[#[\([1]\)]])\
\) /. fit)\)\^2 &, gdata]\/Length[gdata]\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make velocity plot", "Section"],

Cell[BoxData[{
    \(\(U = 1;\)\), "\[IndentingNewLine]", 
    \(\(d = 1;\)\)}], "Input"],

Cell[BoxData[{
    \(\(\[Delta]1 = d/2;\)\), "\[IndentingNewLine]", 
    \(\(U1 = U/2;\)\)}], "Input"],

Cell[BoxData[
    \(\[Delta]0 = \[Delta]1\/Rey0 // N\)], "Input"],

Cell[BoxData[
    \(30  \[Delta]0\)], "Input"],

Cell[BoxData[
    \(11  \[Delta]0\)], "Input"],

Cell[BoxData[
    \(\(B = 5.5;\)\)], "Input"],

Cell[BoxData[
    \(\[CapitalLambda]1 = A\ Log[Rey0] + B + CC /. fit\)], "Input"],

Cell[BoxData[
    \(\[CapitalLambda] = 2  \[CapitalLambda]1\)], "Input"],

Cell[BoxData[
    \(Rey = 4  \[CapitalLambda]1\ Rey0\)], "Input"],

Cell[BoxData[
    \(u0 = U1\/\[CapitalLambda]1\)], "Input"],

Cell[BoxData[
    \(\(vdata = gdata;\)\)], "Input"],

Cell[BoxData[
    \(vdata[\([All, 2]\)] = U1 + u0*gdata[\([All, 2]\)]\)], "Input"],

Cell[BoxData[
    \(\(fig5a = 
        MultipleListPlot[vdata, 
          SymbolShape \[Rule] 
            PlotSymbol[Box, 2, Filled \[Rule] False]];\)\)], "Input"],

Cell[BoxData[
    \(\(v[y_] = U1 + u0\ \((g[y] + w[y])\) /. fit\ ;\)\)], "Input"],

Cell[BoxData[
    \(\(fig5b = 
        Plot[{v[y], y, 0.5}, {y, 0.01, 0.99}, 
          PlotStyle \[Rule] {Dashing[{}], Dashing[{0.02}], 
              Dashing[{0.01}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig5d = 
        Plot[u0\ y/\[Delta]0, {y, 0, 11  \[Delta]0}, 
          PlotStyle \[Rule] Dashing[{0.011}]];\)\)], "Input"],

Cell[BoxData[
    \(\(fig5e = 
        Plot[1 - u0\ \((1 - y)\)/\[Delta]0, {y, d, d - 11  \[Delta]0}, 
          PlotStyle \[Rule] Dashing[{0.011}]];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Show[fig5a, fig5b, fig5d, fig5e, Frame \[Rule] True, 
          PlotRange \[Rule] {0, 1}, 
          FrameLabel \[Rule] {"\<y/d\>", \*"\"\<\!\(v\_x\)/U\>\""}]\), Cell[
        ""]}], ";"}]], "Input"],

Cell[BoxData[
    \(rms = \@\(Plus @@ Map[\((#[\([2]\)] - v[#[\([1]\)]])\)\^2 &, \
vdata]\/Length[vdata]\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Planar Poiseuille flow", "Title"],

Cell[CellGroupData[{

Cell["Data from Moser, Kim, and Mansour", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(Get["\<turbulence.MKM.m\>"];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Global data", "Subsection"],

Cell[BoxData[
    \(Rey0 = Rey0s[\([3]\)]\)], "Input"],

Cell[BoxData[{
    \(\(U = 1;\)\), "\[IndentingNewLine]", 
    \(\(d = 1;\)\)}], "Input"],

Cell[BoxData[
    \(\(\[Delta]1 = d/2;\)\)], "Input"],

Cell[BoxData[
    \(\[Delta]0 = \[Delta]1\/Rey0 // N\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Profile data", "Subsection"],

Cell[BoxData[
    \(\(data = profiles[\([3]\)];\)\)], "Input"],

Cell[BoxData[
    \(max = data[\([\(-1\), 2]\)]\)], "Input"],

Cell[BoxData[{
    \(\(fdata = data;\)\), "\n", 
    \(\(fdata[\([All, 1]\)] /= 2  Rey0;\)\)}], "Input"],

Cell[BoxData[{
    \(\(gfitdata = 
        Select[data, #[\([1]\)] > 100 &];\)\), "\[IndentingNewLine]", 
    \(\(gfitdata[\([All, 1]\)] /= 2  Rey0;\)\), "\[IndentingNewLine]", 
    \(\(gfitdata[\([All, 2]\)] -= max;\)\)}], "Input"],

Cell[BoxData[{
    \(\(gdata = fdata;\)\), "\n", 
    \(\(gdata[\([All, 2]\)] = fdata[\([All, 2]\)] - max;\)\)}], "Input"],

Cell[BoxData[
    \(\(fig1a = ListPlot[gdata];\)\)], "Input"],

Cell[BoxData[
    \(\(w[y_] = CC\ Sin[\[Pi]\ y]\^2;\)\)], "Input"],

Cell[BoxData[
    \(\(g[y_] = A\ Log[4  y \((1 - y)\)] - CC;\)\)], "Input"],

Cell[BoxData[
    \(fit = FindFit[gfitdata, g[y] + w[y], {{A, 2}, {CC, 2}}, y]\)], "Input"],

Cell[BoxData[
    \(\(fig1b = Plot[g[y] + w[y] /. fit, {y, 0, 0.5}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b];\)\)], "Input"],

Cell[BoxData[
    \(\(wdata = 
        Map[{#[\([1]\)], #[\([2]\)] - g[#[\([1]\)]] /. fit} &, 
          Drop[gdata, 1]];\)\)], "Input"],

Cell[BoxData[
    \(\(wdata1 = wdata;\)\)], "Input"],

Cell[BoxData[
    \(\(fig2a = 
        ListPlot[wdata, PlotRange \[Rule] {\(-0.5\), 2.2}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig2b = Plot[w[s] /. fit, {s, 0, 0.5}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig2a, fig2b];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Use fit to wall data", "Section"],

Cell[BoxData[
    \(ffit = {A \[Rule] 2.42, \[Alpha] \[Rule] 9.92*^-4, \[Beta] \[Rule] 
          4.02*^-4}; \[AliasDelimiter]\)], "Input"],

Cell[BoxData[
    \(\(ff[s_] = 
        1\/4\ A\ \((\(-Log[A]\) + 
                Log[A + 
                    s\^4\ \[Beta]])\) + \(1\/\(18\ \((\[Alpha] + \[Beta])\)\^\
\(1/3\)\)\) \((\@3\ \[Pi] - 
                6\ \@3\ ArcTan[\(1 - 2\ s\ \((\[Alpha] + \
\[Beta])\)\^\(1/3\)\)\/\@3] + 
                6\ Log[1 + s\ \((\[Alpha] + \[Beta])\)\^\(1/3\)] - 
                3\ Log[1 - s\ \((\[Alpha] + \[Beta])\)\^\(1/3\) + 
                      s\^2\ \((\[Alpha] + \[Beta])\)\^\(2/3\)])\);\)\)], \
"Input"],

Cell[BoxData[
    \(\(v[y_] = 
        ff[\ 2  Rey0\ y] + ff[2  Rey0 \((1 - y)\)] - 
          ff[2  Rey0];\)\)], "Input"],

Cell[BoxData[
    \(\(v[y_] = ff[2  Rey0\ y \((1 - y)\)];\)\)], "Input"],

Cell[BoxData[
    \(ffit = 
      ffit \[Union] {B -> \(2\ \[Pi]\)\/\(3\ \@3\ \((\[Alpha] + \
\[Beta])\)\^\(1/3\)\) - 1\/4\ A\ Log[A] + 1\/4\ A\ Log[\[Beta]] /. 
            ffit}\)], "Input"],

Cell[BoxData[
    \(ffit = AppendTo[ffit, CC \[Rule] \((max - v[0.5] /. ffit)\)]\)], "Input"],

Cell[BoxData[
    \(\(wdata = 
        Map[{#[\([1]\)], #[\([2]\)] - v[#[\([1]\)]] /. ffit} &, 
          fdata];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1a = 
        MultipleListPlot[wdata, 
          SymbolShape \[Rule] 
            PlotSymbol[Box, 1.5, Filled \[Rule] False]];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = Plot[w[y] /. ffit, {y, 0, 1}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b, FrameLabel \[Rule] {"\<y/d\>", "\<w\>"}, 
          Frame \[Rule] 
            True] // \[IndentingNewLine]Figure["\<turbulence13\>"];\)\)], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make velocity plot", "Section"],

Cell[BoxData[
    \(\[CapitalLambda]1 = 
      A\ Log[Rey0] + B - A\ Log[2] + CC /. ffit\)], "Input"],

Cell[BoxData[
    \(\(h[s_] = ff[2  Rey0\ s \((1 - s)\)] + w[s];\)\)], "Input"],

Cell[BoxData[
    \(\[CapitalLambda] = NIntegrate[h[s] /. ffit, {s, 0, 1}]\)], "Input"],

Cell[BoxData[
    \(Rey = 2\ \[CapitalLambda]\ Rey0\)], "Input"],

Cell[BoxData[
    \(\(f1[s_] = A\ Log[s] + B;\)\)], "Input"],

Cell[BoxData[
    \(\(hh[s_] = f1[2  R\ s \((1 - s)\)] + w[s];\)\)], "Input"],

Cell[BoxData[
    \(\[CapitalLambda]a = \[Integral]\_0\%1 hh[s] \[DifferentialD]s // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\[CapitalLambda]A = \(\[CapitalLambda]a /. ffit\) /. 
        R \[Rule] Rey0\)], "Input"],

Cell[BoxData[
    \(1 - \[CapitalLambda]A\/\[CapitalLambda]\)], "Input"],

Cell[BoxData[
    \(\(udata = fdata;\)\)], "Input"],

Cell[BoxData[
    \(\(udata[\([All, 1]\)] = \ fdata[\([All, 1]\)];\)\)], "Input"],

Cell[BoxData[
    \(\(udata[\([All, 2]\)] = \(1\/\[CapitalLambda]\) 
          fdata[\([All, 2]\)];\)\)], "Input"],

Cell[BoxData[
    \(\(fig7a = 
        MultipleListPlot[Take[udata, {1, \(-1\)}], 
          SymbolShape \[Rule] 
            PlotSymbol[Box, 1.5, Filled \[Rule] False]];\)\)], "Input"],

Cell[BoxData[
    \(\(u[y_] = 1\/\[CapitalLambda]\ \((v[y] + w[y])\) /. ffit;\)\)], "Input"],

Cell[BoxData[
    \(\(fig7b = Plot[u[y], {y, 0, 1}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig7c = 
        Plot[{6  y \((1 - y)\), 1}, {y, 0, 1}, 
          PlotStyle \[Rule] {Dashing[{0.02}], 
              Dashing[{0.003, 0.03}]}];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Show[fig7a, fig7b, fig7c, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<y/d\>", \*"\"\<\!\(v\_x\)/U\>\""}]\), "//", 
        "\[IndentingNewLine]", Cell["Figure[\"turbulence7\"]"]}], 
      ";"}]], "Input"],

Cell[BoxData[
    \(rms = \@\(Plus @@ Map[\((#[\([2]\)] - u[#[\([1]\)]])\)\^2 &, \
udata]\/Length[udata]\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pipe flow profile at Rey=31,000", "Title"],

Cell[CellGroupData[{

Cell["Data from Zagarola and Smits", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(\(Get["\<turbulence.zs.m\>"];\)\)], "Input"],

Cell[BoxData[
    \({Rey, Rey0, Umax, Uave, u0, \[Delta]0} = 
      Map[First, {Reys, Rey0s, Umaxs, Uaves, u0s, \[Delta]0s}]\)], "Input"],

Cell[BoxData[
    \(\[Delta]\)], "Input"],

Cell[BoxData[
    \(\(profile = profiles[\([1]\)];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wake function", "Section"],

Cell[BoxData[
    \(\(ffit = {A \[Rule] 2.29303, 
          B \[Rule] 6.13542, \[Alpha] \[Rule] \(-0.0188508\), \[Beta] \[Rule] 
            0.0214328};\)\)], "Input"],

Cell[BoxData[
    \(f[s_] = 
      1\/4\ A\ \((\(-Log[A]\) + 
                Log[A + 
                    s\^4\ \[Beta]])\) + \(\@3\ \[Pi] - 6\ \@3\ ArcTan[\(1 - 2\
\ s\ \((\[Alpha] + \[Beta])\)\^\(1/3\)\)\/\@3] + 6\ Log[1 + s\ \((\[Alpha] + \
\[Beta])\)\^\(1/3\)] - 3\ Log[1 - s\ \((\[Alpha] + \[Beta])\)\^\(1/3\) + s\^2\
\ \((\[Alpha] + \[Beta])\)\^\(2/3\)]\)\/\(18\ \((\[Alpha] + \[Beta])\)\^\(1/3\
\)\) /. ffit\)], "Input"],

Cell[BoxData[
    \(\(pdata = profile[\([All, {2, 5}]\)];\)\)], "Input"],

Cell[BoxData[{
    \(\(qdata = \(1\/2\) Rey0 \((1 - pdata[\([All, 1]\)]\^2)\);\)\), "\n", 
    \(\(qdata = Map[f[#] &, qdata];\)\)}], "Input"],

Cell[BoxData[
    \(\(wdata = pdata;\)\)], "Input"],

Cell[BoxData[
    \(\(wdata[\([All, 2]\)] -= qdata;\)\)], "Input"],

Cell[BoxData[
    \(\(fig1a = 
        MultipleListPlot[wdata, 
          SymbolShape \[Rule] 
            PlotSymbol[Box, 1.5, Filled \[Rule] False]];\)\)], "Input"],

Cell[BoxData[
    \(\(w[r_] = CC \((1 - r\^2)\)\^2;\)\)], "Input"],

Cell[BoxData[
    \(\(w[r_] = CC\ Cos[\(\[Pi]\/2\) r]\^2;\)\)], "Input"],

Cell[BoxData[
    \(fit = 
      FindFit[Select[wdata, #[\([1]\)] < 0.9 &], w[r], {{CC, 1}}, r] \[Union] 
        ffit\)], "Input"],

Cell[BoxData[
    \(\(fig1b = Plot[w[r] /. fit, {r, \(-1\), 1}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1a, fig1b, 
          AxesLabel \[Rule] {\*"\"\<\!\(r\/a\)\>\"", "\<w\>"}] \
// \[IndentingNewLine]Figure["\<turbulence10\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Velocity profile", "Section"],

Cell[BoxData[
    \(\[CapitalLambda] = 
      NIntegrate[
        2  r \((f[\(1\/2\) Rey0 \((1 - r\^2)\)] + w[r] /. fit)\), {r, 0, 
          1}]\)], "Input"],

Cell[BoxData[
    \(\[CapitalLambda]a = \[Integral]\_0\%1\((A\ Log[\(1\/2\) 
                    R0 \((1 - r\^2)\)] + B + w[r])\) 2  
          r \[DifferentialD]r\)], "Input"],

Cell[BoxData[
    \(\[CapitalLambda]A = \(\[CapitalLambda]a /. 
          fit\) /. {R0 \[Rule] Rey0}\)], "Input"],

Cell[BoxData[
    \(1 - \[CapitalLambda]A\/\[CapitalLambda]\)], "Input"],

Cell[BoxData[
    \(EE = \[CapitalLambda] - A\ Log[Rey0] /. fit\)], "Input"],

Cell[BoxData[
    \(\(vdata = pdata;\)\)], "Input"],

Cell[BoxData[
    \(\(vdata[\([All, 2]\)] /= \[CapitalLambda];\)\)], "Input"],

Cell[BoxData[
    \(\(fig2a = 
        MultipleListPlot[vdata, 
          SymbolShape \[Rule] 
            PlotSymbol[Box, 1.5, Filled \[Rule] False]];\)\)], "Input"],

Cell[BoxData[
    \(\(v[
          r_] = \(1\/\[CapitalLambda]\) \((f[\(Rey0\/2\) \((1 - r\^2)\)] + 
                w[r])\) /. fit;\)\)], "Input"],

Cell[BoxData[
    \(\(fig2b = 
        Plot[{v[r], 1, 2 \((1 - r\^2)\)}, {r, \(-1\), 1}, 
          PlotStyle \[Rule] {Dashing[{}], Dashing[{0.01}], 
              Dashing[{0.02}]}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig2a, fig2b, Frame \[Rule] True, 
          FrameLabel \[Rule] {"\<r/a\>", \*"\"\<\!\(v\_x\)/U\>\""}] \
// \[IndentingNewLine]Figure["\<turbulence8\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Friction coefficient for pipe flow", "Title"],

Cell[CellGroupData[{

Cell["Data Schlichting fig. 1.4 p 11", "Section"],

Cell[BoxData[
    \(\(lodata = {{6.4707, \(-2.6016\)}, {6.4406, \(-2.6046\)}, {6.4165, \
\(-2.5802\)}, {6.3744, \(-2.5863\)}, {6.3143, \(-2.5833\)}, {6.2962, \
\(-2.5741\)}, {6.2722, \(-2.5711\)}, {6.206, \(-2.5741\)}, {6.188, \
\(-2.5589\)}, {6.1459, \(-2.5528\)}, {6.0857, \(-2.5345\)}, {6.0015, \
\(-2.5284\)}, {5.9534, \(-2.5193\)}, {5.8872, \(-2.5101\)}, {5.8331, \
\(-2.4949\)}, {5.791, \(-2.4979\)}, {5.7489, \(-2.4766\)}, {5.6827, \(-2.4797\
\)}, {5.6226, \(-2.4644\)}, {5.5985, \(-2.4583\)}, {5.5624, \(-2.4766\)}, \
{5.4902, \(-2.4461\)}, {5.4602, \(-2.4248\)}, {5.4421, \(-2.44\)}, {5.4, \
\(-2.4279\)}, {5.3519, \(-2.4218\)}, {5.2677, \(-2.4065\)}, {5.2797, \
\(-2.3943\)}, {5.2797, \(-2.373\)}, {5.2376, \(-2.3822\)}, {5.2075, \(-2.3852\
\)}, {5.1714, \(-2.37\)}, {5.1113, \(-2.373\)}, {5.1113, \(-2.3547\)}, \
{5.0692, \(-2.3456\)}, {5.0391, \(-2.3456\)}, {4.9789, \(-2.3456\)}, {4.9429, \
\(-2.3212\)}, {4.9068, \(-2.3182\)}, {4.8586, \(-2.2968\)}, {4.7564, \
\(-2.2846\)}, {4.7323, \(-2.2755\)}, {4.7083, \(-2.2725\)}, {4.6421, \(-2.242\
\)}, {4.618, \(-2.2572\)}, {4.5759, \(-2.2267\)}, {4.5398, \(-2.245\)}, \
{4.4797, \(-2.2237\)}, {4.4677, \(-2.1932\)}, {4.4316, \(-2.1871\)}, {4.4316, \
\(-2.2115\)}, {4.4075, \(-2.2085\)}, {4.3714, \(-2.1932\)}, {4.3113, \
\(-2.1688\)}, {4.2752, \(-2.1871\)}, {4.2692, \(-2.1719\)}, {4.215, \(-2.1536\
\)}, {4.1789, \(-2.1384\)}, {4.1729, \(-2.1506\)}, {4.1248, \(-2.1475\)}, \
{4.0647, \(-2.117\)}, {4.0105, \(-2.0896\)}, {3.8902, \(-2.0896\)}, {3.9023, \
\(-2.0805\)}, {3.8541, \(-2.0561\)}, {3.8301, \(-2.0866\)}, {3.7699, \
\(-2.0409\)}, {3.7519, \(-2.0622\)}, {3.7098, \(-2.0195\)}, {3.6917, \
\(-2.0561\)}, {3.6737, \(-2.0104\)}, {3.6436, \(-2.0012\)}, {3.5895, \
\(-1.9738\)}, {3.5774, \(-2.0104\)}, {3.5654, \(-1.983\)}, {3.5173, \(-1.9799\
\)}, {3.4932, \(-1.9677\)}, {3.5053, \(-2.0226\)}, {3.4932, \(-2.0439\)}, \
{3.4812, \(-2.0866\)}, {3.4451, \(-2.0683\)}, {3.4331, \(-2.0866\)}, {3.415, \
\(-2.0957\)}, {3.4211, \(-2.117\)}, {3.385, \(-2.117\)}, {3.3549, \
\(-2.1292\)}, {3.3188, \(-2.0957\)}, {3.3188, \(-2.0835\)}, {3.2947, \
\(-2.0652\)}, {3.2647, \(-2.0713\)}, {3.2647, \(-2.0317\)}, {3.2526, \
\(-2.0195\)}, {3.1624, \(-1.9738\)}, {3.1624, \(-1.9281\)}, {3.0662, \
\(-1.8458\)}, {3.0421, \(-1.8245\)}};\)\)], "Input"],

Cell[BoxData[
    \(\(figlo = ListPlot[lodata];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data from Zagarola and Smits", "Section"],

Cell[BoxData[
    \(\(Get["\<turbulence.zs.m\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(hidata = MapThread[Log[10, {#1, #2}] &, {Reys, Cfs}];\)\)], "Input"],

Cell[BoxData[
    \(\(fighi = ListPlot[hidata];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make Plot", "Section"],

Cell[BoxData[
    \(\(figa = 
        MultipleListPlot[lodata, hidata, 
          SymbolShape \[Rule] {PlotSymbol[Triangle, 2, Filled \[Rule] False], 
              PlotSymbol[Box, 2, Filled \[Rule] False]}];\)\)], "Input"],

Cell[BoxData[{
    \(\(A = 2.29;\)\), "\[IndentingNewLine]", 
    \(\(EE = 3.03;\)\)}], "Input"],

Cell[BoxData[{
    \(\(rey[R_] = 2  R \((A\ Log[R] + EE)\);\)\), "\[IndentingNewLine]", 
    \(\(Cf[R_] = 2\/\((A\ Log[R] + EE)\)\^2;\)\)}], "Input"],

Cell[BoxData[{
    \(\(LRey[R_] = Log[10, rey[R]];\)\), "\[IndentingNewLine]", 
    \(\(LCf[R_] = Log[10, Cf[R]];\)\)}], "Input"],

Cell[BoxData[
    \(\(figb = 
        ParametricPlot[{LRey[10\^LR], LCf[10\^LR]}, {LR, 1.9, 
            6}];\)\)], "Input"],

Cell[BoxData[
    \(\(figc = 
        Plot[Log[10, 0.079\ 10\^\(\(-LR\)/4\)], {LR, 3.5, 7}, 
          PlotStyle \[Rule] Dashing[{0.02}]];\)\)], "Input"],

Cell[BoxData[
    \(\(figd = LogLogPlot[0.001, {R, 10\^3, 10\^8}];\)\)], "Input"],

Cell[BoxData[
    \(\(fige = Plot[Log[10, 16\ 10\^\(-\ LR\)], {LR, 3, 3.5}];\)\)], "Input"],

Cell[BoxData[
    \(\(ls0 = 5.9;\)\)], "Input"],

Cell[BoxData[
    \(s0 = 10\^ls0\)], "Input"],

Cell[BoxData[
    \(\(xticks = Table[{n, "\<10\>"\^n}, {n, 0, 10}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[figd, figa, figb, figc, fige, 
          PlotRange \[Rule] {\(-2.9\), \(-1.7\)}, 
          AxesOrigin \[Rule] {2.9, \(-2.9\)}, 
          AxesLabel \[Rule] {"\<Re\>", \*"\"\<\!\(C\_f\)\>\""}, 
          Ticks \[Rule] {xticks, 
              Automatic}] \
// \[IndentingNewLine]Figure["\<turbulence9\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simple approximation", "Section"],

Cell[BoxData[
    \(Clear[a, b]\)], "Input"],

Cell[BoxData[
    \(fit = 
      FindFit[Select[lodata, #[\([1]\)] > 4 &] \[Union] \ hidata, 
        Log[10, a\/\((s\ Log[10] - b)\)\^2], {a, b}, s]\)], "Input"],

Cell[BoxData[
    \(\(figg = 
        Plot[Log[10, a\/\((s\ Log[10] - b)\)\^2 /. fit], {s, 3, 8}, 
          PlotStyle \[Rule] Dashing[{0.01}]];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[figa, figb, figg];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uniform Turbulent Boundary Layer", "Title"],

Cell[CellGroupData[{

Cell["Determine the relation", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(f[s_] := A\ Log[s] + B;\)\), "\[IndentingNewLine]", 
    \(\(g[s_] := A\ Log[s];\)\)}], "Input"],

Cell[BoxData[
    \(rhs = \(-\(\(\(\ \)\(u0\)\)\/U\)\)\ \ R \(\[Integral]\_0\%1 g[s] 
            f[R\ s] \[DifferentialD]s\)\)], "Input"],

Cell[BoxData[
    \(\(u0 = U\/f[R];\)\)], "Input"],

Cell[BoxData[
    \(rate = \(U\^2\/u0\^2\) \[PartialD]\_R\((rhs)\) // Simplify\)], "Input"],

Cell[BoxData[
    \(rate /. Log[R] \[Rule] \(ff - B\)\/A // Expand\)], "Input"],

Cell[BoxData[
    \(Reyx = \[Integral]rate\ \[DifferentialD]R // Simplify\)], "Input"],

Cell[BoxData[
    \(Reyx /. Log[R] \[Rule] \(ff - B\)\/A // Expand\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The friction coefficient", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(A = 2.44;\)\), "\[IndentingNewLine]", 
    \(\(B = 5.7;\)\), "\[IndentingNewLine]", 
    \(\(CC = 0;\)\)}], "Input"],

Cell[BoxData[
    \(\(Log10 = Log[10];\)\)], "Input"],

Cell[BoxData[
    \(\(f[s_] = A\ Log[s] + B;\)\)], "Input"],

Cell[BoxData[
    \(Rey0[LReyx_] := \[ExponentialE]\^LR /. 
        FindRoot[
          Log[A\ R \((f[R]\^2 - 4  A\ f[R] + 6  A\^2)\) /. 
                R \[Rule] \[ExponentialE]\^LR] \[Equal] LReyx, {LR, 
            1}]\)], "Input"],

Cell[BoxData[
    \(\(CfTurb[LReyx_?NumericQ] := 
        2\/\((f[Rey0[LReyx]] + CC)\)\^2;\)\)], "Input"],

Cell[BoxData[
    \(\(Rey1 = 10\^4;\)\)], "Input"],

Cell[BoxData[
    \(LRey1 = Log[Rey1] // N\)], "Input"],

Cell[BoxData[
    \(x1 = LRey1\/Log10\)], "Input"],

Cell[BoxData[
    \(\(Reyc = 5\ 10\^5;\)\)], "Input"],

Cell[BoxData[
    \(LReyc = Log[Reyc] // N\)], "Input"],

Cell[BoxData[
    \(xc = LReyc\/Log10\)], "Input"],

Cell[BoxData[
    \(\(CfLam[LRey_] = 0.665\ \[ExponentialE]\^\(\(-LRey\)/2\);\)\)], "Input"],

Cell[BoxData[
    \(\(Cf[LRey_] = If[LRey < LReyc, CfLam[LRey], CfTurb[LRey]];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1a = Plot[Log[10, Cf[x\ Log10]], {x\ , 4, 11.5}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1b = 
        Plot[Log[10, 0.027] - x\/7, {x, 5, 10.5}, 
          PlotStyle \[Rule] Dashing[{0.005, 0.02}]];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1c = 
        Plot[Log[10, CfLam[x\ Log10]], {x, x1, xc}, 
          PlotStyle \[Rule] Dashing[{0.005, 0.02}]];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1d = 
        Plot[Log[10, 0.455\/\((x\ Log10\  - 2.81)\)\^2], {x, 5, 11.5}, 
          PlotStyle \[Rule] Dashing[{0.01, 0.01}]];\)\)], "Input"],

Cell[BoxData[
    \(\(xticks = Table[{10\^n, "\<10\>"\^n}, {n, 0, 15}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig1e = 
        LogLogPlot[x, {x, 10\^4, 10\^12}, 
          PlotRange \[Rule] {{10\^4, 3\ 10\^11}, {0.0007, 0.007}}, 
          Ticks \[Rule] {xticks, Automatic}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig1e, fig1a, fig1b, fig1c, fig1d, 
          AxesLabel \[Rule] {\*"\"\<\!\(Re\_x\)\>\"", \
\*"\"\<\!\(C\_f\)\>\""}] \
// \[IndentingNewLine]Figure["\<turbulence12\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The thickness", "Section"],

Cell[BoxData[
    \(Rey\[Delta]Lam[LRey_] := 5  \[ExponentialE]\^\(LRey/2\)\)], "Input"],

Cell[BoxData[
    \(Rey\[Delta]Turb[LRey_] := 
      Rey0[LRey] \((f[Rey0[LRey]] + CC)\)\)], "Input"],

Cell[BoxData[
    \(Rey\[Delta][LRey_] := 
      If[LRey < LReyc, Rey\[Delta]Lam[LRey], 
        Rey\[Delta]Turb[LRey]]\)], "Input"],

Cell[BoxData[
    \(\(fig2a = 
        Plot[Log[10, Rey\[Delta][x\ Log10]], {x\ , x1, 11.5}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plate drag data from Schlichting fig. 1.3, p. 10", "Section"],

Cell["\<\
data={{8.6386, -2.4493}, {8.4651, -2.4237}, {8.3783, -2.4043}, {8.2771, \
-2.3916}, {8.147, -2.379}, 
 {7.9735, -2.3733}, {7.8867, -2.3473}, {7.7711, -2.3281}, {7.6843, -2.3153}, \
{7.6699, -2.3485}, 
 {7.6843, -2.3153}, {7.5976, -2.2959}, {7.4819, -2.2898}, {7.4241, -2.3166}, \
{7.3229, -2.3039}, 
 {7.3229, -2.2642}, {7.2506, -2.2513}, {7.1494, -2.2916}, {7.106, -2.2587}, \
{6.9904, -2.2527}, 
 {6.8892, -2.1804}, {6.759, -2.2341}, {7.1349, -2.2255}, {6.7301, -2.1746}, \
{6.6723, -2.1352}, 
 {6.6434, -2.2148}, {6.5566, -2.2153}, {6.4699, -2.1495}, {6.253, -2.2036}, \
{5.9783, -2.2581}, 
 {6.2241, -2.0978}, {6.2964, -2.0842}, {6.1229, -2.105}, {6.094, -2.0853}, \
{6.1084, -2.0388}, 
 {6.0651, -2.0192}, {5.9639, -2.0992}, {5.9783, -2.0594}, {5.8337, -1.9873}, \
{5.6458, -2.0016}, 
 {5.588, -1.9621}, {5.5157, -1.9691}, {5.4867, -1.9428}, {5.4289, -1.9497}, \
{5.5157, -2.3069}, 
 {5.1687, -2.1432}, {4.9952, -2.0712}, {4.6482, -1.8943}, {4.359, -1.7435}, \
{4.1566, -1.6386}, 
 {3.9831, -1.56}};\
\>", "Input"],

Cell[BoxData[
    \(\(fig3a = ListPlot[data];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plate drag theory", "Section"],

Cell[BoxData[
    \(\(CDLam[LRey_] = 2.6565  \[ExponentialE]\^\(\(-LRey\)/2\);\)\)], "Input"],

Cell[BoxData[
    \(\(fig3b = Plot[Log[10, CDLam[x\ Log10]], {x, x1, xc}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig3a, fig3b];\)\)], "Input"],

Cell[BoxData[
    \(F = 
      G /. NDSolve[{\(G'\)[x] \[Equal] \ 2  Cf[x] Exp[x], 
              G[LRey1] \[Equal] Rey1\ CDLam[LRey1]}, 
            G, {x, LRey1, 12  Log10}] // First\)], "Input"],

Cell[BoxData[
    \(\(CD[LRey_] = \ \(\[ExponentialE]\^\(-LRey\)\) F[LRey];\)\)], "Input"],

Cell[BoxData[
    \(\(fig3c = Plot[Log[10, CD[x\ Log10]], {x, 4, 10}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig3d = 
        Plot[Log[10, 1.046\/\(\(\((x*Log10 - 2.81)\)\^2\)\(\ \)\)], {x, 5.2, 
            10}, PlotStyle \[Rule] Dashing[{0.02, 0.02}]];\)\)], "Input"],

Cell[BoxData[
    \(\(xticks = Table[{10\^n, "\<10\>"\^n}, {n, 0, 15}];\)\)], "Input"],

Cell[BoxData[
    \(\(fig3e = 
        LogLogPlot[Rey, {Rey, Reyc, 10\^12}, 
          PlotRange \[Rule] {{10\^4, 10\^10}, {0.002, 0.02}}, 
          PlotStyle \[Rule] Dashing[{0.01}], 
          Ticks \[Rule] {xticks, Automatic}];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[fig3e, fig3a, fig3c, fig3d, 
          AxesLabel \[Rule] {"\<Re\>", \*"\"\<\!\(C\_D\)\>\""}] \
// \[IndentingNewLine]Figure["\<turbulence11\>"];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Title"],

Cell[CellGroupData[{

Cell["32.1.1 Pipe flow dissipation", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(a = 0.5\ Meter;\)\), "\[IndentingNewLine]", 
    \(\(Q = 10. \ Meter\^3/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Nu] = \(10\^\(-6\)\) Meter\^2/Second;\)\), "\[IndentingNewLine]", 
    \(\(\[Rho]\_0 = 1000\ Kilogram/Meter\^3;\)\), "\[IndentingNewLine]", 
    \(\(C\_f = 0.005;\)\)}], "Input"],

Cell["Maximal eddy size", "Text"],

Cell[BoxData[
    \(\(L = 2\ a;\)\)], "Input"],

Cell["Average velocity", "Text"],

Cell[BoxData[
    \(U = Q\/\(\[Pi]\ a\^2\) // ToSI\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Rey = \ \(2\ a\ U\)\/\[Nu] // ToSI\)], "Input"],

Cell["Specific rate of dissipation", "Text"],

Cell[BoxData[
    \(\[Epsilon] = C\_f\ U\^3\/a // ToUnit[Watt/Kilogram]\)], "Input"],

Cell["Dissipation per unit of pipe length", "Text"],

Cell[BoxData[
    \(\(\[Rho]\_0\) \[Pi]\ \(a\^2\) \[Epsilon] // 
      ToUnit[Kilo\ Watt]\)], "Input"],

Cell["Friction factor", "Text"],

Cell[BoxData[
    \(f = \(C\_f\) Rey\/16\)], "Input"],

Cell[CellGroupData[{

Cell["Dissipation scales", "Subsection"],

Cell["Length scale", "Text"],

Cell[BoxData[
    \(\[Lambda]\_d = \(\[Epsilon]\^\(\(-1\)/4\)\) \[Nu]\^\(3/4\) // 
        ToUnit[Micrometer]\)], "Input"],

Cell["Time scale", "Text"],

Cell[BoxData[
    \(\[Tau]\_d = \(\[Epsilon]\^\(\(-1\)/2\)\) \[Nu]\^\(1/2\) // 
        ToUnit[Microsecond]\)], "Input"],

Cell["Velocity scale", "Text"],

Cell[BoxData[
    \(u\_d = \((\[Epsilon]\ \[Nu])\)\^\(1/4\) // 
        ToUnit[Centimeter]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integral scales", "Subsection"],

Cell["Velocity", "Text"],

Cell[BoxData[
    \(u\_L = \((\[Epsilon]\ L)\)\^\(1/3\) // ToSI\)], "Input"],

Cell["Integral velocity to flow velocity", "Text"],

Cell[BoxData[
    \(C\_f\^\(1/3\)\)], "Input"],

Cell["Reynolds number", "Text"],

Cell[BoxData[
    \(Rey\_L = \(\(u\_L\) L\)\/\[Nu]\)], "Input"],

Cell["Grid points", "Text"],

Cell[BoxData[
    \(NN = Rey\_L\^\(9/4\)\)], "Input"],

Cell["Time scale", "Text"],

Cell[BoxData[
    \(\[Tau]\_L = \(\[Tau]\_d\) \@Rey\_L // ToSI\)], "Input"],

Cell["Ratio of time scales", "Text"],

Cell[BoxData[
    \(\@Rey\_L\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wall turbulence", "Subsection"],

Cell[BoxData[
    \(\[Sigma]\_wall\  = \(1\/2\) \(\[Rho]\_0\) \(U\^2\) C\_f // 
        ToUnit[Pascal]\)], "Input"],

Cell["Friction velocity", "Text"],

Cell[BoxData[
    \(u\_0 = U \@\( C\_f\/2\) // ToSI\)], "Input"],

Cell["Velocity ratio", "Text"],

Cell[BoxData[
    \(\@\(C\_f\/2\)\)], "Input"],

Cell["Wall length scale", "Text"],

Cell[BoxData[
    \(\[Delta]\_0 = \[Nu]\/u\_0 // ToUnit[Micrometer]\)], "Input"],

Cell[BoxData[
    \(\(\[Delta] = a;\)\)], "Input"],

Cell[BoxData[
    \(Rey0 = \[Delta]\/\[Delta]\_0 // ToSI\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problems", "Title"],

Cell[CellGroupData[{

Cell["32.4 Iteration of friction law", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell["Parameters", "Text"],

Cell[BoxData[{
    \(\(A = 2.44;\)\), "\[IndentingNewLine]", 
    \(\(B = 5.00;\)\), "\[IndentingNewLine]", 
    \(\(CC = 0;\)\), "\[IndentingNewLine]", 
    \(\(Rey = 10\^5;\)\)}], "Input"],

Cell["Initial value", "Text"],

Cell[BoxData[
    \(\(R[1] = 1;\)\)], "Input"],

Cell["Recursion", "Text"],

Cell[BoxData[
    \(\(R[n_] := A \((Log[Rey] - Log[R[n - 1]])\) + B + CC;\)\)], "Input"],

Cell["Table of first 10 values", "Text"],

Cell[BoxData[
    \(Table[R[n], {n, 1, 10}]\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
AutoGeneratedPackage->None,
WindowSize->{861, 837},
WindowMargins->{{Automatic, 121}, {Automatic, 8}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 31, 0, 95, "Title"],
Cell[1810, 55, 281, 5, 90, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[2128, 65, 44, 0, 95, "Title"],
Cell[2175, 67, 46, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2246, 72, 57, 0, 73, "Section"],
Cell[2306, 74, 1960, 42, 390, "Input"],
Cell[4269, 118, 199, 4, 30, "Input"],
Cell[4471, 124, 135, 2, 63, "Input"],
Cell[4609, 128, 117, 3, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4775, 137, 44, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[4844, 141, 39, 0, 73, "Section"],
Cell[4886, 143, 46, 1, 30, "Input"],
Cell[4935, 146, 145, 3, 47, "Input"],
Cell[5083, 151, 103, 2, 41, "Input"],
Cell[5189, 155, 51, 1, 30, "Input"],
Cell[5243, 158, 56, 1, 30, "Input"],
Cell[5302, 161, 93, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5444, 168, 34, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[5503, 172, 52, 0, 73, "Section"],
Cell[5558, 174, 46, 1, 30, "Input"],
Cell[5607, 177, 65, 1, 30, "Input"],
Cell[5675, 180, 62, 1, 30, "Input"],
Cell[5740, 183, 61, 1, 30, "Input"],
Cell[5804, 186, 273, 5, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6114, 196, 55, 0, 73, "Section"],
Cell[6172, 198, 81, 1, 30, "Input"],
Cell[6256, 201, 61, 1, 30, "Input"],
Cell[6320, 204, 123, 3, 30, "Input"],
Cell[6446, 209, 44, 1, 42, "Input"],
Cell[6493, 212, 93, 1, 30, "Input"],
Cell[6589, 215, 139, 3, 30, "Input"],
Cell[6731, 220, 108, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6876, 227, 39, 0, 73, "Section"],
Cell[6918, 229, 427, 8, 95, "Input"],
Cell[7348, 239, 142, 3, 30, "Input"],
Cell[7493, 244, 173, 3, 52, "Input"],
Cell[7669, 249, 76, 1, 30, "Input"],
Cell[7748, 252, 341, 6, 70, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8138, 264, 44, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[8207, 268, 55, 0, 73, "Section"],
Cell[8265, 270, 46, 1, 30, "Input"],
Cell[8314, 273, 64, 1, 30, "Input"],
Cell[8381, 276, 66, 1, 30, "Input"],
Cell[8450, 279, 161, 2, 50, "Input"],
Cell[8614, 283, 46, 1, 30, "Input"],
Cell[8663, 286, 105, 2, 30, "Input"],
Cell[8771, 290, 114, 2, 30, "Input"],
Cell[8888, 294, 141, 2, 50, "Input"],
Cell[9032, 298, 46, 1, 30, "Input"],
Cell[9081, 301, 105, 2, 30, "Input"],
Cell[9189, 305, 154, 3, 30, "Input"],
Cell[9346, 310, 139, 3, 31, "Input"],
Cell[9488, 315, 427, 8, 95, "Input"],
Cell[9918, 325, 127, 3, 30, "Input"],
Cell[10048, 330, 192, 4, 48, "Input"],
Cell[10243, 336, 124, 3, 31, "Input"],
Cell[10370, 341, 204, 4, 52, "Input"],
Cell[10577, 347, 60, 1, 30, "Input"],
Cell[10640, 350, 101, 2, 30, "Input"],
Cell[10744, 354, 50, 1, 30, "Input"],
Cell[10797, 357, 80, 1, 30, "Input"],
Cell[10880, 360, 386, 7, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11303, 372, 39, 0, 73, "Section"],
Cell[11345, 374, 47, 1, 30, "Input"],
Cell[11395, 377, 107, 2, 30, "Input"],
Cell[11505, 381, 76, 1, 30, "Input"],
Cell[11584, 384, 129, 3, 31, "Input"],
Cell[11716, 389, 64, 1, 30, "Input"],
Cell[11783, 392, 66, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11886, 398, 33, 0, 73, "Section"],
Cell[11922, 400, 78, 1, 30, "Input"],
Cell[12003, 403, 167, 3, 63, "Input"],
Cell[12173, 408, 71, 1, 30, "Input"],
Cell[12247, 411, 63, 1, 30, "Input"],
Cell[12313, 414, 61, 1, 30, "Input"],
Cell[12377, 417, 66, 1, 32, "Input"],
Cell[12446, 420, 72, 1, 41, "Input"],
Cell[12521, 423, 117, 3, 30, "Input"],
Cell[12641, 428, 79, 1, 30, "Input"],
Cell[12723, 431, 118, 2, 40, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12890, 439, 36, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[12951, 443, 52, 0, 73, "Section"],
Cell[13006, 445, 46, 1, 30, "Input"],
Cell[13055, 448, 48, 1, 30, "Input"],
Cell[13106, 451, 371, 8, 84, "Input"],
Cell[13480, 461, 54, 1, 30, "Input"],
Cell[13537, 464, 115, 2, 50, "Input"],
Cell[13655, 468, 164, 4, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13856, 477, 44, 0, 73, "Section"],
Cell[13903, 479, 46, 1, 30, "Input"],
Cell[13952, 482, 92, 1, 30, "Input"],
Cell[14047, 485, 66, 1, 30, "Input"],
Cell[14116, 488, 86, 1, 42, "Input"],
Cell[14205, 491, 63, 1, 30, "Input"],
Cell[14271, 494, 163, 4, 30, "Input"],
Cell[14437, 500, 54, 1, 30, "Input"],
Cell[14494, 503, 127, 3, 30, "Input"],
Cell[14624, 508, 61, 1, 30, "Input"],
Cell[14688, 511, 74, 1, 30, "Input"],
Cell[14765, 514, 56, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14858, 520, 44, 0, 73, "Section"],
Cell[14905, 522, 87, 1, 30, "Input"],
Cell[14995, 525, 203, 4, 65, "Input"],
Cell[15201, 531, 148, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15386, 538, 37, 0, 73, "Section"],
Cell[15426, 540, 89, 2, 50, "Input"],
Cell[15518, 544, 102, 2, 50, "Input"],
Cell[15623, 548, 65, 1, 44, "Input"],
Cell[15691, 551, 46, 1, 30, "Input"],
Cell[15740, 554, 46, 1, 30, "Input"],
Cell[15789, 557, 45, 1, 30, "Input"],
Cell[15837, 560, 81, 1, 30, "Input"],
Cell[15921, 563, 72, 1, 30, "Input"],
Cell[15996, 566, 65, 1, 30, "Input"],
Cell[16064, 569, 59, 1, 42, "Input"],
Cell[16126, 572, 51, 1, 30, "Input"],
Cell[16180, 575, 82, 1, 30, "Input"],
Cell[16265, 578, 164, 4, 30, "Input"],
Cell[16432, 584, 81, 1, 30, "Input"],
Cell[16516, 587, 185, 4, 30, "Input"],
Cell[16704, 593, 146, 3, 30, "Input"],
Cell[16853, 598, 164, 3, 30, "Input"],
Cell[17020, 603, 242, 5, 55, "Input"],
Cell[17265, 610, 119, 2, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17433, 618, 39, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[17497, 622, 52, 0, 73, "Section"],
Cell[17552, 624, 46, 1, 30, "Input"],
Cell[17601, 627, 65, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[17691, 632, 33, 0, 38, "Subsection"],
Cell[17727, 634, 54, 1, 30, "Input"],
Cell[17784, 637, 89, 2, 50, "Input"],
Cell[17876, 641, 53, 1, 30, "Input"],
Cell[17932, 644, 65, 1, 44, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18034, 650, 34, 0, 38, "Subsection"],
Cell[18071, 652, 62, 1, 30, "Input"],
Cell[18136, 655, 60, 1, 30, "Input"],
Cell[18199, 658, 104, 2, 50, "Input"],
Cell[18306, 662, 232, 4, 70, "Input"],
Cell[18541, 668, 122, 2, 50, "Input"],
Cell[18666, 672, 61, 1, 30, "Input"],
Cell[18730, 675, 66, 1, 30, "Input"],
Cell[18799, 678, 75, 1, 30, "Input"],
Cell[18877, 681, 91, 1, 30, "Input"],
Cell[18971, 684, 83, 1, 30, "Input"],
Cell[19057, 687, 56, 1, 30, "Input"],
Cell[19116, 690, 136, 3, 30, "Input"],
Cell[19255, 695, 52, 1, 30, "Input"],
Cell[19310, 698, 105, 2, 30, "Input"],
Cell[19418, 702, 76, 1, 30, "Input"],
Cell[19497, 705, 56, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19602, 712, 39, 0, 73, "Section"],
Cell[19644, 714, 139, 2, 30, "Input"],
Cell[19786, 718, 508, 11, 87, "Input"],
Cell[20297, 731, 122, 3, 30, "Input"],
Cell[20422, 736, 72, 1, 30, "Input"],
Cell[20497, 739, 192, 4, 48, "Input"],
Cell[20692, 745, 93, 1, 30, "Input"],
Cell[20788, 748, 128, 3, 30, "Input"],
Cell[20919, 753, 166, 4, 30, "Input"],
Cell[21088, 759, 75, 1, 30, "Input"],
Cell[21166, 762, 192, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21395, 771, 37, 0, 73, "Section"],
Cell[21435, 773, 101, 2, 30, "Input"],
Cell[21539, 777, 79, 1, 30, "Input"],
Cell[21621, 780, 87, 1, 30, "Input"],
Cell[21711, 783, 64, 1, 30, "Input"],
Cell[21778, 786, 60, 1, 30, "Input"],
Cell[21841, 789, 77, 1, 30, "Input"],
Cell[21921, 792, 115, 2, 42, "Input"],
Cell[22039, 796, 109, 2, 30, "Input"],
Cell[22151, 800, 72, 1, 42, "Input"],
Cell[22226, 803, 51, 1, 30, "Input"],
Cell[22280, 806, 81, 1, 30, "Input"],
Cell[22364, 809, 114, 2, 42, "Input"],
Cell[22481, 813, 185, 4, 30, "Input"],
Cell[22669, 819, 92, 1, 42, "Input"],
Cell[22764, 822, 67, 1, 30, "Input"],
Cell[22834, 825, 180, 4, 30, "Input"],
Cell[23017, 831, 257, 5, 55, "Input"],
Cell[23277, 838, 119, 2, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23445, 846, 48, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[23518, 850, 47, 0, 73, "Section"],
Cell[23568, 852, 46, 1, 30, "Input"],
Cell[23617, 855, 64, 1, 30, "Input"],
Cell[23684, 858, 137, 2, 30, "Input"],
Cell[23824, 862, 41, 1, 30, "Input"],
Cell[23868, 865, 65, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23970, 871, 32, 0, 73, "Section"],
Cell[24005, 873, 167, 3, 30, "Input"],
Cell[24175, 878, 428, 8, 116, "Input"],
Cell[24606, 888, 72, 1, 30, "Input"],
Cell[24681, 891, 142, 2, 63, "Input"],
Cell[24826, 895, 51, 1, 30, "Input"],
Cell[24880, 898, 66, 1, 30, "Input"],
Cell[24949, 901, 166, 4, 30, "Input"],
Cell[25118, 907, 66, 1, 32, "Input"],
Cell[25187, 910, 72, 1, 41, "Input"],
Cell[25262, 913, 131, 3, 30, "Input"],
Cell[25396, 918, 79, 1, 30, "Input"],
Cell[25478, 921, 171, 3, 61, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25686, 929, 35, 0, 73, "Section"],
Cell[25724, 931, 158, 4, 42, "Input"],
Cell[25885, 937, 176, 3, 42, "Input"],
Cell[26064, 942, 113, 2, 30, "Input"],
Cell[26180, 946, 72, 1, 42, "Input"],
Cell[26255, 949, 76, 1, 30, "Input"],
Cell[26334, 952, 51, 1, 30, "Input"],
Cell[26388, 955, 77, 1, 30, "Input"],
Cell[26468, 958, 166, 4, 30, "Input"],
Cell[26637, 964, 147, 3, 42, "Input"],
Cell[26787, 969, 197, 4, 31, "Input"],
Cell[26987, 975, 195, 3, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27231, 984, 51, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[27307, 988, 49, 0, 73, "Section"],
Cell[27359, 990, 2293, 31, 410, "Input"],
Cell[29655, 1023, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29754, 1029, 47, 0, 73, "Section"],
Cell[29804, 1031, 64, 1, 30, "Input"],
Cell[29871, 1034, 90, 1, 30, "Input"],
Cell[29964, 1037, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30063, 1043, 28, 0, 73, "Section"],
Cell[30094, 1045, 223, 4, 50, "Input"],
Cell[30320, 1051, 96, 2, 50, "Input"],
Cell[30419, 1055, 149, 2, 65, "Input"],
Cell[30571, 1059, 129, 2, 50, "Input"],
Cell[30703, 1063, 124, 3, 31, "Input"],
Cell[30830, 1068, 153, 3, 31, "Input"],
Cell[30986, 1073, 81, 1, 31, "Input"],
Cell[31070, 1076, 91, 1, 31, "Input"],
Cell[31164, 1079, 47, 1, 30, "Input"],
Cell[31214, 1082, 45, 1, 30, "Input"],
Cell[31262, 1085, 82, 1, 30, "Input"],
Cell[31347, 1088, 346, 7, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31730, 1100, 39, 0, 73, "Section"],
Cell[31772, 1102, 44, 1, 30, "Input"],
Cell[31819, 1105, 162, 3, 42, "Input"],
Cell[31984, 1110, 159, 3, 42, "Input"],
Cell[32146, 1115, 60, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32255, 1122, 49, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[32329, 1126, 41, 0, 73, "Section"],
Cell[32373, 1128, 46, 1, 30, "Input"],
Cell[32422, 1131, 119, 2, 50, "Input"],
Cell[32544, 1135, 138, 2, 42, "Input"],
Cell[32685, 1139, 50, 1, 44, "Input"],
Cell[32738, 1142, 91, 1, 45, "Input"],
Cell[32832, 1145, 79, 1, 42, "Input"],
Cell[32914, 1148, 86, 1, 41, "Input"],
Cell[33003, 1151, 79, 1, 42, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33119, 1157, 43, 0, 73, "Section"],
Cell[33165, 1159, 46, 1, 30, "Input"],
Cell[33214, 1162, 139, 3, 70, "Input"],
Cell[33356, 1167, 53, 1, 30, "Input"],
Cell[33412, 1170, 59, 1, 30, "Input"],
Cell[33474, 1173, 235, 5, 31, "Input"],
Cell[33712, 1180, 105, 2, 44, "Input"],
Cell[33820, 1184, 50, 1, 30, "Input"],
Cell[33873, 1187, 55, 1, 30, "Input"],
Cell[33931, 1190, 50, 1, 44, "Input"],
Cell[33984, 1193, 53, 1, 30, "Input"],
Cell[34040, 1196, 55, 1, 30, "Input"],
Cell[34098, 1199, 50, 1, 44, "Input"],
Cell[34151, 1202, 92, 1, 30, "Input"],
Cell[34246, 1205, 93, 1, 30, "Input"],
Cell[34342, 1208, 89, 1, 30, "Input"],
Cell[34434, 1211, 149, 3, 40, "Input"],
Cell[34586, 1216, 151, 3, 30, "Input"],
Cell[34740, 1221, 169, 3, 44, "Input"],
Cell[34912, 1226, 86, 1, 30, "Input"],
Cell[35001, 1229, 202, 4, 31, "Input"],
Cell[35206, 1235, 210, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35453, 1244, 32, 0, 73, "Section"],
Cell[35488, 1246, 88, 1, 30, "Input"],
Cell[35579, 1249, 101, 2, 30, "Input"],
Cell[35683, 1253, 132, 3, 30, "Input"],
Cell[35818, 1258, 108, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35963, 1265, 67, 0, 73, "Section"],
Cell[36033, 1267, 1029, 22, 210, "Input"],
Cell[37065, 1291, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37162, 1297, 36, 0, 73, "Section"],
Cell[37201, 1299, 93, 1, 30, "Input"],
Cell[37297, 1302, 89, 1, 30, "Input"],
Cell[37389, 1305, 56, 1, 30, "Input"],
Cell[37448, 1308, 197, 4, 30, "Input"],
Cell[37648, 1314, 90, 1, 30, "Input"],
Cell[37741, 1317, 85, 1, 30, "Input"],
Cell[37829, 1320, 182, 3, 44, "Input"],
Cell[38014, 1325, 86, 1, 30, "Input"],
Cell[38103, 1328, 246, 5, 52, "Input"],
Cell[38352, 1335, 186, 3, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38587, 1344, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[38637, 1348, 47, 0, 73, "Section"],
Cell[38687, 1350, 46, 1, 30, "Input"],
Cell[38736, 1353, 26, 0, 33, "Text"],
Cell[38765, 1355, 320, 5, 110, "Input"],
Cell[39088, 1362, 33, 0, 33, "Text"],
Cell[39124, 1364, 46, 1, 30, "Input"],
Cell[39173, 1367, 32, 0, 33, "Text"],
Cell[39208, 1369, 63, 1, 43, "Input"],
Cell[39274, 1372, 31, 0, 33, "Text"],
Cell[39308, 1374, 67, 1, 42, "Input"],
Cell[39378, 1377, 44, 0, 33, "Text"],
Cell[39425, 1379, 84, 1, 45, "Input"],
Cell[39512, 1382, 51, 0, 33, "Text"],
Cell[39566, 1384, 102, 2, 30, "Input"],
Cell[39671, 1388, 31, 0, 33, "Text"],
Cell[39705, 1390, 53, 1, 42, "Input"],

Cell[CellGroupData[{
Cell[39783, 1395, 40, 0, 38, "Subsection"],
Cell[39826, 1397, 28, 0, 33, "Text"],
Cell[39857, 1399, 122, 2, 30, "Input"],
Cell[39982, 1403, 26, 0, 33, "Text"],
Cell[40011, 1405, 120, 2, 30, "Input"],
Cell[40134, 1409, 30, 0, 33, "Text"],
Cell[40167, 1411, 103, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40307, 1418, 37, 0, 38, "Subsection"],
Cell[40347, 1420, 24, 0, 33, "Text"],
Cell[40374, 1422, 76, 1, 30, "Input"],
Cell[40453, 1425, 50, 0, 33, "Text"],
Cell[40506, 1427, 46, 1, 30, "Input"],
Cell[40555, 1430, 31, 0, 33, "Text"],
Cell[40589, 1432, 63, 1, 42, "Input"],
Cell[40655, 1435, 27, 0, 33, "Text"],
Cell[40685, 1437, 53, 1, 30, "Input"],
Cell[40741, 1440, 26, 0, 33, "Text"],
Cell[40770, 1442, 75, 1, 31, "Input"],
Cell[40848, 1445, 36, 0, 33, "Text"],
Cell[40887, 1447, 41, 1, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40965, 1453, 37, 0, 38, "Subsection"],
Cell[41005, 1455, 115, 2, 42, "Input"],
Cell[41123, 1459, 33, 0, 33, "Text"],
Cell[41159, 1461, 64, 1, 51, "Input"],
Cell[41226, 1464, 30, 0, 33, "Text"],
Cell[41259, 1466, 46, 1, 51, "Input"],
Cell[41308, 1469, 33, 0, 33, "Text"],
Cell[41344, 1471, 80, 1, 42, "Input"],
Cell[41427, 1474, 50, 1, 30, "Input"],
Cell[41480, 1477, 69, 1, 44, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[41610, 1485, 25, 0, 95, "Title"],

Cell[CellGroupData[{
Cell[41660, 1489, 49, 0, 73, "Section"],
Cell[41712, 1491, 46, 1, 30, "Input"],
Cell[41761, 1494, 26, 0, 33, "Text"],
Cell[41790, 1496, 190, 4, 90, "Input"],
Cell[41983, 1502, 29, 0, 33, "Text"],
Cell[42015, 1504, 46, 1, 30, "Input"],
Cell[42064, 1507, 25, 0, 33, "Text"],
Cell[42092, 1509, 88, 1, 30, "Input"],
Cell[42183, 1512, 40, 0, 33, "Text"],
Cell[42226, 1514, 56, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

