(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10034,        239]*)
(*NotebookOutlinePosition[     10713,        262]*)
(*  CellTagsIndexPosition[     10669,        258]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[{
    \(\(BeginPackage["\<Lautrup`NDSolveBV`\>", \
"\<Utilities`FilterOptions`\>"];\)\), "\n", 
    \(\(ClearAttributes[
        NDSolveBV, {Protected, ReadProtected}];\)\n\[IndentingNewLine] (*\ 
      Messages\ *) \), "\n", 
    \(\(NDSolveBV::usage = "\<Numerical differential equation boundary value \
solver.\n
NDSolveBV[eqs,vars,intv,init,opts] where\n
\teqs\tcontains differential equations and boundary values with variables for \
the unknown ones\n
\tvars\tcontains the variable names\>";\)\n\ \), "\n", 
    \(\(NDSolveBV::lengtherror = "\<The number of equations, boundary \
conditions, and variables must be the same (`1`)\>";\)\), "\n", 
    \(\(NDSolveBV::intervalerror = "\<Interval must be of the form {x,a,c,b} \
with c between a and b\>";\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(JoinSolutions::usage = "\<Option for NDSolveBV for solution as a \
single interpolating function\>";\)\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(Begin["\<`Private`\>"];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Auxiliary\ functions\ *) \), "\n", 
    \(\(NumericListQ[x_] := 
        And @@ Map[NumericQ, x];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Main\ module\ *) \), "\[IndentingNewLine]", 
    \(\(NDSolveBV[eqs_, vars_, intv_, init_, 
          opts___] := \[IndentingNewLine]Module[{x, a, c, b, n, ivars, aBV, 
            bBV, odes, cvals, solac, solbc, sol, roots, args, varsac, varsbc, 
            fun, sub, int, optsNDSolveBV, optsNDSolve, optsFindRoot, 
            optsFunctionInterpolation}, \ \[IndentingNewLine]\
\[IndentingNewLine] (*\ check\ inputs\ *) \[IndentingNewLine]If[
            Length[intv] \[NotEqual] \ 4, 
            Message[NDSolveBV::intervalerror]]; \[IndentingNewLine]x = 
            intv[\([1]\)]; \[IndentingNewLine]a = 
            intv[\([2]\)]; \[IndentingNewLine]c = 
            intv[\([3]\)]; \[IndentingNewLine]b = 
            intv[\([4]\)]; \[IndentingNewLine]If[\[Not] \((a \[LessEqual] 
                    c \[LessEqual] b || 
                  a \[GreaterEqual] c \[GreaterEqual] b)\), 
            Message[NDSolveBV::intervalerror]]; \[IndentingNewLine]n = 
            Length[vars]; \[IndentingNewLine]If[
            Length[eqs] \[NotEqual] 3  n || Length[init] \[NotEqual] n, 
            Message[NDSolveBV::lengtherror, 
              n]]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            check\ options\ *) \[IndentingNewLine]optsNDSolve\  = \ 
            FilterOptions[NDSolve, opts]; \[IndentingNewLine]optsFindRoot = 
            FilterOptions[FindRoot, opts]; \[IndentingNewLine]optsNDSolveBV = 
            FilterOptions[NDSolveBV, opts, 
              Options[NDSolveBV]]; \
\[IndentingNewLine]optsFunctionInterpolation = 
            FilterOptions[FunctionInterpolation, 
              opts]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            construct\ boundary\ conditions\ *) \[IndentingNewLine]aBV = 
            Cases[eqs, _[a] \[Equal] _]; \[IndentingNewLine]bBV = 
            Cases[eqs, _[b] \[Equal] _]; \[IndentingNewLine]odes = 
            Complement[eqs, aBV, 
              bBV]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            determine\ roots\ *) \[IndentingNewLine]ivars = 
            Map[First[#] &, init]; \[IndentingNewLine]solac[
              args_?NumericListQ] := 
            Apply[NDSolve, {odes \[Union] aBV, vars, {x, a, c}, optsNDSolve} /. 
                  MapThread[#1 \[Rule] #2 &, {ivars, args}]] // 
              First; \[IndentingNewLine]solbc[args_?NumericListQ] := 
            Apply[NDSolve, {odes \[Union] bBV, vars, {x, c, b}, optsNDSolve} /. 
                  MapThread[#1 \[Rule] #2 &, {ivars, args}]] // 
              First; \[IndentingNewLine]cvals = 
            Map[#[c] &, vars]; \[IndentingNewLine]sol[
              args_?NumericListQ] := \((cvals /. solac[args])\) - \((cvals /. 
                  solbc[args])\); \[IndentingNewLine]roots = 
            Apply[FindRoot, {sol[ivars], init, 
                optsFindRoot}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            do\ integral\ *) \[IndentingNewLine]args = 
            ivars /. roots; \[IndentingNewLine]varsac = 
            solac[args]; \[IndentingNewLine]varsbc = 
            solbc[args]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            construct\ output\ *) \[IndentingNewLine] (*fun[f_, x_] := 
              If[x < c, f[x] /. varsac // Evaluate, 
                f[x] /. varsbc // Evaluate]; \[IndentingNewLine]sub = 
              Map[#[x_] -> fun[#, x] &, vars];*) \[IndentingNewLine]fun[f_] := 
            Evaluate[
                If[# < c, f[#] /. varsac // Evaluate, 
                  f[#] /. varsbc // Evaluate]] &; \[IndentingNewLine]sub = 
            Map[# -> fun[#] &, vars]; \[IndentingNewLine]int[f_] := 
            Apply[FunctionInterpolation, {f[x] /. sub, {x, a, b}, 
                optsFunctionInterpolation}]; \[IndentingNewLine]If[
            JoinSolutions /. {optsNDSolveBV}, \ 
            sub = Map[# \[Rule] int[#] &, vars]]; \[IndentingNewLine]{sub, 
            roots}\[IndentingNewLine]];\)\), "\n", 
    \(\(Options[
          NDSolveBV] = {JoinSolutions \[Rule] 
            False};\)\), "\[IndentingNewLine]", 
    \(\(End[];\)\), "\[IndentingNewLine]", 
    \(\(SetAttributes[NDSolveBV, {Protected, ReadProtected}];\)\), "\n", 
    \(\(EndPackage[];\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell["Tests", "Title"],

Cell[BoxData[
    \(<< Lautrup`\)], "Input"],

Cell[BoxData[
    \(Options[FunctionInterpolation]\)], "Input"],

Cell[BoxData[
    \(Options[NDSolveBV]\)], "Input"],

Cell[CellGroupData[{

Cell["Simple test", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[
    \(sol = 
      NDSolveBV[{\(f'\)[x] \[Equal] g[x], \(g'\)[x] \[Equal] x\^2, 
          f[0] \[Equal] 0, f[1] \[Equal] 1, g[0] == u, g[1] == v}, {f, 
          g}, {x, 0, 0.5, 1}, {{u, 0.2, 0.3}, {v, 1, 1.1}}, 
        JoinSolutions \[Rule] False]\)], "Input"],

Cell[BoxData[
    \(\(Plot[f[x] /. sol[\([1]\)], {x, 0, 1}];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Acid test", "Section"],

Cell[BoxData[
    \(CleanGlobal[]\)], "Input"],

Cell[BoxData[{
    \(\(a = 10\^\(-8\);\)\), "\n", 
    \(\(b = 10;\)\), "\n", 
    \(\(c = 0.3;\)\), "\n", 
    \(\(\[Alpha] = 10;\)\), "\n", 
    \(\(\[Beta] = 0.188;\)\), "\n", 
    \(\(ss = 0.1;\)\), "\n", 
    \(\(mm = 0.9;\)\), "\n", 
    \(\(kk = 10\^\(-12\);\)\)}], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"sol", ":=", 
        RowBox[{"NDSolveBV", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{\(\(u'\)[x] \[Equal] v[x]\), ",", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["v", "\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}], "\[Equal]", 
                  RowBox[{\(-\[Alpha]\), 
                    FractionBox[
                      RowBox[{\((1 - \[ExponentialE]\^\(-x\))\), " ", 
                        RowBox[{
                          SuperscriptBox["u", "\[Prime]",
                            MultilineFunction->None], "[", "x", 
                          "]"}]}], \(x\ g[x]\)]}]}], ",", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["g", "\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}], 
                  "\[Equal]", \(\[Beta]\^2\ u[x]\^2\/x\^2\)}], 
                ",", \(u[a] \[Equal] a\ s\), ",", \(v[a] \[Equal] s\), 
                ",", \(g[a] \[Equal] m\), ",", \(u[b] \[Equal] 1\), 
                ",", \(v[b] \[Equal] k\), ",", \(g[b] \[Equal] 1\)}], "}"}], 
            ",", \({u, v, g}\), ",", \({x, a, c, b}\), ",", 
            "\[IndentingNewLine]", \({{s, ss, 1.01  ss}, {m, mm, 
                1.01  mm}, {k, kk, 1.01  kk}}\)}], "]"}]}], ";"}]], "Input"],

Cell[BoxData[
    \(sol\)], "Input"],

Cell[BoxData[
    \(\(Plot[
        Table[u[r\^2]\/r /. sol[\([1]\)], {\[Alpha], 2, 10}] // 
          Evaluate, {r, \@a, \@b}, PlotRange \[Rule] All];\)\)], "Input"],

Cell[BoxData[
    \(\(Plot[
        Table[g[r\^2] /. sol[\([1]\)], {\[Alpha], 2, 10}] // 
          Evaluate, {r, \@a, \@b}, PlotRange \[Rule] All];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 937}},
AutoGeneratedPackage->Automatic,
WindowSize->{735, 740},
WindowMargins->{{143, Automatic}, {Automatic, 56}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 5410, 93, 1630, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[7189, 148, 22, 0, 95, "Title"],
Cell[7214, 150, 44, 1, 30, "Input"],
Cell[7261, 153, 63, 1, 30, "Input"],
Cell[7327, 156, 51, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[7403, 161, 30, 0, 73, "Section"],
Cell[7436, 163, 46, 1, 30, "Input"],
Cell[7485, 166, 277, 5, 52, "Input"],
Cell[7765, 173, 75, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7877, 179, 28, 0, 73, "Section"],
Cell[7908, 181, 46, 1, 30, "Input"],
Cell[7957, 184, 281, 8, 170, "Input"],
Cell[8241, 194, 1391, 28, 111, "Input"],
Cell[9635, 224, 36, 1, 30, "Input"],
Cell[9674, 227, 166, 3, 45, "Input"],
Cell[9843, 232, 163, 3, 33, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

